/********Stata code used for the TN:Extending WID Population Series:
Projections 2024-2100 & Age/Gender Breakdowns*********/

/****Creates provisional dataset with populations for 57 core territories 1950-2100**/



**# WID projections 1800_1949
use "$work_data/pops_1800_2023_57c.dta", clear
keep if year<1950
ren pop999i poptot
replace poptot=poptot*1000000
reshape wide poptot, i(year) j(country) string
save "$work_data/pops_1800_1949_57c.dta", replace


**# UN data 1950-2100
use "$work_data/populations.dta", clear
tab year
drop p
ren iso country


gen coreterritory=.
		foreach c of global coreterritories{
			replace coreterritory=1 if country=="`c'"
		}
		gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		keep if (coreterritory==1  | corecountry==1)
		
		keep if widcode=="npopul999i"
		keep value year country
reshape wide value	, i(year) 	j(country) string

ren value* poptot*

*Original Regions
*aggregate into regions
		g poptotEURO= poptotAD+ poptotAL+ poptotAT+ poptotBA+ poptotBE+ poptotBG+ poptotCH+ poptotCY+ poptotCZ+ poptotDE+ poptotDK+ poptotEE+ poptotES+ poptotFI+ poptotFR+ poptotGB+ poptotGG+ poptotGI+ poptotGR+ poptotHR+ poptotHU+ poptotIE+ poptotIM+ poptotIS+ poptotIT+ poptotJE+ poptotKS+ poptotLI+ poptotLT+ poptotLU+ poptotLV+ poptotMC+ poptotMD+ poptotME+ poptotMK+ poptotMT+ poptotNL+ poptotNO+ poptotPL+ poptotPT+ poptotRO+ poptotRS+ poptotSE+ poptotSI+ poptotSK+ poptotSM
		
		*Check that PAPUA NEW GUINEA is NAOC-> YES
		gen poptotNAOC= poptotAU+ poptotBM+ poptotCA+ poptotFJ+ poptotFM+ poptotGL+ poptotKI+ poptotMH+ poptotNC+ poptotNR+ poptotNZ+ poptotPF+ poptotPG+ poptotPW+ poptotSB+ poptotTO+ poptotTV+ poptotUS+ poptotVU+ poptotWS
		
		gen poptotLATA= poptotAG+ poptotAI+ poptotAR+ poptotAW+ poptotBB+ poptotBO+ poptotBQ+ poptotBR+ poptotBS+ poptotBZ+ poptotCL+ poptotCO+ poptotCR+ poptotCU+ poptotCW+ poptotDM+ poptotDO+ poptotEC+ poptotGD+ poptotGT+ poptotGY+ poptotHN+ poptotHT+ poptotJM+ poptotKN+ poptotKY+ poptotLC+ poptotMS+ poptotMX+ poptotNI+ poptotPA+ poptotPE+ poptotPR+ poptotPY+ poptotSR+ poptotSV+ poptotSX+ poptotTC+ poptotTT+ poptotUY+ poptotVC+ poptotVE+ poptotVG
		
		gen poptotMENA= poptotAE+ poptotBH+ poptotDZ+ poptotEG+ poptotIL+ poptotIQ+ poptotIR+ poptotJO+ poptotKW+ poptotLB+ poptotLY+ poptotMA+ poptotOM+ poptotPS+ poptotQA+ poptotSA+ poptotSY+ poptotTN+ poptotTR+ poptotYE
		
		gen poptotSSAF= poptotAO+ poptotBF+ poptotBI+ poptotBJ+ poptotBW+ poptotCD+ poptotCF+ poptotCG+ poptotCI+ poptotCM+ poptotCV+ poptotDJ+ poptotER+ poptotET+ poptotGA+ poptotGH+ poptotGM+ poptotGN+ poptotGQ+ poptotGW+ poptotKE+ poptotKM+ poptotLR+ poptotLS+ poptotMG+ poptotML+ poptotMR+ poptotMU+ poptotMW+ poptotMZ+ poptotNA+ poptotNE+ poptotNG+ poptotRW+ poptotSC+ poptotSD+ poptotSL+ poptotSN+ poptotSO+ poptotSS+ poptotST+ poptotSZ+ poptotTD+ poptotTG+ poptotTZ+ poptotUG+ poptotZA+ poptotZM+ poptotZW
		
		gen poptotRUCA= poptotAM+ poptotAZ+ poptotBY+ poptotGE+ poptotKG+ poptotKZ+ poptotRU+ poptotTJ+ poptotTM+ poptotUA+ poptotUZ
		
		gen poptotEASA= poptotCN+ poptotHK+ poptotJP+ poptotKP+ poptotKR+ poptotMN+ poptotMO+ poptotTW
		
		gen poptotSSEA= poptotAF+ poptotBD+ poptotBN+ poptotBT+ poptotID+ poptotIN+ poptotKH+ poptotLA+ poptotLK+ poptotMM+ poptotMV+ poptotMY+ poptotNP+ poptotPH+ poptotPK+ poptotSG+ poptotTH+ poptotTL+ poptotVN
		
		gen poptotWO=poptotEURO+poptotNAOC+poptotLATA+poptotMENA+poptotSSAF+poptotRUCA+poptotEASA+poptotSSEA
		
		gen poptotQM=poptotAL		+poptotBA		+poptotBG		+poptotCY		+poptotCZ		+poptotEE		+poptotHR		+poptotHU		+poptotLT		+poptotLV		+poptotMD		+poptotME		+poptotMK		+poptotPL		+poptotRO		+poptotRS		+poptotSI		+poptotSK +			poptotKS


		gen poptotOH=poptotNAOC-(poptotUS+poptotCA+poptotAU+poptotNZ)
		gen poptotOD=poptotLATA-(poptotAR+poptotBR+poptotCL+poptotCO+poptotMX)
		gen poptotOE=poptotMENA-(poptotTR+poptotEG+poptotDZ)
		gen poptotOJ=poptotSSAF-poptotZA
		gen poptotOA=poptotRUCA-poptotRU
		gen poptotOB=poptotEASA-(poptotCN+poptotJP)
		gen poptotOI=poptotSSEA-(poptotIN+poptotID)
		gen poptotOC=poptotEURO-(poptotDE+poptotFR+poptotGB+poptotIT+poptotES+poptotSE+poptotQM)
		
	foreach var in 	poptotOM poptotOH poptotOD poptotOE poptotOJ poptotOA poptotOB poptotOI poptotOC{
		replace `var'=0 if `var'<0 
	}


		*East-Southern Africa
			gen poptotESAF= poptotBI	+poptotBW	+poptotDJ	+poptotER	+poptotET	+poptotKE	+poptotKM	+poptotLS	+poptotMG	+poptotMU	+poptotMW	+poptotMZ	+poptotNA	+poptotRW	+poptotSC	+poptotSD	+poptotSO	+poptotSS	+poptotSZ	+poptotTZ	+poptotUG	+poptotZA	+poptotZM	+poptotZW	/*+poptotZZ*/ //Ricardo subregion:East-Southern Africa

			*West-Central Africa
			gen poptotWCAF= poptotAO	+poptotBF	+poptotBJ	+poptotCD	+poptotCF	+poptotCG	+poptotCI	+poptotCM	+poptotCV	+poptotGA	+poptotGH	+poptotGM	+poptotGN	+poptotGQ	+poptotGW	+poptotLR	+poptotML	+poptotMR	+poptotNE	+poptotNG	/*+poptotSH*/	+poptotSL	+poptotSN	+poptotST	+poptotTD	+poptotTG //Ricardo subregion:West-Central Africa

			*South East Asia
			g poptotSEAS=poptotBN	+poptotID	+poptotKH	+poptotLA	+poptotMM	+poptotMY	+poptotPH	+poptotSG	+poptotTH	+poptotTL	+poptotVN

			*South Asia
			g poptotSAS=poptotAF	+poptotBD	+poptotBT	+poptotIN	+poptotLK	+poptotMV	+poptotNP	+poptotPK


*NEW regions
		**generate other residuals
		*Europe, add (Denmark, Norway, Netherlands) and substract them from OC
		g poptotOC_E=poptotOC-poptotNL-poptotNO-poptotDK
		
		*EASA, add (South Korea and Taiwan) and substract them from OB
		g poptotOB_E=poptotOB-poptotKR-poptotTW
		
		*MENA, add (Iran, Morocco, Saudi Arabia, and UAE) and substract them from OE
		g poptotOE_E=poptotOE-poptotIR-poptotMA-poptotSA-poptotAE
		
		*SSEA, add (Bangladesh, Myanmar, Pakistan, Phillipines, Thailand, Vietnam) and substract them from OI
		g poptotOI_E=poptotOI-poptotBD-poptotMM-poptotPK-poptotPH-poptotTH-poptotVN
		replace poptotOI_E=0 if poptotOI_E<0
		
		*SSAF, add (Congo, Ethiopia, Kenya, Ivory Coast, Mali, Niger, NIgeria, Rwanda, Sudan) and substract them from OI
		g poptotOJ_E=poptotOJ-poptotCD-poptotET-poptotKE-poptotCI-poptotML-poptotNE-poptotNG-poptotRW-poptotSD		
	
sum poptotO*	

drop poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA
		/***sous-totaux regionaux**/
		gen poptotEURO=poptotDE+poptotFR+poptotGB+poptotIT+poptotES+poptotSE+poptotOC+poptotQM
		gen poptotNAOC=poptotUS+poptotCA+poptotAU+poptotNZ+poptotOH
		gen poptotLATA=poptotAR+poptotBR+poptotCL+poptotCO+poptotMX+poptotOD
		gen poptotMENA=poptotTR+poptotEG+poptotDZ+poptotOE
		gen poptotSSAF=poptotZA+poptotOJ
		gen poptotRUCA=poptotRU+poptotOA
		gen poptotEASA=poptotCN+poptotJP+poptotOB
		gen poptotSSEA=poptotIN+poptotID+poptotOI

		drop poptotESAF poptotWCAF poptotSEAS poptotSAS
		*East-Southern Africa
		gen poptotESAF= poptotBI	+poptotBW	+poptotDJ	+poptotER	+poptotET	+poptotKE	+poptotKM	+poptotLS	+poptotMG	+poptotMU	+poptotMW	+poptotMZ	+poptotNA	+poptotRW	+poptotSC	+poptotSD	+poptotSO	+poptotSS	+poptotSZ	+poptotTZ	+poptotUG	+poptotZA	+poptotZM	+poptotZW	/*+poptotZZ*/ //Ricardo subregion:East-Southern Africa

		*West-Central Africa
		gen poptotWCAF= poptotAO	+poptotBF	+poptotBJ	+poptotCD	+poptotCF	+poptotCD	+poptotCI	+poptotCM	+poptotCV	+poptotGA	+poptotGH	+poptotGM	+poptotGN	+poptotGQ	+poptotGW	+poptotLR	+poptotML	+poptotMR	+poptotNE	+poptotNG	/*+poptotSH*/	+poptotSL	+poptotSN	+poptotST	+poptotTD	+poptotTG //Ricardo subregion:West-Central Africa

		*South East Asia
		g poptotSEAS=poptotBN	+poptotID	+poptotKH	+poptotLA	+poptotMM	+poptotMY	+poptotPH	+poptotSG	+poptotTH	+poptotTL	+poptotVN

		*South Asia
		g poptotSAS=poptotAF	+poptotBD	+poptotBT	+poptotIN	+poptotLK	+poptotMV	+poptotNP	+poptotPK
		
		
		drop poptotWO
		gen poptotWO=poptotEURO+poptotNAOC+poptotLATA+poptotMENA+poptotSSAF+poptotRUCA+poptotEASA+poptotSSEA
		
	/****construction of annual 1800-2023 population series for the 57 extended core territories**/
		keep year poptotWO  poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA ///
		poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC_E  poptotNL poptotNO poptotDK poptotQM ///
		poptotUS poptotCA poptotAU poptotNZ poptotOH /// 
		poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD /// 
		poptotTR poptotEG poptotDZ poptotOE_E poptotIR poptotMA poptotSA poptotAE ///
		poptotZA poptotOJ_E poptotCD poptotET poptotKE poptotCI poptotML poptotNE poptotNG poptotRW poptotSD /// 
		poptotRU poptotOA /// 
		poptotCN poptotJP poptotOB_E  poptotKR poptotTW /// 
		poptotIN poptotID poptotOI_E poptotBD poptotMM poptotPK poptotPH poptotTH poptotVN ///
		poptotESAF poptotWCAF poptotSEAS poptotSAS ///
		poptotOC poptotOJ poptotOE poptotOI poptotOB
		order year poptotWO  poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA ///
		poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC_E  poptotNL poptotNO poptotDK poptotQM ///
		poptotUS poptotCA poptotAU poptotNZ poptotOH /// 
		poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD /// 
		poptotTR poptotEG poptotDZ poptotOE_E poptotIR poptotMA poptotSA poptotAE ///
		poptotZA poptotOJ_E poptotCD poptotET poptotKE poptotCI poptotML poptotNE poptotNG poptotRW poptotSD /// 
		poptotRU poptotOA /// 
		poptotCN poptotJP poptotOB_E  poptotKR poptotTW /// 
		poptotIN poptotID poptotOI_E poptotBD poptotMM poptotPK poptotPH poptotTH poptotVN ///
		poptotESAF poptotWCAF poptotSEAS poptotSAS ///
		poptotOC poptotOJ poptotOE poptotOI poptotOB		
		
		
			drop if year<1950
			
**# Main dataset			
	append using "$work_data/pops_1800_1949_57c.dta"
	
	drop poptotEURO	
	gen poptotEURO=poptotDE+poptotFR+poptotGB+poptotIT+poptotES+poptotSE+poptotOC_E+poptotNL+poptotNO+poptotDK+poptotQM
	
	drop poptotNAOC 
	gen poptotNAOC=poptotUS+poptotCA+poptotAU+poptotNZ+poptotOH	
	
	drop poptotLATA
	gen poptotLATA=poptotAR+poptotBR+poptotCL+poptotCO+poptotMX+poptotOD
	
	drop poptotMENA
	gen poptotMENA=poptotTR+poptotEG+poptotDZ+poptotOE_E+poptotIR+poptotMA+poptotSA+poptotAE
	
	drop poptotSSAF
	gen poptotSSAF=poptotZA+poptotOJ_E+poptotCD+poptotET+poptotKE+poptotCI+poptotML+poptotNE+poptotNG+poptotRW+poptotSD
	
	drop poptotRUCA
	gen poptotRUCA=poptotRU+poptotOA
	
	drop poptotEASA
	gen poptotEASA=poptotCN+poptotJP+poptotOB_E+poptotKR+poptotTW
	
	drop poptotSSEA
	gen poptotSSEA=poptotIN+poptotID+poptotOI_E+poptotBD+poptotMM+poptotPK+poptotPH+poptotTH+poptotVN	
	
	
*East-Southern Africa
drop poptotESAF
gen poptotESAF=poptotSSAF-poptotWCAF 

*South East Asia
drop poptotSEAS
g poptotSEAS=poptotSSEA-poptotSAS


drop poptotWO
	gen poptotWO=poptotEURO+poptotNAOC+poptotLATA+poptotMENA+poptotSSAF+poptotRUCA+poptotEASA+poptotSSEA	
	
tsset year
tsline poptotES , xline( 1950)
tsline poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA, xline(1950)

ren poptot* pop999i*
reshape long pop999i , i(year) j(country) string	

save "$work_data\pop_1800_2100_57extendedterritories.dta",replace
















