/********Stata code used for the TN:Extending WID Population Series:
Projections 2024-2100 & Age/Gender Breakdowns*********/

/****Creates inputs for decompositions of population growth 2024-2100 
decomposde by net migration or natural change**/


gl year 	"2024"
gl pastyear "2022"

**# Fertility
import excel "$root\raw-data/WPP${year}_GEN_F01_DEMOGRAPHIC_INDICATORS_COMPACT.xlsx", ///
	cellrange(B17) firstrow case(lower) clear	

*start only with birthsthousands 
keep regionsubregioncountryorar notes iso2alphacode type parentcode birthsthousands /*birthsbywomenaged15to19t crudebirthratebirthsper10 totalfertilityratelivebirth netreproductionratesurviving meanagechildbearingyears sexratioatbirthmalesper10*/ year

ren iso2alphacode iso
ren birthsthousands value


// Kosovo
replace iso = "KS" if iso == "XK"
drop if missing(iso)
 
destring value, replace force
drop if value >= .
replace value = 1e3*value

generate age = "all"
generate sex = "both"

tab year



// Some corrections for consistency with the macroeconomic data ------------- //

// For France, add Guiana and Polynesia
egen value2 = total(value) if inlist(iso, "FR", "GF", "GP", "MQ", "YT", "RE"), ///
	by(year age sex)
drop if inlist(iso, "GF", "GP", "MQ", "YT", "RE")
replace value = value2 if (iso == "FR")
drop value2


// Idem for Czechoslovakia
egen value2 = total(value) if inlist(iso, "CZ", "SK"), by(year age sex)
expand 2 if (iso == "CZ"), generate(newobs)
replace iso = "CS" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for Yugoslavia
egen value2 = total(value) if inlist(iso, "HR", "SI", "RS", "MK", "BA", "ME"), by(year age sex)
expand 2 if (iso == "RS"), generate(newobs)
replace iso = "YU" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for USSR
generate inUSSR = 0
replace inUSSR = 1 if inlist(iso, "AM", "AZ", "BY", "EE", "GE", "KZ", "KG")
replace inUSSR = 1 if inlist(iso, "LV", "LT", "MD", "RU", "TJ")
replace inUSSR = 1 if inlist(iso, "TM", "UA", "UZ")
egen value2 = total(value) if inUSSR, by(year age sex)
expand 2 if (iso == "RU"), generate(newobs)
replace iso = "SU" if newobs
replace value = value2 if newobs
drop value2 newobs inUSSR

ren iso country
gen corecountry=.
foreach c of global corecountries{
	replace corecountry=1 if country=="`c'"
}
keep if corecountry==1

keep year country value
ren value births
save "$work_data/fertility_1950_2023.dta",replace












**# Mortality
import excel "$root\raw-data/WPP${year}_GEN_F01_DEMOGRAPHIC_INDICATORS_COMPACT.xlsx", ///
	cellrange(B17) firstrow case(lower) clear	

keep regionsubregioncountryorar notes iso2alphacode type parentcode totaldeathsthousands  year



ren iso2alphacode iso
ren totaldeathsthousands value


// Kosovo
replace iso = "KS" if iso == "XK"
drop if missing(iso)
 
destring value, replace force
drop if value >= .
replace value = 1e3*value

generate age = "all"
generate sex = "both"

tab year



// Some corrections for consistency with the macroeconomic data ------------- //

// For France, add Guiana and Polynesia
egen value2 = total(value) if inlist(iso, "FR", "GF", "GP", "MQ", "YT", "RE"), ///
	by(year age sex)
drop if inlist(iso, "GF", "GP", "MQ", "YT", "RE")
replace value = value2 if (iso == "FR")
drop value2


// Idem for Czechoslovakia
egen value2 = total(value) if inlist(iso, "CZ", "SK"), by(year age sex)
expand 2 if (iso == "CZ"), generate(newobs)
replace iso = "CS" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for Yugoslavia
egen value2 = total(value) if inlist(iso, "HR", "SI", "RS", "MK", "BA", "ME"), by(year age sex)
expand 2 if (iso == "RS"), generate(newobs)
replace iso = "YU" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for USSR
generate inUSSR = 0
replace inUSSR = 1 if inlist(iso, "AM", "AZ", "BY", "EE", "GE", "KZ", "KG")
replace inUSSR = 1 if inlist(iso, "LV", "LT", "MD", "RU", "TJ")
replace inUSSR = 1 if inlist(iso, "TM", "UA", "UZ")
egen value2 = total(value) if inUSSR, by(year age sex)
expand 2 if (iso == "RU"), generate(newobs)
replace iso = "SU" if newobs
replace value = value2 if newobs
drop value2 newobs inUSSR

ren iso country
gen corecountry=.
foreach c of global corecountries{
	replace corecountry=1 if country=="`c'"
}
keep if corecountry==1

keep year country value
ren value deaths
save "$work_data/mortality_1950_2023.dta",replace






**# Migration
import excel "$root\raw-data/WPP${year}_GEN_F01_DEMOGRAPHIC_INDICATORS_COMPACT.xlsx", ///
	cellrange(B17) firstrow case(lower) clear	

keep regionsubregioncountryorar notes iso2alphacode type parentcode netnumberofmigrantsthousand  year



ren iso2alphacode iso
ren netnumberofmigrantsthousand value


// Kosovo
replace iso = "KS" if iso == "XK"
drop if missing(iso)
 
destring value, replace force
drop if value >= .
replace value = 1e3*value

generate age = "all"
generate sex = "both"

tab year



// Some corrections for consistency with the macroeconomic data ------------- //

// For France, add Guiana and Polynesia
egen value2 = total(value) if inlist(iso, "FR", "GF", "GP", "MQ", "YT", "RE"), ///
	by(year age sex)
drop if inlist(iso, "GF", "GP", "MQ", "YT", "RE")
replace value = value2 if (iso == "FR")
drop value2


// Idem for Czechoslovakia
egen value2 = total(value) if inlist(iso, "CZ", "SK"), by(year age sex)
expand 2 if (iso == "CZ"), generate(newobs)
replace iso = "CS" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for Yugoslavia
egen value2 = total(value) if inlist(iso, "HR", "SI", "RS", "MK", "BA", "ME"), by(year age sex)
expand 2 if (iso == "RS"), generate(newobs)
replace iso = "YU" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for USSR
generate inUSSR = 0
replace inUSSR = 1 if inlist(iso, "AM", "AZ", "BY", "EE", "GE", "KZ", "KG")
replace inUSSR = 1 if inlist(iso, "LV", "LT", "MD", "RU", "TJ")
replace inUSSR = 1 if inlist(iso, "TM", "UA", "UZ")
egen value2 = total(value) if inUSSR, by(year age sex)
expand 2 if (iso == "RU"), generate(newobs)
replace iso = "SU" if newobs
replace value = value2 if newobs
drop value2 newobs inUSSR

ren iso country
gen corecountry=.
foreach c of global corecountries{
	replace corecountry=1 if country=="`c'"
}
keep if corecountry==1

keep year country value
ren value netmigrants
save "$work_data/netmigrants_1950_2023.dta",replace










**# Population
import excel "$root\raw-data/WPP${year}_GEN_F01_DEMOGRAPHIC_INDICATORS_COMPACT.xlsx", ///
	cellrange(B17) firstrow case(lower) clear	

keep regionsubregioncountryorar notes iso2alphacode type parentcode totalpopulationasof1januar year



ren iso2alphacode iso
ren totalpopulationasof1januar value


// Kosovo
replace iso = "KS" if iso == "XK"
drop if missing(iso)
 
destring value, replace force
drop if value >= .
replace value = 1e3*value

generate age = "all"
generate sex = "both"

tab year



// Some corrections for consistency with the macroeconomic data ------------- //

// For France, add Guiana and Polynesia
egen value2 = total(value) if inlist(iso, "FR", "GF", "GP", "MQ", "YT", "RE"), ///
	by(year age sex)
drop if inlist(iso, "GF", "GP", "MQ", "YT", "RE")
replace value = value2 if (iso == "FR")
drop value2


// Idem for Czechoslovakia
egen value2 = total(value) if inlist(iso, "CZ", "SK"), by(year age sex)
expand 2 if (iso == "CZ"), generate(newobs)
replace iso = "CS" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for Yugoslavia
egen value2 = total(value) if inlist(iso, "HR", "SI", "RS", "MK", "BA", "ME"), by(year age sex)
expand 2 if (iso == "RS"), generate(newobs)
replace iso = "YU" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for USSR
generate inUSSR = 0
replace inUSSR = 1 if inlist(iso, "AM", "AZ", "BY", "EE", "GE", "KZ", "KG")
replace inUSSR = 1 if inlist(iso, "LV", "LT", "MD", "RU", "TJ")
replace inUSSR = 1 if inlist(iso, "TM", "UA", "UZ")
egen value2 = total(value) if inUSSR, by(year age sex)
expand 2 if (iso == "RU"), generate(newobs)
replace iso = "SU" if newobs
replace value = value2 if newobs
drop value2 newobs inUSSR

ren iso country
gen corecountry=.
foreach c of global corecountries{
	replace corecountry=1 if country=="`c'"
}
keep if corecountry==1

keep year country value
ren value poptot
save "$work_data/poptot_1950_2023.dta",replace




use "$work_data/fertility_1950_2023.dta",clear
* erase"$work_data/fertility_1950_2023.dta"
merge 1:1 country year using "$work_data/mortality_1950_2023.dta"
drop _merge
* erase"$work_data/mortality_1950_2023.dta"
merge 1:1 country year using "$work_data/netmigrants_1950_2023.dta"
drop _merge 
* erase"$work_data/netmigrants_1950_2023.dta"
merge 1:1 country year using "$work_data/poptot_1950_2023.dta"
drop _merge 
* erase"$work_data/poptot_1950_2023.dta"


save "$work_data/un_1950_2023.dta",replace
















**# Fertility-Un Projections
import excel "$root\raw-data/WPP${year}_GEN_F01_DEMOGRAPHIC_INDICATORS_COMPACT.xlsx", ///
	cellrange(B17) sheet("Medium variant")  firstrow case(lower) clear	

*start only with birthsthousands 
keep regionsubregioncountryorar notes iso2alphacode type parentcode birthsthousands year

ren iso2alphacode iso
ren birthsthousands value


// Kosovo
replace iso = "KS" if iso == "XK"
drop if missing(iso)
 
destring value, replace force
drop if value >= .
replace value = 1e3*value

generate age = "all"
generate sex = "both"

tab year



// Some corrections for consistency with the macroeconomic data ------------- //

// For France, add Guiana and Polynesia
egen value2 = total(value) if inlist(iso, "FR", "GF", "GP", "MQ", "YT", "RE"), ///
	by(year age sex)
drop if inlist(iso, "GF", "GP", "MQ", "YT", "RE")
replace value = value2 if (iso == "FR")
drop value2


// Idem for Czechoslovakia
egen value2 = total(value) if inlist(iso, "CZ", "SK"), by(year age sex)
expand 2 if (iso == "CZ"), generate(newobs)
replace iso = "CS" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for Yugoslavia
egen value2 = total(value) if inlist(iso, "HR", "SI", "RS", "MK", "BA", "ME"), by(year age sex)
expand 2 if (iso == "RS"), generate(newobs)
replace iso = "YU" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for USSR
generate inUSSR = 0
replace inUSSR = 1 if inlist(iso, "AM", "AZ", "BY", "EE", "GE", "KZ", "KG")
replace inUSSR = 1 if inlist(iso, "LV", "LT", "MD", "RU", "TJ")
replace inUSSR = 1 if inlist(iso, "TM", "UA", "UZ")
egen value2 = total(value) if inUSSR, by(year age sex)
expand 2 if (iso == "RU"), generate(newobs)
replace iso = "SU" if newobs
replace value = value2 if newobs
drop value2 newobs inUSSR

ren iso country
gen corecountry=.
foreach c of global corecountries{
	replace corecountry=1 if country=="`c'"
}
keep if corecountry==1

keep year country value
ren value births
save "$work_data/fertility_2024_2100.dta",replace






**# Mortality -projections
import excel "$root\raw-data/WPP${year}_GEN_F01_DEMOGRAPHIC_INDICATORS_COMPACT.xlsx", ///
	cellrange(B17) firstrow case(lower) sheet("Medium variant") clear	

keep regionsubregioncountryorar notes iso2alphacode type parentcode totaldeathsthousands  year



ren iso2alphacode iso
ren totaldeathsthousands value


// Kosovo
replace iso = "KS" if iso == "XK"
drop if missing(iso)
 
destring value, replace force
drop if value >= .
replace value = 1e3*value

generate age = "all"
generate sex = "both"

tab year



// Some corrections for consistency with the macroeconomic data ------------- //

// For France, add Guiana and Polynesia
egen value2 = total(value) if inlist(iso, "FR", "GF", "GP", "MQ", "YT", "RE"), ///
	by(year age sex)
drop if inlist(iso, "GF", "GP", "MQ", "YT", "RE")
replace value = value2 if (iso == "FR")
drop value2


// Idem for Czechoslovakia
egen value2 = total(value) if inlist(iso, "CZ", "SK"), by(year age sex)
expand 2 if (iso == "CZ"), generate(newobs)
replace iso = "CS" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for Yugoslavia
egen value2 = total(value) if inlist(iso, "HR", "SI", "RS", "MK", "BA", "ME"), by(year age sex)
expand 2 if (iso == "RS"), generate(newobs)
replace iso = "YU" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for USSR
generate inUSSR = 0
replace inUSSR = 1 if inlist(iso, "AM", "AZ", "BY", "EE", "GE", "KZ", "KG")
replace inUSSR = 1 if inlist(iso, "LV", "LT", "MD", "RU", "TJ")
replace inUSSR = 1 if inlist(iso, "TM", "UA", "UZ")
egen value2 = total(value) if inUSSR, by(year age sex)
expand 2 if (iso == "RU"), generate(newobs)
replace iso = "SU" if newobs
replace value = value2 if newobs
drop value2 newobs inUSSR

ren iso country
gen corecountry=.
foreach c of global corecountries{
	replace corecountry=1 if country=="`c'"
}
keep if corecountry==1

keep year country value
ren value deaths
save "$work_data/mortality_2024_2100.dta",replace








**# Migration UN projections
import excel "$root\raw-data/WPP${year}_GEN_F01_DEMOGRAPHIC_INDICATORS_COMPACT.xlsx", ///
	cellrange(B17) firstrow case(lower) sheet("Medium variant") clear	

keep regionsubregioncountryorar notes iso2alphacode type parentcode netnumberofmigrantsthousand /*netmigrationrateper1000po*/ year



ren iso2alphacode iso
ren netnumberofmigrantsthousand value


// Kosovo
replace iso = "KS" if iso == "XK"
drop if missing(iso)
 
destring value, replace force
drop if value >= .
replace value = 1e3*value

generate age = "all"
generate sex = "both"

tab year



// Some corrections for consistency with the macroeconomic data ------------- //

// For France, add Guiana and Polynesia
egen value2 = total(value) if inlist(iso, "FR", "GF", "GP", "MQ", "YT", "RE"), ///
	by(year age sex)
drop if inlist(iso, "GF", "GP", "MQ", "YT", "RE")
replace value = value2 if (iso == "FR")
drop value2


// Idem for Czechoslovakia
egen value2 = total(value) if inlist(iso, "CZ", "SK"), by(year age sex)
expand 2 if (iso == "CZ"), generate(newobs)
replace iso = "CS" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for Yugoslavia
egen value2 = total(value) if inlist(iso, "HR", "SI", "RS", "MK", "BA", "ME"), by(year age sex)
expand 2 if (iso == "RS"), generate(newobs)
replace iso = "YU" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for USSR
generate inUSSR = 0
replace inUSSR = 1 if inlist(iso, "AM", "AZ", "BY", "EE", "GE", "KZ", "KG")
replace inUSSR = 1 if inlist(iso, "LV", "LT", "MD", "RU", "TJ")
replace inUSSR = 1 if inlist(iso, "TM", "UA", "UZ")
egen value2 = total(value) if inUSSR, by(year age sex)
expand 2 if (iso == "RU"), generate(newobs)
replace iso = "SU" if newobs
replace value = value2 if newobs
drop value2 newobs inUSSR

ren iso country
gen corecountry=.
foreach c of global corecountries{
	replace corecountry=1 if country=="`c'"
}
keep if corecountry==1

keep year country value
ren value netmigrants
save "$work_data/netmigrants_2024_2100.dta",replace





**# Population
import excel "$root\raw-data/WPP${year}_GEN_F01_DEMOGRAPHIC_INDICATORS_COMPACT.xlsx", ///
	cellrange(B17) firstrow case(lower) sheet("Medium variant") clear	

keep regionsubregioncountryorar notes iso2alphacode type parentcode totalpopulationasof1januar year



ren iso2alphacode iso
ren totalpopulationasof1januar value


// Kosovo
replace iso = "KS" if iso == "XK"
drop if missing(iso)
 
destring value, replace force
drop if value >= .
replace value = 1e3*value

generate age = "all"
generate sex = "both"

tab year



// Some corrections for consistency with the macroeconomic data ------------- //

// For France, add Guiana and Polynesia
egen value2 = total(value) if inlist(iso, "FR", "GF", "GP", "MQ", "YT", "RE"), ///
	by(year age sex)
drop if inlist(iso, "GF", "GP", "MQ", "YT", "RE")
replace value = value2 if (iso == "FR")
drop value2


// Idem for Czechoslovakia
egen value2 = total(value) if inlist(iso, "CZ", "SK"), by(year age sex)
expand 2 if (iso == "CZ"), generate(newobs)
replace iso = "CS" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for Yugoslavia
egen value2 = total(value) if inlist(iso, "HR", "SI", "RS", "MK", "BA", "ME"), by(year age sex)
expand 2 if (iso == "RS"), generate(newobs)
replace iso = "YU" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for USSR
generate inUSSR = 0
replace inUSSR = 1 if inlist(iso, "AM", "AZ", "BY", "EE", "GE", "KZ", "KG")
replace inUSSR = 1 if inlist(iso, "LV", "LT", "MD", "RU", "TJ")
replace inUSSR = 1 if inlist(iso, "TM", "UA", "UZ")
egen value2 = total(value) if inUSSR, by(year age sex)
expand 2 if (iso == "RU"), generate(newobs)
replace iso = "SU" if newobs
replace value = value2 if newobs
drop value2 newobs inUSSR

ren iso country
gen corecountry=.
foreach c of global corecountries{
	replace corecountry=1 if country=="`c'"
}
keep if corecountry==1

keep year country value
ren value poptot
save "$work_data/poptot_2024_2100.dta",replace






**# Population growth decompositions (net fertility +net migrants) in %

use "$work_data/fertility_2024_2100.dta",clear
* erase"$work_data/fertility_2024_2100.dta"
merge 1:1 country year using "$work_data/mortality_2024_2100.dta"
drop _merge
* erase"$work_data/mortality_2024_2100.dta"
merge 1:1 country year using "$work_data/netmigrants_2024_2100.dta"
drop _merge 
* erase"$work_data/netmigrants_2024_2100.dta"
merge 1:1 country year using "$work_data/poptot_2024_2100.dta"
drop _merge 
* erase"$work_data/poptot_2024_2100.dta"


save "$work_data/un_2024_2100.dta",replace



use "$work_data/un_1950_2023.dta",clear
* erase"$work_data/un_1950_2023.dta"
append using "$work_data/un_2024_2100.dta"
* erase"$work_data/un_2024_2100.dta"

g netmortality=births-deaths


save "$outputs/un_1950_2100_fert_mort_migr_216.dta",replace


**# Decomposition

use "$outputs/un_1950_2100_fert_mort_migr_216.dta",clear

 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region

collapse (sum)	births deaths netmigrants poptot netmortality, by(year region)

*Panel format	
encode region,g(id)
xtset id year

*Calculate 
g new_poptot=L.poptot+netmortality+netmigrants
format new_poptot %13.0g
replace new_poptot=poptot if year==1950 & new_poptot==.
// g other=poptot-new_poptot



g change_in_poptot=new_poptot-L.new_poptot
g residual=poptot-new_poptot
order region year new_poptot change_in_poptot netmortality netmigrants id
keep region year new_poptot change_in_poptot netmortality netmigrants id


	save "$work_data/un_fert_mort_migr_region.dta",replace

	g growth_poptot=change_in_poptot/L.new_poptot
g growth_netfertility=netmortality/L.new_poptot
g growth_netmigrants=netmigrants/L.new_poptot
format change_in_poptot netmortality netmigrants %13.0g
drop id
reshape wide new_poptot change_in_poptot netmortality netmigrants  growth*, i(year) j(region) string
keep year growth*
export excel using $outputs/GomezCarreraetal2024Pop.xlsx, sheet("DataF10a_h", modify) cell(B5) keepcellfmt



**# Population growth decompositions in thousands

use "$work_data/un_fert_mort_migr_region.dta",clear
format netmigrants change_in_poptot  netmortality  %13.0g
drop change_in_poptot
g change_in_poptot =netmigrants+netmortality  
format netmigrants change_in_poptot  netmortality  %13.0g
g new_poptot2=L.new_poptot+change_in_poptot
format new_poptot2 %13.0g

foreach var in change_in_poptot netmigrants	netmortality{
	replace `var'=`var'/1000
}
keep year region change_in_poptot netmigrants  netmortality  
format netmigrants /*change_in_poptot change_in_poptot2*/ netmortality  %13.0g
order year change_in_poptot netmortality netmigrants 
reshape wide change_in_poptot netmortality netmigrants  , i(year) j(region) string

keep year change_in_poptot* netmortality* netmigrants*
export excel using $outputs/GomezCarreraetal2024Pop.xlsx, sheet("DataF10i", modify) cell(B5) keepcellfmt



				**# Decomposition separating oil countries

				use "$outputs/un_1950_2100_fert_mort_migr_216.dta",clear

				 gen region2=""
					foreach c of global EURO {
						replace region2="EURO" if country=="`c'"
						}
					foreach c of global NAOC {
						replace region2="NAOC" if country=="`c'"
						}
					foreach c of global LATA {
						replace region2="LATA" if country=="`c'"
						}
					foreach c of global MENA {
						replace region2="MENA" if country=="`c'"
						}
					foreach c of global SSAF {
						replace region2="SSAF" if country=="`c'"
						}
					foreach c of global RUCA {
						replace region2="RUCA" if country=="`c'"
						}
					foreach c of global EASA {
						replace region2="EASA" if country=="`c'"
						}	
					foreach c of global SSEA {
						replace region2="SSEA" if country=="`c'"
						}		
					ren region2 region
					
					gen region2=""
						foreach c of global oil {
						replace region2="Oil" if country=="`c'"
						}
					replace region2="Nonoil" if region=="MENA" & region2==""	
					replace region2=region if region2==""

				collapse (sum)	births deaths netmigrants poptot netmortality, by(year region2)

				*Panel format	
				encode region2,g(id)
				xtset id year

				*Calculate 
				g new_poptot=L.poptot+netmortality+netmigrants
				format new_poptot %13.0g
				replace new_poptot=poptot if year==1950 & new_poptot==.




				g change_in_poptot=new_poptot-L.new_poptot
				g residual=poptot-new_poptot
				order region2 year new_poptot change_in_poptot netmortality netmigrants id
				keep region2 year new_poptot change_in_poptot netmortality netmigrants id


					save "$work_data/un_fert_mort_migr_region_oil.dta",replace

					g growth_poptot=change_in_poptot/L.new_poptot
				g growth_netfertility=netmortality/L.new_poptot
				g growth_netmigrants=netmigrants/L.new_poptot
				format change_in_poptot netmortality netmigrants %13.0g
				drop id
				reshape wide new_poptot change_in_poptot netmortality netmigrants  growth*, i(year) j(region) string
				keep year growth*
				export excel using $outputs/GomezCarreraetal2024Pop.xlsx, sheet("DataF10d", modify) cell(B5) keepcellfmt



				**# Population growth decompositions in thousands oil

				use "$work_data/un_fert_mort_migr_region_oil.dta",clear
				format netmigrants change_in_poptot  netmortality  %13.0g
				drop change_in_poptot
				g change_in_poptot =netmigrants+netmortality  
				format netmigrants change_in_poptot  netmortality  %13.0g
				g new_poptot2=L.new_poptot+change_in_poptot
				format new_poptot2 %13.0g

				foreach var in change_in_poptot netmigrants	netmortality{
					replace `var'=`var'/1000
				}
				keep year region2 change_in_poptot netmigrants  netmortality  
				format netmigrants /*change_in_poptot change_in_poptot2*/ netmortality  %13.0g
				order year change_in_poptot netmortality netmigrants 
				reshape wide change_in_poptot netmortality netmigrants  , i(year) j(region2) string


				keep year change_in_poptot* netmortality* netmigrants*
				export excel using $outputs/GomezCarreraetal2024Pop.xlsx, sheet("DataF10i_oil", modify) cell(B5) keepcellfmt




**# Long period growths and decompositions
*1950-2100
use "$work_data/un_fert_mort_migr_region.dta",clear
keep if inlist(year,1950,1950) 
keep region new_poptot 
ren new_poptot poptot1950
save "$work_data/temporary.dta",replace
use "$work_data/un_fert_mort_migr_region.dta",clear
keep if inrange(year,1950,2100)
collapse (sum)   netmortality netmigrants, by(region)
g change_in_poptot=netmigrants	+netmortality
format  change_in_poptot netmortality netmigrants  %13.0g
merge 1:1 region using "$work_data/temporary.dta"
drop _merge
cap erase "$work_data/temporary.dta"

foreach var in netmortality netmigrants change_in_poptot {
	replace `var'=`var'/poptot1950
	ren `var' `var'1950_2100
	}
drop poptot1950
ren change_in_poptot* pop*
ren netmortality* fert*
ren netmigrants* migr*
order region pop
save "$work_data/temporary_1950_2100.dta",replace

*1950-1990
use "$work_data/un_fert_mort_migr_region.dta",clear
keep if inlist(year,1950,1950) 
keep region new_poptot 
ren new_poptot poptot1950
save "$work_data/temporary.dta",replace
use "$work_data/un_fert_mort_migr_region.dta",clear
keep if inrange(year,1950,1990)
collapse (sum)   netmortality netmigrants, by(region)
g change_in_poptot=netmigrants	+netmortality
format  change_in_poptot netmortality netmigrants  %13.0g
merge 1:1 region using "$work_data/temporary.dta"
drop _merge
erase "$work_data/temporary.dta"

foreach var in netmortality netmigrants change_in_poptot {
	replace `var'=`var'/poptot1950
	ren `var' `var'1950_1990
	}
drop poptot1950
ren change_in_poptot* pop*
ren netmortality* fert*
ren netmigrants* migr*
order region pop
save "$work_data/temporary_1950_1990.dta",replace


*1990-2025
use "$work_data/un_fert_mort_migr_region.dta",clear
keep if inlist(year,1990,1990) 
keep region new_poptot 
ren new_poptot poptot1990
save "$work_data/temporary.dta",replace
use "$work_data/un_fert_mort_migr_region.dta",clear
keep if inrange(year,1990,2025)
collapse (sum)   netmortality netmigrants, by(region)
g change_in_poptot=netmigrants	+netmortality
format  change_in_poptot netmortality netmigrants  %13.0g
merge 1:1 region using "$work_data/temporary.dta"
drop _merge
erase "$work_data/temporary.dta"

foreach var in netmortality netmigrants change_in_poptot {
	replace `var'=`var'/poptot1990
	ren `var' `var'1990_2025
	}
drop poptot1990
ren change_in_poptot* pop*
ren netmortality* fert*
ren netmigrants* migr*
order region pop
save "$work_data/temporary_1990_2025.dta",replace


*2025-2060
use "$work_data/un_fert_mort_migr_region.dta",clear
keep if inlist(year,2025,2025) 
keep region new_poptot 
ren new_poptot poptot2025
save "$work_data/temporary.dta",replace
use "$work_data/un_fert_mort_migr_region.dta",clear
keep if inrange(year,2025,2060)
collapse (sum)   netmortality netmigrants, by(region)
g change_in_poptot=netmigrants	+netmortality
format  change_in_poptot netmortality netmigrants  %13.0g
merge 1:1 region using "$work_data/temporary.dta"
drop _merge
erase "$work_data/temporary.dta"
foreach var in netmortality netmigrants change_in_poptot {
	replace `var'=`var'/poptot2025
	ren `var' `var'2025_2060
	}
drop poptot2025
ren change_in_poptot* pop*
ren netmortality* fert*
ren netmigrants* migr*
order region pop
save "$work_data/temporary_2025_2060.dta",replace


*2060-2100
use "$work_data/un_fert_mort_migr_region.dta",clear
keep if inlist(year,2060,2060) 
keep region new_poptot 
ren new_poptot poptot2060
save "$work_data/temporary.dta",replace
use "$work_data/un_fert_mort_migr_region.dta",clear
keep if inrange(year,2060,2100)
collapse (sum)   netmortality netmigrants, by(region)
g change_in_poptot=netmigrants	+netmortality
format  change_in_poptot netmortality netmigrants  %13.0g
merge 1:1 region using "$work_data/temporary.dta"
drop _merge
erase "$work_data/temporary.dta"

foreach var in netmortality netmigrants change_in_poptot {
	replace `var'=`var'/poptot2060
	ren `var' `var'2060_2100
	}
drop poptot2060
ren change_in_poptot* pop*
ren netmortality* fert*
ren netmigrants* migr*
order region pop
save "$work_data/temporary_2060_2100.dta",replace






use "$work_data/temporary_1950_1990.dta",clear
merge 1:1 region using "$work_data/temporary_1990_2025.dta"
drop _merge
merge 1:1 region using "$work_data/temporary_2025_2060.dta"
drop _merge
merge 1:1 region using "$work_data/temporary_2060_2100.dta"
drop _merge

	replace region="East Asia" if 					region=="EASA"
	replace region="Europe" if 						region=="EURO"
	replace region="Latin America" if 				region=="LATA"
	replace region="Middle East/ North Africa " if 	region=="MENA"
	replace region="North America/ Oceania " if 		region=="NAOC"
	replace region="Russia Central Asia" if 		region=="RUCA"
	replace region="South/ South-East Asia" if 		region=="SSEA"
	replace region="Sub Saharan Africa" if 			region=="SSAF"
	replace region="World " if 						region=="WO"

export excel using $outputs/GomezCarreraetal2024Pop.xlsx, sheet("T10b", modify) cell(B5) keepcellfmt



