

/********Stata code used for the TN:Extending WID Population Series:
Projections 2024-2100 & Age/Gender Breakdowns*********/

/****Creates tables for populations for 57 core territories 1950-2100**/


**# Tables for countries 1800-2100



	use "$work_data\pop_1800_2100_57extendedterritories.dta",clear
	keep year country pop999i
	ren pop999i poptot
		replace poptot=poptot/1000000
	reshape wide poptot, i(year) j(country) string

	drop poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA
	
	
drop poptotOC_E poptotOB_E poptotOE_E poptotOI_E poptotOJ_E
	g poptotOC_E=poptotOC-poptotNL-poptotNO-poptotDK
	g poptotOB_E=poptotOB-poptotKR-poptotTW
	g poptotOE_E=poptotOE-poptotIR-poptotMA-poptotSA-poptotAE		
	g poptotOI_E=poptotOI-poptotBD-poptotMM-poptotPK-poptotPH-poptotTH-poptotVN
	g poptotOJ_E=poptotOJ-poptotCD-poptotET-poptotKE-poptotCI-poptotML-poptotNE-poptotNG-poptotRW-poptotSD		
	
	gen poptotEURO=poptotDE+poptotFR+poptotGB+poptotIT+poptotES+poptotSE+poptotOC_E+poptotNL+poptotNO+poptotDK+poptotQM
	gen poptotNAOC=poptotUS+poptotCA+poptotAU+poptotNZ+poptotOH	
	gen poptotLATA=poptotAR+poptotBR+poptotCL+poptotCO+poptotMX+poptotOD
	gen poptotMENA=poptotTR+poptotEG+poptotDZ+poptotOE_E+poptotIR+poptotMA+poptotSA+poptotAE
	gen poptotSSAF=poptotZA+poptotOJ_E+poptotCD+poptotET+poptotKE+poptotCI+poptotML+poptotNE+poptotNG+poptotRW+poptotSD
	gen poptotRUCA=poptotRU+poptotOA
	gen poptotEASA=poptotCN+poptotJP+poptotOB_E+poptotKR+poptotTW
	gen poptotSSEA=poptotIN+poptotID+poptotOI_E+poptotBD+poptotMM+poptotPK+poptotPH+poptotTH+poptotVN	

	g poptotWO=poptotEURO+poptotNAOC+poptotLATA+poptotMENA+poptotSSAF+poptotRUCA+poptotEASA+poptotSSEA	

	*Compute
	foreach region in DE FR GB IT ES SE NL	NO	DK	 OC_E QM US CA AU NZ OH AR BR CL CO MX OD TR EG DZ IR	MA	SA	AE OE_E ZA CD	ET	KE	CI	ML	NE	NG	RW	SD OJ_E RU OA CN JP KR TW OB_E IN ID BD	MM	PK	PH	TH	VN OI_E WO{
		preserve
		keep year poptot`region'
		sum poptot`region' if year==2100
		loc poptot2100=r(mean)
		sum poptot`region' if year==2060
		loc poptot2060=r(mean)
		sum poptot`region' if year==2025
		loc poptot2025=r(mean)
		sum poptot`region' if year==1950
		loc poptot1950=r(mean)
		sum poptot`region' if year==1800
		loc poptot1800=r(mean)	
		
		loc ratio_2025_2100=`poptot2100'/`poptot2025'
		loc ratio_2060_2100=`poptot2100'/`poptot2060'
		loc ratio_2025_2060=`poptot2060'/`poptot2025'
		loc ratio_1800_1950=`poptot1950'/`poptot1800'
		loc ratio_1950_2025=`poptot2025'/`poptot1950'	
		loc ratio_1800_2025=`poptot2025'/`poptot1800'	
		loc ratio_1800_2100=`poptot2100'/`poptot1800'	
		
		tsset year
		g annual_growth=100*(poptot`region'/L.poptot`region'-1)

		sum annual_growth if inrange(year,2060,2100)
		loc growth2060_2100=r(mean)
		sum annual_growth if inrange(year,2025,2060)
		loc growth2025_2060=r(mean)
		sum annual_growth if inrange(year,2025,2100)
		loc growth2025_2100=r(mean)	
		sum annual_growth if inrange(year,1800,1950)
		loc growth1800_1950=r(mean)
		sum annual_growth if inrange(year,1950,2025)
		loc growth1950_2025=r(mean)
		sum annual_growth if inrange(year,1800,2025)
		loc growth1800_2025=r(mean)	
		sum annual_growth if inrange(year,1800,2100)
		loc growth1800_2100=r(mean)		
		

		g region="`region'"
		g poptotpc1800=`poptot1800'
		g poptotpc1950=`poptot1950'
		g poptotpc2025=`poptot2025'
		g poptotpc2060=`poptot2060'
		g poptotpc2100=`poptot2100'
		
		g ratio_1800_2025=`ratio_1800_2025'
		g ratio_2025_2100=`ratio_2025_2100'	
		
		g growth1800_2100=`growth1800_2100'
		g growth2060_2100=`growth2060_2100'	
		g growth2025_2060=`growth2025_2060'
		g growth1800_2025=`growth1800_2025'
		g growth1800_1950=`growth1800_1950'	
		g growth1950_2025=`growth1950_2025'		
		g growth2025_2100=`growth2025_2100'
		

		keep region 	poptotpc1800 poptotpc1950 poptotpc2025 poptotpc2060 poptotpc2100 ///
		ratio_1800_2025  ratio_2025_2100 	///
		growth1800_2100 growth2025_2100  growth1800_1950 growth1950_2025 growth2025_2060 growth2060_2100 
		order region 	poptotpc1800 poptotpc1950 poptotpc2025 poptotpc2060 poptotpc2100 ///
		ratio_1800_2025  ratio_2025_2100 	///
		growth1800_2100 growth2025_2100  growth1800_1950 growth1950_2025 growth2025_2060 growth2060_2100 	
		duplicates drop
		
		save "$work_data\temp_`region'.dta", replace
		restore
	}

	*Append in exporting format
	use "$work_data\temp_DE.dta", clear
	foreach var in  FR GB IT ES SE NL	NO	DK	 OC_E QM US CA AU NZ OH AR BR CL CO MX OD TR EG DZ IR	MA	SA	AE OE_E ZA CD	ET	KE	CI	ML	NE	NG	RW	SD OJ_E RU OA CN JP KR TW OB_E IN ID BD	MM	PK	PH	TH	VN OI_E WO{
	append using "$work_data\temp_`var'.dta" 	
	}

	*Export
	// drop region
	replace region="Germany" if region=="DE"
	replace region="France" if region=="FR"
	replace region="United Kingdom" if region=="GB"
	replace region="Italy" if region=="IT"
	replace region="Spain" if region=="ES"
	replace region="Sweden" if region=="SE"
		replace region="Netherlands" if region=="NL"
		replace region="Norway" if region=="NO"
		replace region="Denmark" if region=="DK"
	replace region="Other Western Europe" if region=="OC_E"
	replace region="Eastern Europe" if region=="QM"
	replace region="USA" if region=="US"
	replace region="Canada" if region=="CA"
	replace region="Australia" if region=="AU"
	replace region="New Zealand" if region=="NZ"
	replace region="Other NAOC" if region=="OH"
	replace region="Argentina" if region=="AR"
	replace region="Brazil" if region=="BR"
	replace region="Chile" if region=="CL"
	replace region="Colombia" if region=="CO"
	replace region="Mexico" if region=="MX"
	replace region="Other Latin America" if region=="OD"
	replace region="Turkey" if region=="TR"
	replace region="Egypt" if region=="EG"
	replace region="Algeria" if region=="DZ"
		replace region="Iran" if region=="IR"
		replace region="Morocco" if region=="MA"
		replace region="Saudi Arabia" if region=="SA"
		replace region="United Arab Emirates" if region=="AE"		
	replace region="Other MENA" if region=="OE_E"
	replace region="South Africa" if region=="ZA"
		replace region="DR Congo" if region=="CD"	
		replace region="Ethiopia" if region=="ET"	
		replace region="Kenya" if region=="KE"	
		replace region="Ivory Coast" if region=="CI"	
		replace region="Mali" if region=="ML"	
		replace region="Niger" if region=="NE"	
		replace region="Nigeria" if region=="NG"	
		replace region="Rwanda" if region=="RW"	
		replace region="Sudan" if region=="SD"			
	replace region="Other SSAF" if region=="OJ_E"
	replace region="Russian Federation" if region=="RU"
	replace region="Other RUCA" if region=="OA"
	replace region="China" if region=="CN"
	replace region="Japan" if region=="JP"
		replace region="South Korea" if region=="KR"
		replace region="Taiwan" if region=="TW"	
	replace region="Other East Asia" if region=="OB_E"
	replace region="India" if region=="IN"
	replace region="Indonesia" if region=="ID"
		replace region="Bangladesh" if region=="BD"
		replace region="Myanmar" if region=="MM"	
		replace region="Pakistan" if region=="PK"
		replace region="Philipinnes" if region=="PH"
		replace region="Thailand" if region=="TH"
		replace region="Vietnam" if region=="VN"	
	replace region="Other SSEA" if region=="OI_E"
	replace region="World " if 						region=="WO"
	export excel using $outputs/GomezCarreraetal2024Pop.xlsx, sheet("T1e", modify) cell(B5) keepcellfmt

	*Erase temporary files
	foreach region in DE FR GB IT ES SE NL	NO	DK	 OC_E QM US CA AU NZ OH AR BR CL CO MX OD TR EG DZ IR	MA	SA	AE OE_E ZA CD	ET	KE	CI	ML	NE	NG	RW	SD OJ_E RU OA CN JP KR TW OB_E IN ID BD	MM	PK	PH	TH	VN OI_E WO{
		cap erase "$work_data\temp_`region'.dta"
		}		
		

