/********Stata code used for the TN:Extending WID Population Series:
Projections 2024-2100 & Age/Gender Breakdowns*********/

/****Creates most figures and tables in the Excel file**/

**# Figures and Tables for regions 1800-2100

loc c=1
foreach var in pop999i /*pop991i*/ pop992i pop15_64i pop0_14i pop65i 	pop999f  /*pop991f pop992f*/   pop15_64f pop0_14f pop65f{

	**# Figures regions
	use "$outputs\pop_1800_2100_33coreterritories.dta",clear
	keep year country `var'
	ren `var' poptot
	replace poptot=poptot/1000000
	reshape wide poptot, i(year) j(country) string

// 	drop poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA
	gen poptotEURO=poptotDE+poptotFR+poptotGB+poptotIT+poptotES+poptotSE+poptotOC+poptotQM
	gen poptotNAOC=poptotUS+poptotCA+poptotAU+poptotNZ+poptotOH
	gen poptotLATA=poptotAR+poptotBR+poptotCL+poptotCO+poptotMX+poptotOD
	gen poptotMENA=poptotTR+poptotEG+poptotDZ+poptotOE
	gen poptotRUCA=poptotRU+poptotOA
	gen poptotEASA=poptotCN+poptotJP+poptotOB

	gen poptotSSAF=poptotESAF+poptotWCAF
	gen poptotSSEA=poptotSEAS +poptotSAS

	g poptotWO=poptotEURO+poptotNAOC+poptotLATA+poptotMENA+poptotSSAF+poptotRUCA+poptotEASA+poptotSSEA

	keep year poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC poptotQM poptotUS poptotCA poptotAU poptotNZ poptotOH poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD poptotTR poptotEG poptotDZ poptotOE poptotZA poptotOJ poptotRU poptotOA poptotCN poptotJP poptotOB poptotIN poptotID poptotOI poptotESAF poptotWCAF poptotSEAS poptotSAS
	order year poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC poptotQM poptotUS poptotCA poptotAU poptotNZ poptotOH poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD poptotTR poptotEG poptotDZ poptotOE poptotZA poptotOJ poptotRU poptotOA poptotCN poptotJP poptotOB poptotIN poptotID poptotOI poptotESAF poptotWCAF poptotSEAS poptotSAS
	sort year
	preserve
	drop year
	export excel using $outputs/GomezCarreraetal2024Pop.xlsx, sheet("DataF`c'", modify) cell(B5) keepcellfmt
	restore



	**# Tables regions

	*Import data
	keep year poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA

	*Compute
	foreach region in EURO NAOC LATA MENA SSAF RUCA EASA  SSEA WO{
		preserve
		keep year poptot`region'
		sum poptot`region' if year==2100
		loc poptot2100=r(mean)
		sum poptot`region' if year==2060
		loc poptot2060=r(mean)
		sum poptot`region' if year==2025
		loc poptot2025=r(mean)
		sum poptot`region' if year==1950
		loc poptot1950=r(mean)
		sum poptot`region' if year==1800
		loc poptot1800=r(mean)	
		
		loc ratio_2025_2100=`poptot2100'/`poptot2025'
		loc ratio_2060_2100=`poptot2100'/`poptot2060'
		loc ratio_2025_2060=`poptot2060'/`poptot2025'
		loc ratio_1800_1950=`poptot1950'/`poptot1800'
		loc ratio_1950_2025=`poptot2025'/`poptot1950'	
		loc ratio_1800_2025=`poptot2025'/`poptot1800'	
		loc ratio_1800_2100=`poptot2100'/`poptot1800'	
		
		tsset year
		g annual_growth=100*(poptot`region'/L.poptot`region'-1)

		sum annual_growth if inrange(year,2060,2100)
		loc growth2060_2100=r(mean)
		sum annual_growth if inrange(year,2025,2060)
		loc growth2025_2060=r(mean)
		sum annual_growth if inrange(year,2025,2100)
		loc growth2025_2100=r(mean)	
		sum annual_growth if inrange(year,1800,1950)
		loc growth1800_1950=r(mean)
		sum annual_growth if inrange(year,1950,2025)
		loc growth1950_2025=r(mean)
		sum annual_growth if inrange(year,1800,2025)
		loc growth1800_2025=r(mean)	
		sum annual_growth if inrange(year,1800,2100)
		loc growth1800_2100=r(mean)		
		

		g region="`region'"
		g poptotpc1800=`poptot1800'
		g poptotpc1950=`poptot1950'
		g poptotpc2025=`poptot2025'
		g poptotpc2060=`poptot2060'
		g poptotpc2100=`poptot2100'
		
		g ratio_1800_2025=`ratio_1800_2025'
		g ratio_2025_2100=`ratio_2025_2100'	
		
		g growth1800_2100=`growth1800_2100'
		g growth2060_2100=`growth2060_2100'	
		g growth2025_2060=`growth2025_2060'
		g growth1800_2025=`growth1800_2025'
		g growth1800_1950=`growth1800_1950'	
		g growth1950_2025=`growth1950_2025'		
		g growth2025_2100=`growth2025_2100'
		

		keep region 	poptotpc1800 poptotpc1950 poptotpc2025 poptotpc2060 poptotpc2100 ///
		ratio_1800_2025  ratio_2025_2100 	///
		growth1800_2100 growth2025_2100  growth1800_1950 growth1950_2025 growth2025_2060 growth2060_2100 
		order region 	poptotpc1800 poptotpc1950 poptotpc2025 poptotpc2060 poptotpc2100 ///
		ratio_1800_2025  ratio_2025_2100 	///
		growth1800_2100 growth2025_2100  growth1800_1950 growth1950_2025 growth2025_2060 growth2060_2100 	
		duplicates drop
		
		save "$work_data\temp_`region'.dta", replace
		restore
	}

	*Append in exporting format
	use "$work_data\temp_EASA.dta", clear
	append using "$work_data\temp_EURO.dta" 
	append using "$work_data\temp_LATA.dta" 
	append using "$work_data\temp_MENA.dta"
	append using "$work_data\temp_NAOC.dta"
	append using "$work_data\temp_RUCA.dta"
	append using "$work_data\temp_SSEA.dta"
	append using "$work_data\temp_SSAF.dta"
	append using "$work_data\temp_WO.dta"

	*Export
	// drop region
	replace region="East Asia" if 					region=="EASA"
	replace region="Europe" if 						region=="EURO"
	replace region="Latin America" if 				region=="LATA"
	replace region="Middle East/ North Africa " if 	region=="MENA"
	replace region="North America/ Oceania " if 		region=="NAOC"
	replace region="Russia Central Asia" if 		region=="RUCA"
	replace region="South/ South-East Asia" if 		region=="SSEA"
	replace region="Sub Saharan Africa" if 			region=="SSAF"
	replace region="World " if 						region=="WO"
	export excel using $outputs/GomezCarreraetal2024Pop.xlsx, sheet("T`c'", modify) cell(B5) keepcellfmt

	*Erase temporary files
	foreach region in EURO NAOC LATA MENA SSAF RUCA EASA  SSEA WO{
		cap erase "$work_data\temp_`region'.dta"
		}		
		
	loc c=`c'+1	
}










**# Tables for countries 1800-2100

loc c=1
foreach var in pop999i /*pop991i*/ pop992i pop15_64i pop0_14i pop65i 	pop999f  /*pop991f pop992f*/   pop15_64f pop0_14f pop65f{


	use "$outputs\pop_1800_2100_33coreterritories.dta",clear
	keep year country `var'
	ren `var' poptot
		replace poptot=poptot/1000000
	reshape wide poptot, i(year) j(country) string

// 	drop poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA
	gen poptotEURO=poptotDE+poptotFR+poptotGB+poptotIT+poptotES+poptotSE+poptotOC+poptotQM
	gen poptotNAOC=poptotUS+poptotCA+poptotAU+poptotNZ+poptotOH
	gen poptotLATA=poptotAR+poptotBR+poptotCL+poptotCO+poptotMX+poptotOD
	gen poptotMENA=poptotTR+poptotEG+poptotDZ+poptotOE
	gen poptotRUCA=poptotRU+poptotOA
	gen poptotEASA=poptotCN+poptotJP+poptotOB

	gen poptotSSAF=poptotESAF+poptotWCAF
	gen poptotSSEA=poptotSEAS +poptotSAS

	g poptotWO=poptotEURO+poptotNAOC+poptotLATA+poptotMENA+poptotSSAF+poptotRUCA+poptotEASA+poptotSSEA

	keep year poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC poptotQM poptotUS poptotCA poptotAU poptotNZ poptotOH poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD poptotTR poptotEG poptotDZ poptotOE poptotZA poptotOJ poptotRU poptotOA poptotCN poptotJP poptotOB poptotIN poptotID poptotOI poptotESAF poptotWCAF poptotSEAS poptotSAS
	order year poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC poptotQM poptotUS poptotCA poptotAU poptotNZ poptotOH poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD poptotTR poptotEG poptotDZ poptotOE poptotZA poptotOJ poptotRU poptotOA poptotCN poptotJP poptotOB poptotIN poptotID poptotOI poptotESAF poptotWCAF poptotSEAS poptotSAS
	sort year


	keep year poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC poptotQM poptotUS poptotCA poptotAU poptotNZ poptotOH poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD poptotTR poptotEG poptotDZ poptotOE poptotZA poptotOJ poptotRU poptotOA poptotCN poptotJP poptotOB poptotIN poptotID poptotOI poptotWO

	*Compute
	foreach region in DE FR GB IT ES SE OC QM US CA AU NZ OH AR BR CL CO MX OD TR EG DZ OE ZA OJ RU OA CN JP OB IN ID OI WO{
		preserve
		keep year poptot`region'
		sum poptot`region' if year==2100
		loc poptot2100=r(mean)
		sum poptot`region' if year==2060
		loc poptot2060=r(mean)
		sum poptot`region' if year==2025
		loc poptot2025=r(mean)
		sum poptot`region' if year==1950
		loc poptot1950=r(mean)
		sum poptot`region' if year==1800
		loc poptot1800=r(mean)	
		
		loc ratio_2025_2100=`poptot2100'/`poptot2025'
		loc ratio_2060_2100=`poptot2100'/`poptot2060'
		loc ratio_2025_2060=`poptot2060'/`poptot2025'
		loc ratio_1800_1950=`poptot1950'/`poptot1800'
		loc ratio_1950_2025=`poptot2025'/`poptot1950'	
		loc ratio_1800_2025=`poptot2025'/`poptot1800'	
		loc ratio_1800_2100=`poptot2100'/`poptot1800'	
		
		tsset year
		g annual_growth=100*(poptot`region'/L.poptot`region'-1)

		sum annual_growth if inrange(year,2060,2100)
		loc growth2060_2100=r(mean)
		sum annual_growth if inrange(year,2025,2060)
		loc growth2025_2060=r(mean)
		sum annual_growth if inrange(year,2025,2100)
		loc growth2025_2100=r(mean)	
		sum annual_growth if inrange(year,1800,1950)
		loc growth1800_1950=r(mean)
		sum annual_growth if inrange(year,1950,2025)
		loc growth1950_2025=r(mean)
		sum annual_growth if inrange(year,1800,2025)
		loc growth1800_2025=r(mean)	
		sum annual_growth if inrange(year,1800,2100)
		loc growth1800_2100=r(mean)		
		

		g region="`region'"
		g poptotpc1800=`poptot1800'
		g poptotpc1950=`poptot1950'
		g poptotpc2025=`poptot2025'
		g poptotpc2060=`poptot2060'
		g poptotpc2100=`poptot2100'
		
		g ratio_1800_2025=`ratio_1800_2025'
		g ratio_2025_2100=`ratio_2025_2100'	
		
		g growth1800_2100=`growth1800_2100'
		g growth2060_2100=`growth2060_2100'	
		g growth2025_2060=`growth2025_2060'
		g growth1800_2025=`growth1800_2025'
		g growth1800_1950=`growth1800_1950'	
		g growth1950_2025=`growth1950_2025'		
		g growth2025_2100=`growth2025_2100'
		

		keep region 	poptotpc1800 poptotpc1950 poptotpc2025 poptotpc2060 poptotpc2100 ///
		ratio_1800_2025  ratio_2025_2100 	///
		growth1800_2100 growth2025_2100  growth1800_1950 growth1950_2025 growth2025_2060 growth2060_2100 
		order region 	poptotpc1800 poptotpc1950 poptotpc2025 poptotpc2060 poptotpc2100 ///
		ratio_1800_2025  ratio_2025_2100 	///
		growth1800_2100 growth2025_2100  growth1800_1950 growth1950_2025 growth2025_2060 growth2060_2100 	
		duplicates drop
		
		save "$work_data\temp_`region'.dta", replace
		restore
	}

	*Append in exporting format
	use "$work_data\temp_DE.dta", clear
	foreach var in FR GB IT ES SE OC QM US CA AU NZ OH AR BR CL CO MX OD TR EG DZ OE ZA OJ RU OA CN JP OB IN ID OI WO{
	append using "$work_data\temp_`var'.dta" 	
	}



	*Export
	// drop region
	replace region="Germany" if region=="DE"
	replace region="France" if region=="FR"
	replace region="United Kingdom" if region=="GB"
	replace region="Italy" if region=="IT"
	replace region="Spain" if region=="ES"
	replace region="Sweden" if region=="SE"
	replace region="Other Western Europe" if region=="OC"
	replace region="Eastern Europe" if region=="QM"
	replace region="USA" if region=="US"
	replace region="Canada" if region=="CA"
	replace region="Australia" if region=="AU"
	replace region="New Zealand" if region=="NZ"
	replace region="Other North America and Oceania" if region=="OH"
	replace region="Argentina" if region=="AR"
	replace region="Brazil" if region=="BR"
	replace region="Chile" if region=="CL"
	replace region="Colombia" if region=="CO"
	replace region="Mexico" if region=="MX"
	replace region="Other Latin America" if region=="OD"
	replace region="Turkey" if region=="TR"
	replace region="Egypt" if region=="EG"
	replace region="Algeria" if region=="DZ"
	replace region="Other MENA" if region=="OE"
	replace region="South Africa" if region=="ZA"
	replace region="Other Sub-Saharan Africa" if region=="OJ"
	replace region="Russian Federation" if region=="RU"
	replace region="Other Russia and Central Asia" if region=="OA"
	replace region="China" if region=="CN"
	replace region="Japan" if region=="JP"
	replace region="Other East Asia" if region=="OB"
	replace region="India" if region=="IN"
	replace region="Indonesia" if region=="ID"
	replace region="Other South & South-East Asia" if region=="OI"

	replace region="World " if 						region=="WO"
	export excel using $outputs/GomezCarreraetal2024Pop.xlsx, sheet("T`c'b", modify) cell(B5) keepcellfmt

	*Erase temporary files
	foreach region in DE FR GB IT ES SE OC QM US CA AU NZ OH AR BR CL CO MX OD TR EG DZ OE ZA OJ RU OA CN JP OB IN ID OI WO{
		cap erase "$work_data\temp_`region'.dta"
		}		
		
loc c=`c'+1	
}





