/********Stata code used for the TN:Extending WID Population Series:
Projections 2024-2100 & Age/Gender Breakdowns*********/

/****Creates graphs for UN-s different population projections per region**/


**# Population scenarios

gl sheets " "Medium variant" "High variant" "Low variant" "Constant-fertility" "Instant-replacement" "Instant-replacement zero migr" "Momentum" "Zero-migration"  "No change" "No fertility below age 18" "Accelerated ABR decline" "Accelarated ABR decline recup" "

// gl sheets " "Medium variant" "High variant" "
loc c=1
foreach sheet in  $sheets{
	

	**# Migration UN projections
import excel "$root\raw-data/WPP${year}_GEN_F01_DEMOGRAPHIC_INDICATORS_FULL.xlsx", ///
	cellrange(B17) firstrow case(lower) sheet("`sheet'") clear	

keep regionsubregioncountryorar notes iso2alphacode type parentcode netnumberofmigrantsthousand naturalchangebirthsminusdea  /*netmigrationrateper1000po*/ year



ren iso2alphacode iso
ren netnumberofmigrantsthousand value
ren naturalchangebirthsminusdea valor


// Kosovo
replace iso = "KS" if iso == "XK"
drop if missing(iso)
 
destring value, replace force
drop if value >= .
replace value = 1e3*value

destring valor, replace force
drop if valor >= .
replace valor = 1e3*valor

generate age = "all"
generate sex = "both"

tab year



// Some corrections for consistency with the macroeconomic data ------------- //

// For France, add Guiana and Polynesia
egen value2 = total(value) if inlist(iso, "FR", "GF", "GP", "MQ", "YT", "RE"), ///
	by(year age sex)
drop if inlist(iso, "GF", "GP", "MQ", "YT", "RE")
replace value = value2 if (iso == "FR")
drop value2


// Idem for Czechoslovakia
egen value2 = total(value) if inlist(iso, "CZ", "SK"), by(year age sex)
expand 2 if (iso == "CZ"), generate(newobs)
replace iso = "CS" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for Yugoslavia
egen value2 = total(value) if inlist(iso, "HR", "SI", "RS", "MK", "BA", "ME"), by(year age sex)
expand 2 if (iso == "RS"), generate(newobs)
replace iso = "YU" if newobs
replace value = value2 if newobs
drop value2 newobs

// Idem for USSR
generate inUSSR = 0
replace inUSSR = 1 if inlist(iso, "AM", "AZ", "BY", "EE", "GE", "KZ", "KG")
replace inUSSR = 1 if inlist(iso, "LV", "LT", "MD", "RU", "TJ")
replace inUSSR = 1 if inlist(iso, "TM", "UA", "UZ")
egen value2 = total(value) if inUSSR, by(year age sex)
expand 2 if (iso == "RU"), generate(newobs)
replace iso = "SU" if newobs
replace value = value2 if newobs
drop value2 newobs inUSSR



// For France, add Guiana and Polynesia
egen valor2 = total(valor) if inlist(iso, "FR", "GF", "GP", "MQ", "YT", "RE"), ///
	by(year age sex)
drop if inlist(iso, "GF", "GP", "MQ", "YT", "RE")
replace valor = valor2 if (iso == "FR")
drop valor2


// Idem for Czechoslovakia
egen valor2 = total(valor) if inlist(iso, "CZ", "SK"), by(year age sex)
expand 2 if (iso == "CZ"), generate(newobs)
replace iso = "CS" if newobs
replace valor = valor2 if newobs
drop valor2 newobs

// Idem for Yugoslavia
egen valor2 = total(valor) if inlist(iso, "HR", "SI", "RS", "MK", "BA", "ME"), by(year age sex)
expand 2 if (iso == "RS"), generate(newobs)
replace iso = "YU" if newobs
replace valor = valor2 if newobs
drop valor2 newobs

// Idem for USSR
generate inUSSR = 0
replace inUSSR = 1 if inlist(iso, "AM", "AZ", "BY", "EE", "GE", "KZ", "KG")
replace inUSSR = 1 if inlist(iso, "LV", "LT", "MD", "RU", "TJ")
replace inUSSR = 1 if inlist(iso, "TM", "UA", "UZ")
egen valor2 = total(valor) if inUSSR, by(year age sex)
expand 2 if (iso == "RU"), generate(newobs)
replace iso = "SU" if newobs
replace valor = valor2 if newobs
drop valor2 newobs inUSSR

ren iso country
gen corecountry=.
foreach c of global corecountries{
	replace corecountry=1 if country=="`c'"
}
keep if corecountry==1

keep year country value valor

g sheet="`sheet'"
	loc s sheet
			replace `s' = subinstr(`s', " ", "", .)
tab sheet			

g netmigrants_`c'=value
g natchange_`c'=valor
g sheet_`c'=sheet
drop sheet
keep country year sheet_ netmigrants_ natchange_
save "$work_data/netmigrants_2024_2100_`sheet'.dta",replace

}




use "$work_data/netmigrants_2024_2100_Medium variant.dta",clear
ren netmigrants_ migr_medium
ren natchange_ natchange_medium
keep country year migr* natchange*
save "$work_data/netmigrants_2024_2100_Medium variant.dta",replace

use "$work_data/netmigrants_2024_2100_High variant.dta",clear
ren netmigrants_ migr_high
ren natchange_ natchange_high
keep country year migr* natchange*
save "$work_data/netmigrants_2024_2100_High variant.dta",replace

use "$work_data/netmigrants_2024_2100_Low variant.dta",clear
ren netmigrants_ migr_low
ren natchange_ natchange_low
keep country year migr* natchange*
save "$work_data/netmigrants_2024_2100_Low variant.dta",replace

use "$work_data/netmigrants_2024_2100_Constant-fertility.dta",clear
ren netmigrants_ migr_const_fert
ren natchange_ natchange_const_fert
keep country year migr* natchange*
save "$work_data/netmigrants_2024_2100_Constant-fertility.dta",replace

use "$work_data/netmigrants_2024_2100_Instant-replacement.dta",clear
ren netmigrants_ migr_inst_repl
ren natchange_ natchange_inst_repl
keep country year migr* natchange*
save "$work_data/netmigrants_2024_2100_Instant-replacement.dta",replace

use "$work_data/netmigrants_2024_2100_Instant-replacement zero migr.dta",clear
ren netmigrants_ migr_inst_repl_zero
ren natchange_ natchange_inst_repl_zero
keep country year migr* natchange*
save "$work_data/netmigrants_2024_2100_Instant-replacement zero migr.dta",replace

use "$work_data/netmigrants_2024_2100_Momentum.dta",clear
ren netmigrants_ migr_momentum
ren natchange_ natchange_momentum
keep country year migr* natchange*
save "$work_data/netmigrants_2024_2100_Momentum.dta",replace

use "$work_data/netmigrants_2024_2100_Zero-migration.dta",clear
ren netmigrants_ migr_zero
ren natchange_ natchange_zero
keep country year migr* natchange*
save "$work_data/netmigrants_2024_2100_Zero-migration.dta",replace

use "$work_data/netmigrants_2024_2100_No change.dta",clear
ren netmigrants_ migr_nochange
ren natchange_ natchange_nochange
keep country year migr* natchange*
save "$work_data/netmigrants_2024_2100_No change.dta",replace

use "$work_data/netmigrants_2024_2100_No fertility below age 18.dta",clear
ren netmigrants_ migr_nofert18
ren natchange_ natchange_nofert18
keep country year migr* natchange*
save "$work_data/netmigrants_2024_2100_No fertility below age 18.dta",replace

use "$work_data/netmigrants_2024_2100_Accelerated ABR decline.dta",clear
ren netmigrants_ migr_accABR
ren natchange_ natchange_accABR
keep country year migr* natchange*
save "$work_data/netmigrants_2024_2100_Accelerated ABR decline.dta",replace

use "$work_data/netmigrants_2024_2100_Accelarated ABR decline recup.dta",clear
ren netmigrants_ migr_accABR_recup
ren natchange_ natchange_accABR_recup
keep country year migr* natchange*
save "$work_data/netmigrants_2024_2100_Accelarated ABR decline recup.dta",replace

gl sheets "  "High variant" "Low variant" "Constant-fertility" "Instant-replacement" "Instant-replacement zero migr" "Momentum" "Zero-migration"  "No change" "No fertility below age 18" "Accelerated ABR decline" "Accelarated ABR decline recup" "



use "$work_data/netmigrants_2024_2100_Medium variant.dta",clear
foreach sheet in  $sheets{
	merge 1:1 year country using "$work_data/netmigrants_2024_2100_`sheet'.dta"
	keep if _merge==3
	drop _merge
}

sort country year


gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region

collapse (sum)	migr* natchange* , by(year region)
sort  region year
preserve
keep if region=="EURO"
tsset year
tsline migr_medium migr_high migr_low migr_const_fert migr_inst_repl migr_inst_repl_zero migr_momentum migr_zero migr_nochange migr_nofert18 migr_accABR migr_accABR_recup, xlabel(2025(5)2100)

tsline natchange_medium natchange_high natchange_low natchange_const_fert natchange_inst_repl natchange_inst_repl_zero natchange_momentum natchange_zero natchange_nochange natchange_nofert18 natchange_accABR natchange_accABR_recup, xlabel(2025(5)2100)
restore

preserve
keep if region=="NAOC"
tsset year
tsline migr_medium migr_high migr_low migr_const_fert migr_inst_repl migr_inst_repl_zero migr_momentum migr_zero migr_nochange migr_nofert18 migr_accABR migr_accABR_recup

tsline natchange_medium natchange_high natchange_low natchange_const_fert natchange_inst_repl natchange_inst_repl_zero natchange_momentum natchange_zero natchange_nochange natchange_nofert18 natchange_accABR natchange_accABR_recup, xlabel(2025(5)2100)
restore

preserve
keep region year migr_medium
reshape wide migr_medium, i(year) j(region) string
tsset year
ren migr_medium* * 
	 foreach var of varlist _all {
	label var `var' ""
}
tsline EASA EURO LATA MENA NAOC RUCA SSAF SSEA, lcolor(red ebblue green gold magenta orange sienna purple black) lwidth(thick thick thick thick thick thick thick thick thick) legend(row(2)) yline(0) xla(2025(5)2100, angle(90))

export excel using $outputs/GomezCarreraetal2024Pop.xlsx, sheet("Data_F10c", modify) cell(B5) keepcellfmt
restore

foreach region in NAOC MENA EASA EURO LATA SSEA RUCA SSAF{
	preserve
	keep if region=="`region'"
	keep region year natchange*
	foreach var in natchange_medium natchange_high natchange_low natchange_const_fert natchange_inst_repl natchange_inst_repl_zero natchange_momentum natchange_zero natchange_nochange natchange_nofert18 natchange_accABR natchange_accABR_recup{
		replace `var'=`var'/1000000
	}
	tsset year
	ren natchange_* * 
		 foreach var of varlist _all {
		label var `var' ""
	}
	drop region
	export excel using $outputs/GomezCarreraetal2024Pop.xlsx, sheet("Data_F12_`region'", modify) cell(B5) keepcellfmt
	restore
}


