

use "$work_data\pop_1800_2100_57extendedterritories.dta",clear
 *Keep core countries and regions
gen extendedterritory=.
foreach c of global extendedterritories {
	replace extendedterritory=1 if country=="`c'"
	}
	
gen region=.
foreach c of global regions {
	replace region=1 if country=="`c'"
	}	
keep if extendedterritory==1 | region==1 | country=="WO"
drop region extend

local today = c(current_date)
label data "Poptot for 57 extended core territories 1800-2100, Dataset created on `today'"
save "$outputs\pop_1800_2100_57extendedterritories.dta",replace
describe


**# Share of the world population of the 44 extended territories
use "$outputs\pop_1800_2100_57extendedterritories.dta", clear
gen extendedterritory=.
foreach c of global extendedterritories {
	replace extendedterritory=1 if country=="`c'"
	}
keep if extendedterritory==1 |  country=="WO"
tab year
tab country
*Drop other regions
drop if inlist(country,"OA","OB_E","OC_E","OD","OE_E","OH","OI_E","OJ_E","QM")

replace extendedterritory=0 if country=="WO"
collapse (sum) pop999i, by(extendedterritory year)
replace pop999i=pop999i/1000000
reshape wide pop999i, i(year) j(extendedterritory)
tsset year
ren pop999i0 World
ren pop999i1 Extended 
	 foreach var of varlist _all {
	label var `var' ""
}
g Share=Extended/World
twoway (tsline Extended World , ytitle(Population (millions))) (tsline Share , yaxis(2) ytitle("Extended as % of World population", axis(2))), xlabel(1800(20)2100,angle(90))
graph export "$root\outputs\extended core territories share\\World.png",replace
keep Share year
ren Share World 
save "$work_data\share_57_World.dta",replace


**# Share of the region population of the 48 extended territories
foreach region in MENA SSEA SSAF EASA EURO LATA NAOC RUCA{
use "$outputs\pop_1800_2100_57extendedterritories.dta", clear
gen extendedterritory=.
foreach c of global extendedterritories {
	replace extendedterritory=1 if country=="`c'"
	}
gen region=.
foreach c of global regions {
	replace region=1 if country=="`c'"
	}	
keep if extendedterritory==1 | region==1 | country=="WO"
tab year
tab country
*Drop other regions
drop if inlist(country,"OA","OB_E","OC_E","OD","OE_E","OH","OI_E","OJ_E","QM")

*Generate Region variable
 gen region2=""
foreach c of global EURO {
	replace region2="EURO" if country=="`c'"
	}
foreach c of global NAOC {
	replace region2="NAOC" if country=="`c'"
	}
foreach c of global LATA {
	replace region2="LATA" if country=="`c'"
	}
foreach c of global MENA {
	replace region2="MENA" if country=="`c'"
	}
foreach c of global SSAF {
	replace region2="SSAF" if country=="`c'"
	}
foreach c of global RUCA {
	replace region2="RUCA" if country=="`c'"
	}
foreach c of global EASA {
	replace region2="EASA" if country=="`c'"
	}	
foreach c of global SSEA {
	replace region2="SSEA" if country=="`c'"
	}		


keep if region2=="`region'" | country=="`region'"
replace extendedterritory=0 if country=="`region'"
collapse (sum) pop999i, by(extendedterritory year)
replace pop999i=pop999i/1000000
reshape wide pop999i, i(year) j(extendedterritory)
tsset year
ren pop999i0 `region'
ren pop999i1 Extended 
	 foreach var of varlist _all {
	label var `var' ""
}
g Share=Extended/`region'
twoway (tsline Extended `region' , ytitle(Population (millions))) (tsline Share , yaxis(2) ytitle("Extended as % of `region' population", axis(2))), xlabel(1800(20)2100,angle(90))
graph export "$root\outputs\extended core territories share\\`region'.png",replace

keep Share year
ren Share `region'
save "$work_data\share_57_`region'.dta",replace
}


use "$work_data\share_57_World.dta",clear
foreach region in MENA SSEA SSAF EASA EURO LATA NAOC RUCA{
merge 1:1 year using "$work_data\share_57_`region'.dta"
drop _merge
}
tsset year
tsline EASA EURO LATA MENA NAOC RUCA SSAF SSEA World, legend(pos(6) row(2)) lcolor(red ebblue green gold magenta orange sienna purple black) lwidth(thick thick thick thick thick thick thick thick thick) ylabel(.4(.05)1) xlabel(1800(20)2100, angle(90)) ytitle(" % of region's population")

ren World WO
keep year WO EURO NAOC LATA MENA SSAF RUCA EASA SSEA 
order year WO EURO NAOC LATA MENA SSAF RUCA EASA SSEA 
	sort year
drop year
	export excel using $outputs/GomezCarreraetal2024Pop.xlsx, sheet("DataF1_d", modify) cell(B5) keepcellfmt




*Erase all temporary files
local datafiles: dir "$root\work-data\" files "*.dta"
foreach datafile of local datafiles {
        rm "`datafile'"
}