/********Stata code used for the TN:Extending WID Population Series:
Projections 2024-2100 & Age/Gender Breakdowns*********/
/****Import UN series.***/


gl year 	"2024"
gl pastyear "2022"

*Import data from https://population.un.org/wpp/
import excel "$root\raw-data/WPP${year}_GEN_F01_DEMOGRAPHIC_INDICATORS_COMPACT.xlsx", ///
	cellrange(B17) firstrow case(lower) clear	

keep regionsubregioncountryorar notes iso2alphacode type parentcode totalpopulationasof1july year

// Adding estimated year - Medium Variant - 2022 and 2023
preserve
		import excel "$root\raw-data/WPP${year}_GEN_F01_DEMOGRAPHIC_INDICATORS_COMPACT.xlsx", ///
			cellrange(B17) sheet("Medium variant") firstrow case(lower) clear		
	keep regionsubregioncountryorar notes iso2alphacode type parentcode totalpopulationasof1july year
	tempfile $year 
	save `$year'
	tab year
restore	

append using `$year'

// Identify countries
ren iso2alphacode iso
ren totalpopulationasof1july value
// Kosovo
replace iso = "KS" if iso == "XK"
drop if missing(iso)
 
destring value, replace force
drop if value >= .
replace value = 1e3*value

generate age = "all"
generate sex = "both"

tempfile unpop
save "`unpop'", replace

// Both sexes, age groups --------------------------------------------------- //
import excel "$root\raw-data/WPP${year}_POP_F02_1_POPULATION_5-YEAR_AGE_GROUPS_BOTH_SEXES.xlsx", ///
	cellrange(B17) firstrow case(lower) clear

// Correct column names
foreach v of varlist l-af {
	destring `v', replace ignore("…")

	local age: var label `v'
	local age = subinstr("`age'", "-", "_", 1)
	local age = subinstr("`age'", "+", "", 1)
	if ("`age'" == "") {
		drop `v'
	}
	else {
		rename `v' value`age'
	}
}

// Adding estimated year - Medium Variant - 2022 and 2023
preserve
import excel "$root\raw-data/WPP${year}_POP_F02_1_POPULATION_5-YEAR_AGE_GROUPS_BOTH_SEXES.xlsx", ///
			cellrange(B17) sheet("Medium variant") firstrow case(lower) clear
		// Correct column names
foreach v of varlist l-af {
		destring `v', replace ignore("…")

		local age: var label `v'
		local age = subinstr("`age'", "-", "_", 1)
		local age = subinstr("`age'", "+", "", 1)
		if ("`age'" == "") {
			drop `v'
		}
		else {
			rename `v' value`age'
		}
	}

// 	keep if year == $year | year == $pastyear
	
	tempfile age_$year
	save `age_$year'
restore	

append using `age_$year'

// Identify countries
ren iso2alphacode iso
// Kosovo
replace iso = "KS" if iso == "XK"
drop variant regionsubregioncountryorar notes
destring value*, replace force

// Calculate value for 80+ when we only have the detail
generate value80 = value80_84 + value85_89 + value90_94 + value95_99 + value100 

// Calculate other population categories
generate valuechildren = value0_4 + value5_9 + value10_14 + value15_19
generate valueadults = value20_24 + value25_29 + value30_34 + value35_39 + value40_44 + value45_49 + value50_54 + value55_59 + value60_64 + value65_69 + value70_74 + value75_79 + value80
generate value20_39 = value20_24 + value25_29 + value30_34 + value35_39
generate value40_59 = value40_44 + value45_49 + value50_54 + value55_59
generate value60 = value60_64 + value65_69 + value70_74 + value75_79 + value80
generate value20_64 = value20_24 + value25_29 + value30_34 + value35_39 + value40_44 + value45_49 + value50_54 + value55_59 + value60_64
generate value65 = value65_69 + value70_74 + value75_79 + value80

cap rename referencedateasof1july year
duplicates drop iso year, force
reshape long value, i(iso year) j(age) string
drop if value >= .
replace value = 1e3*value

generate sex = "both"
	
append using "`unpop'"
save "`unpop'", replace

// Men, age groups ---------------------------------------------------------- //


import excel "$root\raw-data/WPP${year}_POP_F02_2_POPULATION_5-YEAR_AGE_GROUPS_MALE.xlsx", ///
	cellrange(B17) firstrow case(lower) clear

// Correct column names
foreach v of varlist l-af {
	destring `v', replace ignore("…")

	local age: var label `v'
	local age = subinstr("`age'", "-", "_", 1)
	local age = subinstr("`age'", "+", "", 1)
	if ("`age'" == "") {
		drop `v'
	}
	else {
		rename `v' value`age'
	}
}

// Adding estimated year - Medium Variant - 2022 and 2023
preserve
import excel "$root\raw-data/WPP${year}_POP_F02_2_POPULATION_5-YEAR_AGE_GROUPS_MALE.xlsx", ///
		cellrange(B17) sheet("Medium variant") firstrow case(lower) clear		
		// Correct column names
	foreach v of varlist l-af {
		destring `v', replace ignore("…")

		local age: var label `v'
		local age = subinstr("`age'", "-", "_", 1)
		local age = subinstr("`age'", "+", "", 1)
		if ("`age'" == "") {
			drop `v'
		}
		else {
			rename `v' value`age'
		}
	}

	
	tempfile male_$year
	save `male_$year'
restore	

append using `male_$year'

// Identify countries
ren iso2alphacode iso
// Kosovo
replace iso = "KS" if iso == "XK"
drop variant regionsubregioncountryorar notes
destring value*, replace force

// Calculate value for 80+ when we only have the detail
gen value80 = value80_84 + value85_89 + value90_94 + value95_99 + value100

// Calculate other population categories
generate valuechildren = value0_4 + value5_9 + value10_14 + value15_19
generate valueadults = value20_24 + value25_29 + value30_34 + value35_39 + value40_44 + value45_49 + value50_54 + value55_59 + value60_64 + value65_69 + value70_74 + value75_79 + value80
generate value20_39 = value20_24 + value25_29 + value30_34 + value35_39
generate value40_59 = value40_44 + value45_49 + value50_54 + value55_59
generate value60 = value60_64 + value65_69 + value70_74 + value75_79 + value80
generate value20_64 = value20_24 + value25_29 + value30_34 + value35_39 + value40_44 + value45_49 + value50_54 + value55_59 + value60_64
generate value65 = value65_69 + value70_74 + value75_79 + value80
generate value20_29 = value20_24 + value25_29
generate value30_39 = value30_34 + value35_39
generate value40_49 = value40_44 + value45_49
generate value50_59 = value50_54 + value55_59
generate value60_69 = value60_64 + value65_69
generate value70_79 = value70_74 + value75_79
generate value80_89 = value80_84 + value85_89
generate value90_99 = value90_94 + value95_99

// Generate entire men population
generate valueall = value0_4 + value5_9 + value10_14 + value15_19 + value20_24 + value25_29 + value30_34 + value35_39 + value40_44 + value45_49 + value50_54 + value55_59 + value60_64 + value65_69 + value70_74 + value75_79 + value80

cap rename referencedateasof1july year
duplicates drop iso year, force
reshape long value, i(iso year) j(age) string
drop if value >= .
replace value = 1e3*value
generate sex = "men"
	
append using "`unpop'"
save "`unpop'", replace

// Women, age groups -------------------------------------------------------- //
	import excel "$root\raw-data/WPP${year}_POP_F02_3_POPULATION_5-YEAR_AGE_GROUPS_FEMALE.xlsx", ///
	cellrange(B17) firstrow case(lower) clear

// Correct column names
foreach v of varlist l-af {
	destring `v', replace ignore("…")

	local age: var label `v'
	local age = subinstr("`age'", "-", "_", 1)
	local age = subinstr("`age'", "+", "", 1)
	if ("`age'" == "") {
		drop `v'
	}
	else {
		rename `v' value`age'
	}
}

// Adding estimated year - Medium Variant - 2022 and 2023
preserve
import excel "$root\raw-data/WPP${year}_POP_F02_3_POPULATION_5-YEAR_AGE_GROUPS_FEMALE.xlsx", ///
		cellrange(B17) sheet("Medium variant") firstrow case(lower) clear		
		// Correct column names
	foreach v of varlist l-af {
		destring `v', replace ignore("…")

		local age: var label `v'
		local age = subinstr("`age'", "-", "_", 1)
		local age = subinstr("`age'", "+", "", 1)
		if ("`age'" == "") {
			drop `v'
		}
		else {
			rename `v' value`age'
		}
	}

// 	keep if year == $year | year == $pastyear
	
	tempfile female_$year
	save `female_$year'
restore	

append using `female_$year'

// Identify countries
ren iso2alphacode iso
// Kosovo
replace iso = "KS" if iso == "XK"
drop variant regionsubregioncountryorar notes
destring value*, replace force

// Calculate value for 80+ when we only have the detail
gen value80 = value80_84 + value85_89 + value90_94 + value95_99 + value100

// Calculate other population categories
generate valuechildren = value0_4 + value5_9 + value10_14 + value15_19
generate valueadults = value20_24 + value25_29 + value30_34 + value35_39 + value40_44 + value45_49 + value50_54 + value55_59 + value60_64 + value65_69 + value70_74 + value75_79 + value80
generate value20_39 = value20_24 + value25_29 + value30_34 + value35_39
generate value40_59 = value40_44 + value45_49 + value50_54 + value55_59
generate value60 = value60_64 + value65_69 + value70_74 + value75_79 + value80
generate value20_64 = value20_24 + value25_29 + value30_34 + value35_39 + value40_44 + value45_49 + value50_54 + value55_59 + value60_64
generate value65 = value65_69 + value70_74 + value75_79 + value80
generate value20_29 = value20_24 + value25_29
generate value30_39 = value30_34 + value35_39
generate value40_49 = value40_44 + value45_49
generate value50_59 = value50_54 + value55_59
generate value60_69 = value60_64 + value65_69
generate value70_79 = value70_74 + value75_79
generate value80_89 = value80_84 + value85_89
generate value90_99 = value90_94 + value95_99

// Generate entire women population
generate valueall = value0_4 + value5_9 + value10_14 + value15_19 + value20_24 + value25_29 + value30_34 + value35_39 + value40_44 + value45_49 + value50_54 + value55_59 + value60_64 + value65_69 + value70_74 + value75_79 + value80

cap rename referencedateasof1july year
duplicates drop iso year, force
reshape long value, i(iso year) j(age) string
drop if value >= .
replace value = 1e3*value
generate sex = "women"

append using "`unpop'"
save "`unpop'", replace

drop locationcode iso3alphacode sdmxcode regionsubregioncountryorar notes
drop if missing(iso)

label data "Generated by import-un-populations.do"
save "$work_data/un-population.dta", replace


