/********Stata code used for the TN:Extending WID Population Series:
Projections 2024-2100 & Age/Gender Breakdowns*********/

/****extraction of WID series 1820-2023 for population***/
// #delimit
clear all
set more off
set maxvar 6000
run "$code/2 doglobalvariables.do"


**# WID 1800 2023 Load and extrapolate data
foreach sex in i f{
	foreach code in 999 992 991 996 151 001 051 101 997{
	
		/****importation of WID population series***/ /**33 core territories: 24 countries + 9 subregions**/
		wid, ind(npopul) ag(`code') pop(`sex') clear
		gen coreterritory=.
		foreach c of global coreterritories{
			replace coreterritory=1 if country=="`c'"
		}
		gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		keep if (coreterritory==1 | country=="WO" | corecountry==1)
		rename value poptot
		drop age pop percentile variable coreterritory corecountry
		reshape wide poptot, i(year) j(country) string
		keep if year==1820 | year==1850 | year==1880 | year==1900 | year==1910 | year==1920 | year==1930 | year==1940 | year==1950 | year==1960 | year==1970 | year>=1980
		sort year
		/***sous-totaux regionaux**/
		gen poptotEURO=poptotDE+poptotFR+poptotGB+poptotIT+poptotES+poptotSE+poptotOC+poptotQM
		gen poptotNAOC=poptotUS+poptotCA+poptotAU+poptotNZ+poptotOH
		gen poptotLATA=poptotAR+poptotBR+poptotCL+poptotCO+poptotMX+poptotOD
		gen poptotMENA=poptotTR+poptotEG+poptotDZ+poptotOE
		gen poptotSSAF=poptotZA+poptotOJ
		gen poptotRUCA=poptotRU+poptotOA
		gen poptotEASA=poptotCN+poptotJP+poptotOB
		gen poptotSSEA=poptotIN+poptotID+poptotOI

		*East-Southern Africa
		gen poptotESAF= poptotBI	+poptotBW	+poptotDJ	+poptotER	+poptotET	+poptotKE	+poptotKM	+poptotLS	+poptotMG	+poptotMU	+poptotMW	+poptotMZ	+poptotNA	+poptotRW	+poptotSC	+poptotSD	+poptotSO	+poptotSS	+poptotSZ	+poptotTZ	+poptotUG	+poptotZA	+poptotZM	+poptotZW	/*+poptotZZ*/ //Ricardo subregion:East-Southern Africa

		*West-Central Africa
		gen poptotWCAF= poptotAO	+poptotBF	+poptotBJ	+poptotCD	+poptotCF	+poptotCG	+poptotCI	+poptotCM	+poptotCV	+poptotGA	+poptotGH	+poptotGM	+poptotGN	+poptotGQ	+poptotGW	+poptotLR	+poptotML	+poptotMR	+poptotNE	+poptotNG	/*+poptotSH*/	+poptotSL	+poptotSN	+poptotST	+poptotTD	+poptotTG //Ricardo subregion:West-Central Africa

		*South East Asia
		g poptotSEAS=poptotBN	+poptotID	+poptotKH	+poptotLA	+poptotMM	+poptotMY	+poptotPH	+poptotSG	+poptotTH	+poptotTL	+poptotVN

		*South Asia
		g poptotSAS=poptotAF	+poptotBD	+poptotBT	+poptotIN	+poptotLK	+poptotMV	+poptotNP	+poptotPK

		*Extrapolate to the past maintaining the share in 1950
		foreach var in poptotESAF poptotWCAF{
			g sh`var'=`var'/poptotSSAF
			sum sh`var' if year==1950
			replace `var'=r(mean)*poptotSSAF if `var'==. & year<1950 
		}

		foreach var in poptotSEAS poptotSAS{
			g sh`var'=`var'/poptotSSEA
			sum sh`var' if year==1950
			replace `var'=r(mean)*poptotSSEA if `var'==. & year<1950 
		}
		g check1=shpoptotESAF +shpoptotWCAF 
		g check2=shpoptotSEAS +shpoptotSAS
		drop check* sh*



		drop poptotWO 
		g poptotWO=poptotEURO+poptotNAOC+poptotLATA+poptotMENA+poptotSSAF+poptotRUCA+poptotEASA+poptotSSEA

		/****construction of annual 1800-2023 population series for the 8 world regions and the 33 core territories**/
		keep year poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC poptotQM poptotUS poptotCA poptotAU poptotNZ poptotOH poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD poptotTR poptotEG poptotDZ poptotOE poptotZA poptotOJ poptotRU poptotOA poptotCN poptotJP poptotOB poptotIN poptotID poptotOI poptotESAF poptotWCAF poptotSEAS poptotSAS
		order year poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC poptotQM poptotUS poptotCA poptotAU poptotNZ poptotOH poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD poptotTR poptotEG poptotDZ poptotOE poptotZA poptotOJ poptotRU poptotOA poptotCN poptotJP poptotOB poptotIN poptotID poptotOI poptotESAF poptotWCAF poptotSEAS poptotSAS
		insobs 190
		replace year=1800 if _n==56
		replace year=year[_n-1]+1 if _n>=57
		sort year poptotWO
		drop if year==year[_n-1]
		foreach i in WO EURO NAOC LATA MENA SSAF RUCA EASA SSEA DE FR GB IT ES SE OC QM US CA AU NZ OH AR BR CL CO MX OD TR EG DZ OE ZA OJ RU OA CN JP OB IN ID OI ESAF WCAF SEAS SAS{
			forvalues j=1/20{
				replace poptot`i'=poptot`i'[21]/((poptot`i'[51]/poptot`i'[21])^((21-`j')/30)) if _n==`j'
			}
			forvalues j=22/50{
				replace poptot`i'=((51-`j')*poptot`i'[21]+(`j'-21)*poptot`i'[51])/30 if _n==`j'
			}
			forvalues j=52/80{
				replace poptot`i'=((81-`j')*poptot`i'[51]+(`j'-51)*poptot`i'[81])/30 if _n==`j'
			}
			forvalues j=82/100{
				replace poptot`i'=((101-`j')*poptot`i'[81]+(`j'-81)*poptot`i'[101])/20 if _n==`j'
			}
			forvalues j=102/110{
				replace poptot`i'=((111-`j')*poptot`i'[101]+(`j'-101)*poptot`i'[111])/10 if _n==`j'
			}
			forvalues j=112/120{
				replace poptot`i'=((121-`j')*poptot`i'[111]+(`j'-111)*poptot`i'[121])/10 if _n==`j'
			}
			forvalues j=122/130{
				replace poptot`i'=((131-`j')*poptot`i'[121]+(`j'-121)*poptot`i'[131])/10 if _n==`j'
			}
			forvalues j=132/140{
				replace poptot`i'=((141-`j')*poptot`i'[131]+(`j'-131)*poptot`i'[141])/10 if _n==`j'
			}
			forvalues j=142/150{
				replace poptot`i'=((151-`j')*poptot`i'[141]+(`j'-141)*poptot`i'[151])/10 if _n==`j'
			}
			forvalues j=152/160{
				replace poptot`i'=((161-`j')*poptot`i'[151]+(`j'-151)*poptot`i'[161])/10 if _n==`j'
			}
			forvalues j=162/170{
				replace poptot`i'=((171-`j')*poptot`i'[161]+(`j'-161)*poptot`i'[171])/10 if _n==`j'
			}
			forvalues j=172/180{
				replace poptot`i'=((181-`j')*poptot`i'[171]+(`j'-171)*poptot`i'[181])/10 if _n==`j'
			}
			forvalues j=225/226{ // imputes 2024 and 2025
				replace poptot`i'=((224-`j')*poptot`i'[214]+(`j'-214)*poptot`i'[224])/10 if _n==`j'
			}
			replace poptot`i'=poptot`i'/1000000
		}
		drop poptotWO
		g poptotWO=poptotEURO+poptotNAOC+poptotLATA+poptotMENA+poptotSSAF+poptotRUCA+poptotEASA+poptotSSEA
		order year poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC poptotQM poptotUS poptotCA poptotAU poptotNZ poptotOH poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD poptotTR poptotEG poptotDZ poptotOE poptotZA poptotOJ poptotRU poptotOA poptotCN poptotJP poptotOB poptotIN poptotID poptotOI poptotESAF poptotWCAF poptotSEAS poptotSAS
		*save 
		format _all %13.0g
		ren poptot* pop`code'`sex'*
		save "$work_data/pop_`code'`sex'_1800_2023.dta", replace
	}
}	


