/********Stata code used for the TN:Extending WID Population Series:
Projections 2024-2100 & Age/Gender Breakdowns*********/

/********Estimate shares for regions 1800-1940*********/


**# Estimate shares for regions 

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear


	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1950




	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""
	



collapse (sum)  young* non* adul* old* work* tot*, by(region year)

reshape wide young* non* adul* old* work* tot*, i(year) j(region) string
	
	
drop young_MEASA nonadult_MEASA adult_MEASA oldage_MEASA workingage_MEASA total_MEASA young_MEURO nonadult_MEURO adult_MEURO oldage_MEURO workingage_MEURO total_MEURO young_MLATA nonadult_MLATA adult_MLATA oldage_MLATA workingage_MLATA total_MLATA young_MMENA nonadult_MMENA adult_MMENA oldage_MMENA workingage_MMENA total_MMENA young_MNAOC nonadult_MNAOC adult_MNAOC oldage_MNAOC workingage_MNAOC total_MNAOC young_MSSAF nonadult_MSSAF adult_MSSAF oldage_MSSAF workingage_MSSAF total_MSSAF young_MSSEA nonadult_MSSEA adult_MSSEA oldage_MSSEA workingage_MSSEA total_MSSEA

recode _all (0=.)

foreach region in EASA EURO LATA MENA NAOC SSAF SSEA RUCA{
		g sh_young_F`region'=young_F`region'/young_T`region' 					if young_F`region'!=.
		g sh_nonadult_F`region'=nonadult_F`region'/nonadult_T`region'			if nonadult_F`region'!=.
		g sh_adult_F`region'=adult_F`region'/adult_T`region'					if adult_F`region'!=.
		g sh_oldage_F`region'=oldage_F`region'/oldage_T`region'					if oldage_F`region'!=.	
		g sh_workingage_F`region'=workingage_F`region'/workingage_T`region'		if workingage_F`region'!=.
		g sh_total_F`region'=total_F`region'/total_T`region'					if total_F`region'!=.
}

foreach region in EASA EURO LATA MENA NAOC SSAF SSEA RUCA{
		g sh_young_T`region'=young_T`region'/total_T`region'					if young_T`region'!=.
		g sh_nonadult_T`region'=nonadult_T`region'/total_T`region'				if nonadult_T`region'!=.	
		g sh_adult_T`region'=adult_T`region'/total_T`region'					if adult_T`region'!=.	
		g sh_oldage_T`region'=oldage_T`region'/total_T`region'					if oldage_T`region'!=.			
		g sh_workingage_T`region'=workingage_T`region'/total_T`region'			if workingage_T`region'!=.						
}
br year sh_*

sum sh*

ren sh_total_F* sh_pop999f*
ren sh_nonadult_T* sh_pop991i*
ren sh_nonadult_F* sh_pop991f*
ren sh_adult_T* sh_pop992i*
ren sh_adult_F* sh_pop992f*

ren sh_workingage_T* sh_pop15_64i*
ren sh_workingage_F* sh_pop15_64f*

ren sh_young_T* sh_pop0_14i*
ren sh_young_F* sh_pop0_14f*

ren sh_oldage_T* sh_pop65i*
ren sh_oldage_F* sh_pop65f*

keep year sh*

tsset year

*Assumption NAOC behaves like US in 1800
replace sh_pop65iNAOC=421/10527 if year==1800
replace sh_pop15_64iNAOC=5369/10527 if year==1800
replace sh_pop0_14iNAOC=4737/10527 if year==1800
replace sh_pop65fNAOC=210/421 if year==1800
replace sh_pop15_64fNAOC=2650/5369 if year==1800
replace sh_pop0_14fNAOC=2312/4737 if year==1800





	
	
	
**# Shares of young female
	
**Shares young female in EUROPE

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1950


keep country year young_F* young_T*	region 
keep if region=="EURO"

reshape wide young_F* young_T*, i(year) j(country) string

foreach var in AL AT BE BG CH DE DK ES FI FR GB GR HU IE IT NL NO PL PT RO RS SE{
	g sh_youngF`var'=young_F`var'/young_T`var'
	drop young_F`var' //young_T`var'
}	

reshape long young_T sh_youngF, i(year) j(country) string
collapse (mean) sh_youngF [w=young_T], by(year )

tsset year 
tsline sh_youngF
sum sh_youngF,d
drop if sh_youngF<r(p10)
tsline sh_youngF
replace year=round(year/10,1)*10
collapse (mean) sh_youngF, by(year)
keep if inrange(year,1800,1940)
tsline sh_youngF















**Shares young female in NAOC

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1950


keep country year young_F* young_T*	region 
keep if region=="NAOC"

reshape wide young_F* young_T*, i(year) j(country) string

foreach var in AU CA NZ US{
	g sh_youngF`var'=young_F`var'/young_T`var'
	drop young_F`var' //young_T`var'
}	

reshape long young_T sh_youngF, i(year) j(country) string
collapse (mean) sh_youngF [w=young_T], by(year )

tsset year 
tsline sh_youngF
sum sh_youngF,d
drop if sh_youngF<r(p10)
tsline sh_youngF
replace year=round(year/10,1)*10
collapse (mean) sh_youngF, by(year)
keep if inrange(year,1800,1940)
tsline sh_youngF

sort year
ipolate sh_youngF year , gen(sh_youngF_2) epolate 



















**Shares young female in LATA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1950


keep country year young_F* young_T*	region 
keep if region=="LATA"

reshape wide young_F* young_T*, i(year) j(country) string

foreach var in AR BR CL CO CR CU DO GT GY HN JM MX NI PA PE PR TT UY{
	g sh_youngF`var'=young_F`var'/young_T`var'
	drop young_F`var' //young_T`var'
}	

reshape long young_T sh_youngF, i(year) j(country) string
collapse (mean) sh_youngF [w=young_T], by(year )

tsset year 
tsline sh_youngF
// sum sh_youngF,d
// drop if sh_youngF>r(p95)
sum sh_youngF,d
drop if sh_youngF<r(p10)
tsline sh_youngF
replace year=round(year/10,1)*10
collapse (mean) sh_youngF, by(year)
keep if inrange(year,1800,1940)
tsline sh_youngF

sort year
ipolate sh_youngF year , gen(sh_youngF_2) epolate 







**Shares young female in MENA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1950


keep country year young_F* young_T*	region 
keep if region=="MENA"

reshape wide young_F* young_T*, i(year) j(country) string

foreach var in /*DZ*/ EG /*TR*/{
	g sh_youngF`var'=young_F`var'/young_T`var'
	drop young_F`var' //young_T`var'
}	

reshape long young_T sh_youngF, i(year) j(country) string
collapse (mean) sh_youngF [w=young_T], by(year )

tsset year 
tsline sh_youngF
sum sh_youngF,d
drop if sh_youngF<r(p10)
tsline sh_youngF
replace year=round(year/10,1)*10
collapse (mean) sh_youngF, by(year)
keep if inrange(year,1800,1940)
tsline sh_youngF



sort year
ipolate sh_youngF year , gen(sh_youngF_2) epolate 









**Shares young female in SSAF

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1950


keep country year young_F* young_T*	region 
keep if region=="SSAF"

reshape wide young_F* young_T*, i(year) j(country) string

foreach var in AO MZ ZA{
	g sh_youngF`var'=young_F`var'/young_T`var'
	drop young_F`var' //young_T`var'
}	

reshape long young_T sh_youngF, i(year) j(country) string
collapse (mean) sh_youngF [w=young_T], by(year )

tsset year 
tsline sh_youngF
sum sh_youngF,d
drop if sh_youngF<r(p10)
tsline sh_youngF


sort year
ipolate sh_youngF year , gen(sh_youngF_2) epolate 
replace year=round(year/10,1)*10
collapse (mean) sh_youngF_2, by(year)












**Shares young female in SSEA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1950


keep country year young_F* young_T*	region 
keep if region=="SSEA"

reshape wide young_F* young_T*, i(year) j(country) string

foreach var in IN /*LK MM MY PH TH*/{
	g sh_youngF`var'=young_F`var'/young_T`var'
	drop young_F`var' //young_T`var'
}	

reshape long young_T sh_youngF, i(year) j(country) string
collapse (mean) sh_youngF [w=young_T], by(year )

tsset year 
tsline sh_youngF
sum sh_youngF,d
drop if sh_youngF<r(p10)
tsline sh_youngF
replace year=round(year/10,1)*10
collapse (mean) sh_youngF, by(year)
keep if inrange(year,1800,1940)
tsline sh_youngF



sort year
ipolate sh_youngF year , gen(sh_youngF_2) epolate 










**Shares young female in RUCA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1950


keep country year young_F* young_T*	region 
keep if region=="RUCA"

reshape wide young_F* young_T*, i(year) j(country) string

foreach var in RU{
	g sh_youngF`var'=young_F`var'/young_T`var'
	drop young_F`var' //young_T`var'
}	

reshape long young_T sh_youngF, i(year) j(country) string
collapse (mean) sh_youngF [w=young_T], by(year )

tsset year 
tsline sh_youngF
sum sh_youngF,d
drop if sh_youngF<r(p10)
tsline sh_youngF
replace year=round(year/10,1)*10
collapse (mean) sh_youngF, by(year)
keep if inrange(year,1800,1940)
tsline sh_youngF



sort year
ipolate sh_youngF year , gen(sh_youngF_2) epolate 







**Shares young female in EASA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1950


keep country year young_F* young_T*	region 
keep if region=="EASA"

reshape wide young_F* young_T*, i(year) j(country) string

foreach var in JP KR TW{
	g sh_youngF`var'=young_F`var'/young_T`var'
	drop young_F`var' //young_T`var'
}	

reshape long young_T sh_youngF, i(year) j(country) string
collapse (mean) sh_youngF [w=young_T], by(year )

tsset year 
tsline sh_youngF
// sum sh_youngF,d
// drop if sh_youngF>r(p95)
sum sh_youngF,d
drop if sh_youngF<r(p10)
tsline sh_youngF
replace year=round(year/10,1)*10
collapse (mean) sh_youngF, by(year)
keep if inrange(year,1800,1940)
tsline sh_youngF

sort year
ipolate sh_youngF year , gen(sh_youngF_2) epolate 




















**# Shares of old female
	
**Shares old female in EUROPE

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{

	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
} 	

keep if year<1950


keep country year old_F* old_T*	region 
keep if region=="EURO"

reshape wide old_F* old_T*, i(year) j(country) string

foreach var in AL AT BE BG CH DE DK ES FI FR GB GR HU IE IT NL NO PL PT RO RS SE{
	g sh_oldF`var'=old_F`var'/old_T`var'
	drop old_F`var' //old_T`var'
}	

reshape long old_T sh_oldF, i(year) j(country) string
collapse (mean) sh_oldF [w=old_T], by(year )

tsset year 
tsline sh_oldF
sum sh_oldF,d
drop if sh_oldF<r(p10)
tsline sh_oldF
replace year=round(year/10,1)*10
collapse (mean) sh_oldF, by(year)
keep if inrange(year,1800,1940)
tsline sh_oldF















**Shares old female in NAOC

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
} 		

keep if year<1950


keep country year old_F* old_T*	region 
keep if region=="NAOC"

reshape wide old_F* old_T*, i(year) j(country) string

foreach var in /*AU CA NZ*/ US{
	g sh_oldF`var'=old_F`var'/old_T`var'
	drop old_F`var' //old_T`var'
}	

reshape long old_T sh_oldF, i(year) j(country) string
collapse (mean) sh_oldF [w=old_T], by(year )

tsset year 
tsline sh_oldF
sum sh_oldF,d
drop if sh_oldF<r(p10)
tsline sh_oldF
replace year=round(year/10,1)*10
collapse (mean) sh_oldF, by(year)
keep if inrange(year,1800,1940)
tsline sh_oldF




sort year
ipolate sh_oldF year , gen(sh_oldF_2) epolate 

egen seg=seq()
tsset seg
tsfilter hp ct=sh_oldF, trend(trendvar)


ipolate trendvar year , gen(trendvar_2) epolate 



















**Shares old female in LATA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
} 	
keep if year<1950


keep country year old_F* old_T*	region 
keep if region=="LATA"

reshape wide old_F* old_T*, i(year) j(country) string

foreach var in AR BR CL CO CR CU DO GT GY HN JM MX NI PA PE PR TT UY{
	g sh_oldF`var'=old_F`var'/old_T`var'
	drop old_F`var' //old_T`var'
}	

reshape long old_T sh_oldF, i(year) j(country) string
collapse (mean) sh_oldF [w=old_T], by(year )

tsset year 
tsline sh_oldF
// sum sh_oldF,d
// drop if sh_oldF>r(p95)
sum sh_oldF,d
drop if sh_oldF<r(p10)
tsline sh_oldF
replace year=round(year/10,1)*10
collapse (mean) sh_oldF, by(year)
keep if inrange(year,1800,1940)
tsline sh_oldF



sort year
ipolate sh_oldF year , gen(sh_oldF_2) epolate 

egen seg=seq()
tsset seg
tsfilter hp ct=sh_oldF, trend(trendvar)


ipolate trendvar year , gen(trendvar_2) epolate 





**Shares old female in MENA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{

	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
} 	

keep if year<1950


keep country year old_F* old_T*	region 
keep if region=="MENA"

reshape wide old_F* old_T*, i(year) j(country) string

foreach var in /*DZ*/ EG /*TR*/{
	g sh_oldF`var'=old_F`var'/old_T`var'
	drop old_F`var' //old_T`var'
}	

reshape long old_T sh_oldF, i(year) j(country) string
collapse (mean) sh_oldF [w=old_T], by(year )

tsset year 
tsline sh_oldF
sum sh_oldF,d
drop if sh_oldF<r(p10)
tsline sh_oldF
replace year=round(year/10,1)*10
collapse (mean) sh_oldF, by(year)
keep if inrange(year,1800,1940)
tsline sh_oldF


sort year
ipolate sh_oldF year , gen(sh_oldF_2) epolate 



egen seg=seq()
tsset seg






**Shares old female in SSAF

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{

	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
} 	

keep if year<1950


keep country year old_F* old_T*	region 
keep if region=="SSAF"

reshape wide old_F* old_T*, i(year) j(country) string

foreach var in AO MZ ZA{
	g sh_oldF`var'=old_F`var'/old_T`var'
	drop old_F`var' //old_T`var'
}	

reshape long old_T sh_oldF, i(year) j(country) string
collapse (mean) sh_oldF [w=old_T], by(year )

tsset year 
tsline sh_oldF
sum sh_oldF,d
drop if sh_oldF<r(p10)
tsline sh_oldF

sort year
ipolate sh_oldF year , gen(sh_oldF_2) epolate 
replace year=round(year/10,1)*10
collapse (mean) sh_oldF_2, by(year)












**Shares old female in SSEA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
} 	

keep if year<1950


keep country year old_F* old_T*	region 
keep if region=="SSEA"

reshape wide old_F* old_T*, i(year) j(country) string

foreach var in IN LK MM MY PH TH{
	g sh_oldF`var'=old_F`var'/old_T`var'
	drop old_F`var' //old_T`var'
}	

reshape long old_T sh_oldF, i(year) j(country) string
collapse (mean) sh_oldF [w=old_T], by(year )

tsset year 
tsline sh_oldF
sum sh_oldF,d
drop if sh_oldF<r(p10)
tsline sh_oldF
replace year=round(year/10,1)*10
collapse (mean) sh_oldF, by(year)
keep if inrange(year,1800,1940)
tsline sh_oldF

sort year
ipolate sh_oldF year , gen(sh_oldF_2) epolate 



egen seg=seq()
tsset seg
tsfilter hp ct=sh_oldF, trend(trendvar)


ipolate trendvar year , gen(trendvar_2) epolate 







**Shares old female in RUCA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}


foreach sex in F M T{
	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
} 	

keep if year<1950


keep country year old_F* old_T*	region 
keep if region=="RUCA"

reshape wide old_F* old_T*, i(year) j(country) string

foreach var in RU{
	g sh_oldF`var'=old_F`var'/old_T`var'
	drop old_F`var' //old_T`var'
}	

reshape long old_T sh_oldF, i(year) j(country) string
collapse (mean) sh_oldF [w=old_T], by(year )

tsset year 
tsline sh_oldF
sum sh_oldF,d
drop if sh_oldF<r(p10)
tsline sh_oldF
replace year=round(year/10,1)*10
collapse (mean) sh_oldF, by(year)
keep if inrange(year,1800,1940)
tsline sh_oldF


sort year
ipolate sh_oldF year , gen(sh_oldF_2) epolate
g sh_oldF_=sh_oldF
sort year
// ipolate sh_oldF_ year , gen(sh_oldF_2) epolate 

// ipolate sh_oldF_2 year , gen(sh_oldF_3) epolate 

egen seg=seq()
tsset seg
tsfilter hp ct=sh_oldF, trend(trendvar)


ipolate trendvar year , gen(trendvar_2) epolate 





**Shares old female in EASA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{

	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
} 	

keep if year<1950


keep country year old_F* old_T*	region 
keep if region=="EASA"

reshape wide old_F* old_T*, i(year) j(country) string

foreach var in JP KR TW{
	g sh_oldF`var'=old_F`var'/old_T`var'
	drop old_F`var' //old_T`var'
}	

reshape long old_T sh_oldF, i(year) j(country) string
collapse (mean) sh_oldF [w=old_T], by(year )

tsset year 
tsline sh_oldF
sum sh_oldF,d
drop if sh_oldF<r(p10)
tsline sh_oldF
replace year=round(year/10,1)*10
collapse (mean) sh_oldF, by(year)
keep if inrange(year,1800,1940)
tsline sh_oldF


sort year
ipolate sh_oldF year , gen(sh_oldF_2) epolate 

ipolate sh_oldF_2 year , gen(sh_oldF_3) epolate 




**# Shares of women




**Shares old female in MENA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=old_`sex'+workingage_`sex'+old_`sex'
} 	

keep if year<1950


keep country year total_F total_T	region 
keep if region=="MENA"

reshape wide total_F* total_T*, i(year) j(country) string

foreach var in /*DZ*/ EG /*TR*/{
	g sh_totalF`var'=total_F`var'/total_T`var'
	drop total_F`var' //total_T`var'
}	

reshape long total_T sh_totalF, i(year) j(country) string
collapse (mean) sh_totalF [w=total_T], by(year )

tsset year 
tsline sh_totalF

sum sh_totalF,d
drop if sh_totalF<r(p10)
tsline sh_totalF
replace year=round(year/10,1)*10
collapse (mean) sh_totalF, by(year)
keep if inrange(year,1800,1940)
tsline sh_totalF


sort year
ipolate sh_totalF year , gen(sh_totalF_2) epolate 



egen seg=seq()
tsset seg
tsfilter hp ct=sh_totalF, trend(trendvar)


ipolate trendvar year , gen(trendvar_2) epolate 




**# Share young all
*EUROPE

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1970


keep country year  young_T* total_T*	region 
keep if region=="EURO"

reshape wide total_T* young_T*, i(year) j(country) string

foreach var in AL AT BE BG CH DE DK ES FI FR GB GR HU IE IT NL NO PL PT RO RS SE{
	g sh_youngT`var'=young_T`var'/total_T`var'
	drop young_T`var' //young_T`var'
}	
sort year
reshape long total_T sh_youngT, i(year) j(country) string
keep if country=="SE"



tsset year 
tsline sh_youngT

replace year=round(year/10,1)*10
collapse (mean) sh_youngT, by(year)
// keep if inrange(year,1800,1970)
tsline sh_youngT


sort year
ipolate sh_youngT year , gen(sh_youngT_2) epolate






*NAOC

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1970


keep country year  young_T* total_T*	region 
keep if region=="NAOC"

reshape wide total_T* young_T*, i(year) j(country) string

foreach var in AU CA NZ US{
	g sh_youngT`var'=young_T`var'/total_T`var'
	drop young_T`var' //young_T`var'
}	
sort year
reshape long total_T sh_youngT, i(year) j(country) string
keep if country=="AU"

tsset year 
tsline sh_youngT

replace year=round(year/10,1)*10
collapse (mean) sh_youngT, by(year)

tsline sh_youngT


sort year
ipolate sh_youngT year , gen(sh_youngT_2) epolate








*LATA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1970


keep country year  young_T* total_T*	region 
keep if region=="LATA"

reshape wide total_T* young_T*, i(year) j(country) string

foreach var in AR BR CL CO CR CU DO GT GY HN JM MX NI PA PE PR TT UY{
	g sh_youngT`var'=young_T`var'/total_T`var'
	drop young_T`var' //young_T`var'
}	
sort year
reshape long total_T sh_youngT, i(year) j(country) string
keep if country=="CL"


tsset year 
tsline sh_youngT

replace year=round(year/10,1)*10
collapse (mean) sh_youngT, by(year)

tsline sh_youngT


sort year
ipolate sh_youngT year , gen(sh_youngT_2) epolate







*MENA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1970


keep country year  young_T* total_T*	region 
keep if region=="MENA"

reshape wide total_T* young_T*, i(year) j(country) string

foreach var in DZ EG TR{
	g sh_youngT`var'=young_T`var'/total_T`var'
	drop young_T`var' //young_T`var'
}	
sort year
reshape long total_T sh_youngT, i(year) j(country) string
keep if country=="DZ"


tsset year 
tsline sh_youngT

replace year=round(year/10,1)*10
collapse (mean) sh_youngT, by(year)

tsline sh_youngT


sort year
ipolate sh_youngT year , gen(sh_youngT_2) epolate




*SSAF

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1970


keep country year  young_T* total_T*	region 
keep if region=="SSAF"

reshape wide total_T* young_T*, i(year) j(country) string

foreach var in AO MZ ZA  {
	g sh_youngT`var'=young_T`var'/total_T`var'
	drop young_T`var' //young_T`var'
}	
sort year
reshape long total_T sh_youngT, i(year) j(country) string
keep if country=="ZA"


tsset year 
tsline sh_youngT

replace year=round(year/10,1)*10
collapse (mean) sh_youngT, by(year)

tsline sh_youngT


sort year
ipolate sh_youngT year , gen(sh_youngT_2) epolate






*RUCA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1970


keep country year  young_T* total_T*	region 
keep if region=="RUCA"

reshape wide total_T* young_T*, i(year) j(country) string

foreach var in RU  {
	g sh_youngT`var'=young_T`var'/total_T`var'
	drop young_T`var' //young_T`var'
}	
sort year
reshape long total_T sh_youngT, i(year) j(country) string
keep if country=="RU"


tsset year 
tsline sh_youngT

replace year=round(year/10,1)*10
collapse (mean) sh_youngT, by(year)

tsline sh_youngT


sort year
ipolate sh_youngT year , gen(sh_youngT_2) epolate





*EASA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1970


keep country year  young_T* total_T*	region 
keep if region=="EASA"

reshape wide total_T* young_T*, i(year) j(country) string

foreach var in JP KR TW  {
	g sh_youngT`var'=young_T`var'/total_T`var'
	drop young_T`var' //young_T`var'
}	
sort year
reshape long total_T sh_youngT, i(year) j(country) string
keep if country=="JP"


tsset year 
tsline sh_youngT

replace year=round(year/10,1)*10
collapse (mean) sh_youngT, by(year)

tsline sh_youngT


sort year
ipolate sh_youngT year , gen(sh_youngT_2) epolate




*SSEA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g oldage_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+oldage_`sex'
} 	

keep if year<1970


keep country year  young_T* total_T*	region 
keep if region=="SSEA"

reshape wide total_T* young_T*, i(year) j(country) string

foreach var in IN LK MM MY PH TH {
	g sh_youngT`var'=young_T`var'/total_T`var'
	drop young_T`var' //young_T`var'
}	
sort year
reshape long total_T sh_youngT, i(year) j(country) string
keep if country=="IN"


tsset year 
tsline sh_youngT

replace year=round(year/10,1)*10
collapse (mean) sh_youngT, by(year)

tsline sh_youngT


sort year
ipolate sh_youngT year , gen(sh_youngT_2) epolate














**# Share old all


*EUROPE

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+old_`sex'
} 	

keep if year<1970


keep country year  old_T* total_T*	region 
keep if region=="EURO"

reshape wide total_T* old_T*, i(year) j(country) string

foreach var in AL AT BE BG CH DE DK ES FI FR GB GR HU IE IT NL NO PL PT RO RS SE{
	g sh_oldT`var'=old_T`var'/total_T`var'
	drop old_T`var' //old_T`var'
}	
sort year
reshape long total_T sh_oldT, i(year) j(country) string
keep if country=="SE"



tsset year 
tsline sh_oldT

replace year=round(year/10,1)*10
collapse (mean) sh_oldT, by(year)
tsline sh_oldT


sort year
ipolate sh_oldT year , gen(sh_oldT_2) epolate






*NAOC

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+old_`sex'
} 	

keep if year<1970


keep country year  old_T* total_T*	region 
keep if region=="NAOC"

reshape wide total_T* old_T*, i(year) j(country) string

foreach var in AU CA NZ US{
	g sh_oldT`var'=old_T`var'/total_T`var'
	drop old_T`var' //old_T`var'
}	
sort year
reshape long total_T sh_oldT, i(year) j(country) string
keep if country=="US"


tsset year 
tsline sh_oldT

replace year=round(year/10,1)*10
collapse (mean) sh_oldT, by(year)

tsline sh_oldT


sort year
ipolate sh_oldT year , gen(sh_oldT_2) epolate








*LATA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+old_`sex'
} 	

keep if year<1970


keep country year  old_T* total_T*	region 
keep if region=="LATA"

reshape wide total_T* old_T*, i(year) j(country) string

foreach var in AR BR CL CO CR CU DO GT GY HN JM MX NI PA PE PR TT UY{
	g sh_oldT`var'=old_T`var'/total_T`var'
	drop old_T`var' //old_T`var'
}	
sort year
reshape long total_T sh_oldT, i(year) j(country) string
keep if country=="BR"


tsset year 
tsline sh_oldT

replace year=round(year/10,1)*10
collapse (mean) sh_oldT, by(year)

tsline sh_oldT


sort year
ipolate sh_oldT year , gen(sh_oldT_2) epolate







*MENA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+old_`sex'
} 	

keep if year<1970


keep country year  old_T* total_T*	region 
keep if region=="MENA"

reshape wide total_T* old_T*, i(year) j(country) string

foreach var in DZ EG TR{
	g sh_oldT`var'=old_T`var'/total_T`var'
	drop old_T`var' //old_T`var'
}	
sort year
reshape long total_T sh_oldT, i(year) j(country) string
keep if country=="EG"


tsset year 
tsline sh_oldT

replace year=round(year/10,1)*10
collapse (mean) sh_oldT, by(year)

tsline sh_oldT


sort year
ipolate sh_oldT year , gen(sh_oldT_2) epolate




*SSAF

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+old_`sex'
} 	

keep if year<1970


keep country year  old_T* total_T*	region 
keep if region=="SSAF"

reshape wide total_T* old_T*, i(year) j(country) string

foreach var in AO MZ ZA  {
	g sh_oldT`var'=old_T`var'/total_T`var'
	drop old_T`var' //old_T`var'
}	
sort year
reshape long total_T sh_oldT, i(year) j(country) string
keep if country=="ZA"


tsset year 
tsline sh_oldT

replace year=round(year/10,1)*10
collapse (mean) sh_oldT, by(year)

tsline sh_oldT


sort year
ipolate sh_oldT year , gen(sh_oldT_2) epolate






*RUCA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+old_`sex'
} 	

keep if year<1970


keep country year  old_T* total_T*	region 
keep if region=="RUCA"

reshape wide total_T* old_T*, i(year) j(country) string

foreach var in RU  {
	g sh_oldT`var'=old_T`var'/total_T`var'
	drop old_T`var' //old_T`var'
}	
sort year
reshape long total_T sh_oldT, i(year) j(country) string
keep if country=="RU"


tsset year 
tsline sh_oldT

replace year=round(year/10,1)*10
collapse (mean) sh_oldT, by(year)

tsline sh_oldT


sort year
ipolate sh_oldT year , gen(sh_oldT_2) epolate





*EASA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+old_`sex'
} 	

keep if year<1970


keep country year  old_T* total_T*	region 
keep if region=="EASA"

reshape wide total_T* old_T*, i(year) j(country) string

foreach var in JP KR TW  {
	g sh_oldT`var'=old_T`var'/total_T`var'
	drop old_T`var' //old_T`var'
}	
sort year
reshape long total_T sh_oldT, i(year) j(country) string
keep if country=="JP"


tsset year 
tsline sh_oldT

replace year=round(year/10,1)*10
collapse (mean) sh_oldT, by(year)

tsline sh_oldT


sort year
ipolate sh_oldT year , gen(sh_oldT_2) epolate




*SSEA

use "$root\raw-data\International_Historical_Statistics_pop.dta",clear

	gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		
			 gen region2=""
	foreach c of global EURO {
		replace region2="EURO" if country=="`c'"
		}
	foreach c of global NAOC {
		replace region2="NAOC" if country=="`c'"
		}
	foreach c of global LATA {
		replace region2="LATA" if country=="`c'"
		}
	foreach c of global MENA {
		replace region2="MENA" if country=="`c'"
		}
	foreach c of global SSAF {
		replace region2="SSAF" if country=="`c'"
		}
	foreach c of global RUCA {
		replace region2="RUCA" if country=="`c'"
		}
	foreach c of global EASA {
		replace region2="EASA" if country=="`c'"
		}	
	foreach c of global SSEA {
		replace region2="SSEA" if country=="`c'"
		}		
	ren region2 region
	drop if region==""

	foreach var in a04 a59 a1014 a1519 a2024 a2529 a3034 a3539 a4044 a4549 a5054 a5559 a6064 a6569 a7074 a7579 a80over unknown{
	
	gen `var'T=`var'F+`var'M if `var'F!=. & `var'M!=.
	
	
}
	
foreach sex in F M T{
	g young_`sex'=a04`sex'+a59`sex'+ a1014`sex'
	g nonadult_`sex'=a04`sex'+a59`sex'+ a1014`sex'+a1519`sex'	
	g adult_`sex'=a2024`sex'+ a2529`sex'+ a3034`sex'+ a3539`sex'+ a4044`sex'+ a4549`sex'+ a5054`sex'+ a5559`sex'+ a6064`sex'+ a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g workingage_`sex'=a1519`sex'+  a2024`sex'+  a2529`sex'+  a3034`sex'+  a3539`sex'+  a4044`sex'+  a4549`sex'+  a5054`sex'+  a5559`sex'+  a6064`sex'
	g old_`sex'=a6569`sex'+ a7074`sex'+ a7579`sex'+ a80over`sex'
	g total_`sex'=young_`sex'+workingage_`sex'+old_`sex'
} 	

keep if year<1970


keep country year  old_T* total_T*	region 
keep if region=="SSEA"

reshape wide total_T* old_T*, i(year) j(country) string

foreach var in IN LK MM MY PH TH {
	g sh_oldT`var'=old_T`var'/total_T`var'
	drop old_T`var' //old_T`var'
}	
sort year
reshape long total_T sh_oldT, i(year) j(country) string
keep if country=="IN"


tsset year 
tsline sh_oldT

replace year=round(year/10,1)*10
collapse (mean) sh_oldT, by(year)

tsline sh_oldT


sort year
ipolate sh_oldT year , gen(sh_oldT_2) epolate
