/********Stata code used for the TN:Extending WID Population Series:
Projections 2024-2100 & Age/Gender Breakdowns*********/

/****Create population series  for 33 coreterritories between 1800-2100 based on International Historical Statistics**/


**# Load UN data to create populations 1950-2100


foreach sex in i f{
	foreach code in 999 992 991 996 151 001 051 101 997{

use "$work_data/populations.dta", clear
tab year
drop p
ren iso country


gen coreterritory=.
		foreach c of global coreterritories{
			replace coreterritory=1 if country=="`c'"
		}
		gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		keep if (coreterritory==1  | corecountry==1)
		
		keep if widcode=="npopul`code'`sex'"
		keep value year country
reshape wide value	, i(year) 	j(country) string

ren value* poptot*

	*aggregate into regions
		g poptotEURO= poptotAD+ poptotAL+ poptotAT+ poptotBA+ poptotBE+ poptotBG+ poptotCH+ poptotCY+ poptotCZ+ poptotDE+ poptotDK+ poptotEE+ poptotES+ poptotFI+ poptotFR+ poptotGB+ poptotGG+ poptotGI+ poptotGR+ poptotHR+ poptotHU+ poptotIE+ poptotIM+ poptotIS+ poptotIT+ poptotJE+ poptotKS+ poptotLI+ poptotLT+ poptotLU+ poptotLV+ poptotMC+ poptotMD+ poptotME+ poptotMK+ poptotMT+ poptotNL+ poptotNO+ poptotPL+ poptotPT+ poptotRO+ poptotRS+ poptotSE+ poptotSI+ poptotSK+ poptotSM
		
		*Check that PAPUA NEW GUINEA is NAOC-> YES
		gen poptotNAOC= poptotAU+ poptotBM+ poptotCA+ poptotFJ+ poptotFM+ poptotGL+ poptotKI+ poptotMH+ poptotNC+ poptotNR+ poptotNZ+ poptotPF+ poptotPG+ poptotPW+ poptotSB+ poptotTO+ poptotTV+ poptotUS+ poptotVU+ poptotWS
		
		gen poptotLATA= poptotAG+ poptotAI+ poptotAR+ poptotAW+ poptotBB+ poptotBO+ poptotBQ+ poptotBR+ poptotBS+ poptotBZ+ poptotCL+ poptotCO+ poptotCR+ poptotCU+ poptotCW+ poptotDM+ poptotDO+ poptotEC+ poptotGD+ poptotGT+ poptotGY+ poptotHN+ poptotHT+ poptotJM+ poptotKN+ poptotKY+ poptotLC+ poptotMS+ poptotMX+ poptotNI+ poptotPA+ poptotPE+ poptotPR+ poptotPY+ poptotSR+ poptotSV+ poptotSX+ poptotTC+ poptotTT+ poptotUY+ poptotVC+ poptotVE+ poptotVG
		
		gen poptotMENA= poptotAE+ poptotBH+ poptotDZ+ poptotEG+ poptotIL+ poptotIQ+ poptotIR+ poptotJO+ poptotKW+ poptotLB+ poptotLY+ poptotMA+ poptotOM+ poptotPS+ poptotQA+ poptotSA+ poptotSY+ poptotTN+ poptotTR+ poptotYE
		
		gen poptotSSAF= poptotAO+ poptotBF+ poptotBI+ poptotBJ+ poptotBW+ poptotCD+ poptotCF+ poptotCG+ poptotCI+ poptotCM+ poptotCV+ poptotDJ+ poptotER+ poptotET+ poptotGA+ poptotGH+ poptotGM+ poptotGN+ poptotGQ+ poptotGW+ poptotKE+ poptotKM+ poptotLR+ poptotLS+ poptotMG+ poptotML+ poptotMR+ poptotMU+ poptotMW+ poptotMZ+ poptotNA+ poptotNE+ poptotNG+ poptotRW+ poptotSC+ poptotSD+ poptotSL+ poptotSN+ poptotSO+ poptotSS+ poptotST+ poptotSZ+ poptotTD+ poptotTG+ poptotTZ+ poptotUG+ poptotZA+ poptotZM+ poptotZW
		
		gen poptotRUCA= poptotAM+ poptotAZ+ poptotBY+ poptotGE+ poptotKG+ poptotKZ+ poptotRU+ poptotTJ+ poptotTM+ poptotUA+ poptotUZ
		
		gen poptotEASA= poptotCN+ poptotHK+ poptotJP+ poptotKP+ poptotKR+ poptotMN+ poptotMO+ poptotTW
		
		gen poptotSSEA= poptotAF+ poptotBD+ poptotBN+ poptotBT+ poptotID+ poptotIN+ poptotKH+ poptotLA+ poptotLK+ poptotMM+ poptotMV+ poptotMY+ poptotNP+ poptotPH+ poptotPK+ poptotSG+ poptotTH+ poptotTL+ poptotVN
		
		gen poptotWO=poptotEURO+poptotNAOC+poptotLATA+poptotMENA+poptotSSAF+poptotRUCA+poptotEASA+poptotSSEA
		
		gen poptotQM=poptotAL		+poptotBA		+poptotBG		+poptotCY		+poptotCZ		+poptotEE		+poptotHR		+poptotHU		+poptotLT		+poptotLV		+poptotMD		+poptotME		+poptotMK		+poptotPL		+poptotRO		+poptotRS		+poptotSI		+poptotSK +			poptotKS


		gen poptotOH=poptotNAOC-(poptotUS+poptotCA+poptotAU+poptotNZ)
		gen poptotOD=poptotLATA-(poptotAR+poptotBR+poptotCL+poptotCO+poptotMX)
		gen poptotOE=poptotMENA-(poptotTR+poptotEG+poptotDZ)
		gen poptotOJ=poptotSSAF-poptotZA
		gen poptotOA=poptotRUCA-poptotRU
		gen poptotOB=poptotEASA-(poptotCN+poptotJP)
		gen poptotOI=poptotSSEA-(poptotIN+poptotID)
		gen poptotOC=poptotEURO-(poptotDE+poptotFR+poptotGB+poptotIT+poptotES+poptotSE+poptotQM)
		
	foreach var in 	poptotOM poptotOH poptotOD poptotOE poptotOJ poptotOA poptotOB poptotOI poptotOC{
		replace `var'=0 if `var'<0 
	}


		*East-Southern Africa
			gen poptotESAF= poptotBI	+poptotBW	+poptotDJ	+poptotER	+poptotET	+poptotKE	+poptotKM	+poptotLS	+poptotMG	+poptotMU	+poptotMW	+poptotMZ	+poptotNA	+poptotRW	+poptotSC	+poptotSD	+poptotSO	+poptotSS	+poptotSZ	+poptotTZ	+poptotUG	+poptotZA	+poptotZM	+poptotZW	/*+poptotZZ*/ //Ricardo subregion:East-Southern Africa

			*West-Central Africa
			gen poptotWCAF= poptotAO	+poptotBF	+poptotBJ	+poptotCD	+poptotCF	+poptotCG	+poptotCI	+poptotCM	+poptotCV	+poptotGA	+poptotGH	+poptotGM	+poptotGN	+poptotGQ	+poptotGW	+poptotLR	+poptotML	+poptotMR	+poptotNE	+poptotNG	/*+poptotSH*/	+poptotSL	+poptotSN	+poptotST	+poptotTD	+poptotTG //Ricardo subregion:West-Central Africa

			*South East Asia
			g poptotSEAS=poptotBN	+poptotID	+poptotKH	+poptotLA	+poptotMM	+poptotMY	+poptotPH	+poptotSG	+poptotTH	+poptotTL	+poptotVN

			*South Asia
			g poptotSAS=poptotAF	+poptotBD	+poptotBT	+poptotIN	+poptotLK	+poptotMV	+poptotNP	+poptotPK


					keep year poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC poptotQM poptotUS poptotCA poptotAU poptotNZ poptotOH poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD poptotTR poptotEG poptotDZ poptotOE poptotZA poptotOJ poptotRU poptotOA poptotCN poptotJP poptotOB poptotIN poptotID poptotOI poptotESAF poptotWCAF poptotSEAS poptotSAS
			order year poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC poptotQM poptotUS poptotCA poptotAU poptotNZ poptotOH poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD poptotTR poptotEG poptotDZ poptotOE poptotZA poptotOJ poptotRU poptotOA poptotCN poptotJP poptotOB poptotIN poptotID poptotOI poptotESAF poptotWCAF poptotSEAS poptotSAS

	drop if year<1950

	save "$work_data/pop_`code'`sex'_1800_1949.dta",replace

	}
}

foreach sex in i f{
	foreach code in 999 992 991 996 151 001 051 101 997{
	
use "$work_data/pop_`code'`sex'_1800_1949.dta",clear	
erase "$work_data/pop_`code'`sex'_1800_1949.dta" 
save "$work_data/pop_`code'`sex'_1950_2100.dta",replace	
	}
}


**# Load WID data for projections by coreterritories 1800-1949
*Poptot
use "$work_data/pop_999i_1800_2023.dta",clear
ren pop999i* poptot*
keep if year<1950
foreach var in poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC poptotQM poptotUS poptotCA poptotAU poptotNZ poptotOH poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD poptotTR poptotEG poptotDZ poptotOE poptotZA poptotOJ poptotRU poptotOA poptotCN poptotJP poptotOB poptotIN poptotID poptotOI poptotESAF poptotWCAF poptotSEAS poptotSAS{
	replace `var'=`var'*1000000
}
append using "$work_data/pop_999i_1950_2100.dta"
tsset year
tsline poptotES , xline( 1950)
tsline poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA, xline(1950)
save "$work_data/pop_999i_1800_2023_UN.dta",replace	

*Adult
use "$work_data/pop_992i_1800_2023.dta",clear
ren pop992i* poptot*
keep if year<1950
foreach var in poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC poptotQM poptotUS poptotCA poptotAU poptotNZ poptotOH poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD poptotTR poptotEG poptotDZ poptotOE poptotZA poptotOJ poptotRU poptotOA poptotCN poptotJP poptotOB poptotIN poptotID poptotOI poptotESAF poptotWCAF poptotSEAS poptotSAS{
	replace `var'=`var'*1000000
}
append using "$work_data/pop_992i_1950_2100.dta"
tsset year
tsline poptotES , xline( 1950)
tsline poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA, xline(1950)
save "$work_data/pop_992i_1800_2023_UN.dta",replace	





**# Merge UN 1950-2100 and WID projections 1800-1949
*Merge all 1950_2100
use "$work_data/pop_999i_1800_2023_UN.dta",clear
ren 	poptot* pop999i*
merge 1:1 year using "$work_data/pop_992i_1800_2023_UN.dta"
drop if year==.
drop _merge
ren 	poptot* pop992i*



foreach sex in i f{
	foreach code in   991 996 151 001 051 101 997{
merge 1:1 year using  "$work_data/pop_`code'`sex'_1950_2100.dta"
		drop if year==.
		drop _merge	
format poptot* %13.0g
tsset year
tsline poptotES , xline( 1950)
tsline poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA, xline(1950)		
ren 	poptot* pop`code'`sex'*		
	}
}

foreach sex in  f{
	foreach code in   999{
merge 1:1 year using  "$work_data/pop_`code'`sex'_1950_2100.dta"
		drop if year==.
		drop _merge	
format poptot* %13.0g
tsset year
tsline poptotES , xline( 1950)
tsline poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA, xline(1950)		
ren 	poptot* pop`code'`sex'*		
	}
}	

tsline pop999iWO pop992iWO pop991iWO , xline(1950)



**# 0-19i Computation
*Generate non-adult (0-19) as the substraction of total and 20+
g pop991iWO_2=pop999iWO-pop992iWO
tsline pop991iWO pop991iWO_2 , xline(1950)
drop pop991iWO_2
foreach region in WO EURO NAOC LATA MENA SSAF RUCA EASA SSEA DE FR GB IT ES SE OC QM US CA AU NZ OH AR BR CL CO MX OD TR EG DZ OE ZA OJ RU OA CN JP OB IN ID OI ESAF WCAF SEAS SAS{
	drop pop991i`region'
	g pop991i`region'=pop999i`region'-pop992i`region'
}
tsline pop992iMENA , xline(1950)


**# 0-14i Assumption
*Generate young age all 0-14 as the addition of 0-4 (001i), 5-9 (051i), and 10-14 (101i)
foreach country in WO EURO NAOC LATA MENA SSAF RUCA EASA SSEA DE FR GB IT ES SE OC QM US CA AU NZ OH AR BR CL CO MX OD TR EG DZ OE ZA OJ RU OA CN JP OB IN ID OI ESAF WCAF SEAS SAS{
	
	g pop0_14i`country'=pop001i`country'+pop051i`country'+pop101i`country'	if year>=1950
	
* EASA young based on International Historical Statistics
replace pop0_14i`country' = pop999i`country' *0.346043114285714 if inrange(year, 1800, 1800) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14i`country' = pop999i`country' *0.34228675 if inrange(year, 1810, 1810) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14i`country' = pop999i`country' *0.33857352 if inrange(year, 1820, 1820) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14i`country' = pop999i`country' *0.33486028 if inrange(year, 1830, 1830) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14i`country' = pop999i`country' *0.33114704 if inrange(year, 1840, 1840) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14i`country' = pop999i`country' *0.32743381 if inrange(year, 1850, 1850) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14i`country' = pop999i`country' *0.32372057 if inrange(year, 1860, 1860) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14i`country' = pop999i`country' *0.32000734 if inrange(year, 1870, 1870) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14i`country' = pop999i`country' *0.3162941 if inrange(year, 1880, 1880) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14i`country' = pop999i`country' *0.33101365 if inrange(year, 1890, 1890) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14i`country' = pop999i`country' *0.334867 if inrange(year, 1900, 1900) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14i`country' = pop999i`country' *0.34935537 if inrange(year, 1910, 1910) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14i`country' = pop999i`country' *0.36472777 if inrange(year, 1920, 1920) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14i`country' = pop999i`country' *0.3655749 if inrange(year, 1930, 1930) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14i`country' = pop999i`country' *0.36046895 if inrange(year, 1940, 1940) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )


* EURO young based on International Historical Statistics
replace pop0_14i`country' = pop999i`country' *0.32596686 if inrange(year, 1800, 1800) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14i`country' = pop999i`country' *0.31904161 if inrange(year, 1810, 1810) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14i`country' = pop999i`country' *0.32115087 if inrange(year, 1820, 1820) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14i`country' = pop999i`country' *0.35095653 if inrange(year, 1830, 1830) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14i`country' = pop999i`country' *0.33855999 if inrange(year, 1840, 1840) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14i`country' = pop999i`country' *0.32881063 if inrange(year, 1850, 1850) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14i`country' = pop999i`country' *0.3339397 if inrange(year, 1860, 1860) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14i`country' = pop999i`country' *0.3483519 if inrange(year, 1870, 1870) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14i`country' = pop999i`country' *0.32610601 if inrange(year, 1880, 1880) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14i`country' = pop999i`country' *0.33326364 if inrange(year, 1890, 1890) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14i`country' = pop999i`country' *0.32431379 if inrange(year, 1900, 1900) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14i`country' = pop999i`country' *0.31721014 if inrange(year, 1910, 1910) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14i`country' = pop999i`country' *0.29268292 if inrange(year, 1920, 1920) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14i`country' = pop999i`country' *0.24816805 if inrange(year, 1930, 1930) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14i`country' = pop999i`country' *0.24906796 if inrange(year, 1940, 1940) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")


* LATA young based on International Historical Statistics
replace pop0_14i`country' = pop999i`country' *0.38111274 if inrange(year, 1800, 1800) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14i`country' = pop999i`country' *0.38365178 if inrange(year, 1810, 1810) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14i`country' = pop999i`country' *0.38630354 if inrange(year, 1820, 1820) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14i`country' = pop999i`country' *0.38895531 if inrange(year, 1830, 1830) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14i`country' = pop999i`country' *0.39160708 if inrange(year, 1840, 1840) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14i`country' = pop999i`country' *0.39425884 if inrange(year, 1850, 1850) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14i`country' = pop999i`country' *0.39691061 if inrange(year, 1860, 1860) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14i`country' = pop999i`country' *0.39956237 if inrange(year, 1870, 1870) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14i`country' = pop999i`country' *0.40221414 if inrange(year, 1880, 1880) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14i`country' = pop999i`country' *0.40486591 if inrange(year, 1890, 1890) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14i`country' = pop999i`country' *0.40751767 if inrange(year, 1900, 1900) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14i`country' = pop999i`country' *0.37530789 if inrange(year, 1910, 1910) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14i`country' = pop999i`country' *0.3793655 if inrange(year, 1920, 1920) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14i`country' = pop999i`country' *0.37188154 if inrange(year, 1930, 1930) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14i`country' = pop999i`country' *0.37149113 if inrange(year, 1940, 1940) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")



* MENA young based on International Historical Statistics
replace pop0_14i`country' = pop999i`country' *0.37619495 if inrange(year, 1800, 1800) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14i`country' = pop999i`country' *0.3779799 if inrange(year, 1810, 1810) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14i`country' = pop999i`country' *0.37995981 if inrange(year, 1820, 1820) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14i`country' = pop999i`country' *0.38193971 if inrange(year, 1830, 1830) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14i`country' = pop999i`country' *0.38391962 if inrange(year, 1840, 1840) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14i`country' = pop999i`country' *0.38589953 if inrange(year, 1850, 1850) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14i`country' = pop999i`country' *0.38787944 if inrange(year, 1860, 1860) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14i`country' = pop999i`country' *0.38985935 if inrange(year, 1870, 1870) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14i`country' = pop999i`country' *0.39183926 if inrange(year, 1880, 1880) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14i`country' = pop999i`country' *0.39381917 if inrange(year, 1890, 1890) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14i`country' = pop999i`country' *0.39579908 if inrange(year, 1900, 1900) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14i`country' = pop999i`country' *0.39777899 if inrange(year, 1910, 1910) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14i`country' = pop999i`country' *0.38338963 if inrange(year, 1920, 1920) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14i`country' = pop999i`country' *0.36900028 if inrange(year, 1930, 1930) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14i`country' = pop999i`country' *0.35461092 if inrange(year, 1940, 1940) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")


* NAOC young based on International Historical Statistics
replace pop0_14i`country' = pop999i`country' *0.35163145 if inrange(year, 1800, 1800) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14i`country' = pop999i`country' *0.35459064 if inrange(year, 1810, 1810) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14i`country' = pop999i`country' *0.35718128 if inrange(year, 1820, 1820) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14i`country' = pop999i`country' *0.35977192 if inrange(year, 1830, 1830) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14i`country' = pop999i`country' *0.36236256 if inrange(year, 1840, 1840) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14i`country' = pop999i`country' *0.3649532 if inrange(year, 1850, 1850) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14i`country' = pop999i`country' *0.36754385 if inrange(year, 1860, 1860) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14i`country' = pop999i`country' *0.42168674 if inrange(year, 1870, 1870) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14i`country' = pop999i`country' *0.39037433 if inrange(year, 1880, 1880) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14i`country' = pop999i`country' *0.37080431 if inrange(year, 1890, 1890) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14i`country' = pop999i`country' *0.35200426 if inrange(year, 1900, 1900) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14i`country' = pop999i`country' *0.31753555 if inrange(year, 1910, 1910) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14i`country' = pop999i`country' *0.31833273 if inrange(year, 1920, 1920) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14i`country' = pop999i`country' *0.27477002 if inrange(year, 1930, 1930) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14i`country' = pop999i`country' *0.27445096 if inrange(year, 1940, 1940) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")



* RUCA young based on International Historical Statistics
replace pop0_14i`country' = pop999i`country' *0.370433366666667 if inrange(year, 1800, 1800) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA") 
replace pop0_14i`country' = pop999i`country' *0.3715518 if inrange(year, 1810, 1810) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14i`country' = pop999i`country' *0.37310359 if inrange(year, 1820, 1820) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14i`country' = pop999i`country' *0.37465538 if inrange(year, 1830, 1830) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14i`country' = pop999i`country' *0.37620717 if inrange(year, 1840, 1840) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14i`country' = pop999i`country' *0.37775896 if inrange(year, 1850, 1850) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14i`country' = pop999i`country' *0.37931076 if inrange(year, 1860, 1860) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14i`country' = pop999i`country' *0.38086255 if inrange(year, 1870, 1870) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14i`country' = pop999i`country' *0.38241434 if inrange(year, 1880, 1880) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14i`country' = pop999i`country' *0.38396613 if inrange(year, 1890, 1890) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14i`country' = pop999i`country' *0.38551793 if inrange(year, 1900, 1900) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14i`country' = pop999i`country' *0.38106259 if inrange(year, 1910, 1910) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14i`country' = pop999i`country' *0.37660725 if inrange(year, 1920, 1920) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14i`country' = pop999i`country' *0.37215191 if inrange(year, 1930, 1930) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14i`country' = pop999i`country' *0.35363027 if inrange(year, 1940, 1940) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")




* SSEA young based on International Historical Statistics
replace pop0_14i`country' = pop999i`country' *0.391569733333333 if inrange(year, 1800, 1800) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14i`country' = pop999i`country' *0.39156506 if inrange(year, 1810, 1810) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14i`country' = pop999i`country' *0.39113013 if inrange(year, 1820, 1820) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14i`country' = pop999i`country' *0.3906952 if inrange(year, 1830, 1830) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14i`country' = pop999i`country' *0.39026026 if inrange(year, 1840, 1840) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14i`country' = pop999i`country' *0.38982533 if inrange(year, 1850, 1850) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14i`country' = pop999i`country' *0.3893904 if inrange(year, 1860, 1860) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14i`country' = pop999i`country' *0.38895547 if inrange(year, 1870, 1870) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14i`country' = pop999i`country' *0.38852054 if inrange(year, 1880, 1880) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14i`country' = pop999i`country' *0.39765963 if inrange(year, 1890, 1890) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14i`country' = pop999i`country' *0.38635576 if inrange(year, 1900, 1900) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14i`country' = pop999i`country' *0.38479808 if inrange(year, 1910, 1910) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14i`country' = pop999i`country' *0.3918409 if inrange(year, 1920, 1920) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14i`country' = pop999i`country' *0.40024349 if inrange(year, 1930, 1930) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14i`country' = pop999i`country' *0.38735466 if inrange(year, 1940, 1940) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")


* SSAF young based on International Historical Statistics
replace pop0_14i`country' = pop999i`country' *0.38236205 if inrange(year, 1800, 1800) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ" | "`country'" == "ESAF" | "`country'" == "WCAF") 
replace pop0_14i`country' = pop999i`country' *0.38249201 if inrange(year, 1810, 1810) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14i`country' = pop999i`country' *0.38298402 if inrange(year, 1820, 1820) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14i`country' = pop999i`country' *0.38347603 if inrange(year, 1830, 1830) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14i`country' = pop999i`country' *0.38396803 if inrange(year, 1840, 1840) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14i`country' = pop999i`country' *0.38446004 if inrange(year, 1850, 1850) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14i`country' = pop999i`country' *0.38495205 if inrange(year, 1860, 1860) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14i`country' = pop999i`country' *0.38544406 if inrange(year, 1870, 1870) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14i`country' = pop999i`country' *0.38593607 if inrange(year, 1880, 1880) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14i`country' = pop999i`country' *0.38642808 if inrange(year, 1890, 1890) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14i`country' = pop999i`country' *0.38692009 if inrange(year, 1900, 1900) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14i`country' = pop999i`country' *0.3874121 if inrange(year, 1910, 1910) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14i`country' = pop999i`country' *0.38790411 if inrange(year, 1920, 1920) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14i`country' = pop999i`country' *0.38839611 if inrange(year, 1930, 1930) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14i`country' = pop999i`country' *0.37632802 if inrange(year, 1940, 1940) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")

ipolate pop0_14i`country' year, gen(pop0_14i`country'_2) epolate
drop pop0_14i`country'
ren pop0_14i`country'_2 pop0_14i`country'	
}
drop pop001i* pop051i* pop101i*

tsline pop0_14iEURO , xline(1950)




**# 65+i Assumption
foreach country in WO EURO NAOC LATA MENA SSAF RUCA EASA SSEA DE FR GB IT ES SE OC QM US CA AU NZ OH AR BR CL CO MX OD TR EG DZ OE ZA OJ RU OA CN JP OB IN ID OI ESAF WCAF SEAS SAS{
	
	**Compute 65+ as the share for each decade foreach region
			g pop65i`country'=pop997i`country' if year>=1950

* EASA old age based on International Historical Statistics
replace pop65i`country' = pop999i`country' *0.0524054571428572 if inrange(year, 1800, 1800) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65i`country' = pop999i`country' *0.05265421 if inrange(year, 1810, 1810) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65i`country' = pop999i`country' *0.05330842 if inrange(year, 1820, 1820) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65i`country' = pop999i`country' *0.05396262 if inrange(year, 1830, 1830) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65i`country' = pop999i`country' *0.05461683 if inrange(year, 1840, 1840) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65i`country' = pop999i`country' *0.05527104 if inrange(year, 1850, 1850) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65i`country' = pop999i`country' *0.05592525 if inrange(year, 1860, 1860) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65i`country' = pop999i`country' *0.05657945 if inrange(year, 1870, 1870) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65i`country' = pop999i`country' *0.05723366 if inrange(year, 1880, 1880) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65i`country' = pop999i`country' *0.05516491 if inrange(year, 1890, 1890) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65i`country' = pop999i`country' *0.05172377 if inrange(year, 1900, 1900) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65i`country' = pop999i`country' *0.0554681 if inrange(year, 1910, 1910) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65i`country' = pop999i`country' *0.05264298 if inrange(year, 1920, 1920) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65i`country' = pop999i`country' *0.04750125 if inrange(year, 1930, 1930) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65i`country' = pop999i`country' *0.04710345 if inrange(year, 1940, 1940) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )


* EURO old age based on International Historical Statistics
replace pop65i`country' = pop999i`country' *0.05482363 if inrange(year, 1800, 1800) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65i`country' = pop999i`country' *0.0517024 if inrange(year, 1810, 1810) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65i`country' = pop999i`country' *0.05365475 if inrange(year, 1820, 1820) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65i`country' = pop999i`country' *0.05321739 if inrange(year, 1830, 1830) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65i`country' = pop999i`country' *0.04736 if inrange(year, 1840, 1840) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65i`country' = pop999i`country' *0.04821016 if inrange(year, 1850, 1850) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65i`country' = pop999i`country' *0.05223493 if inrange(year, 1860, 1860) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65i`country' = pop999i`country' *0.0535926 if inrange(year, 1870, 1870) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65i`country' = pop999i`country' *0.05891371 if inrange(year, 1880, 1880) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65i`country' = pop999i`country' *0.07652101 if inrange(year, 1890, 1890) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65i`country' = pop999i`country' *0.08370645 if inrange(year, 1900, 1900) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65i`country' = pop999i`country' *0.08442029 if inrange(year, 1910, 1910) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65i`country' = pop999i`country' *0.0843496 if inrange(year, 1920, 1920) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65i`country' = pop999i`country' *0.0921674 if inrange(year, 1930, 1930) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65i`country' = pop999i`country' *0.08998318 if inrange(year, 1940, 1940) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")



* LATA old age based on International Historical Statistics
replace pop65i`country' = pop999i`country' *0.02553492 if inrange(year, 1800, 1800) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65i`country' = pop999i`country' *0.02968317 if inrange(year, 1810, 1810) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65i`country' = pop999i`country' *0.03336634 if inrange(year, 1820, 1820) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65i`country' = pop999i`country' *0.03704951 if inrange(year, 1830, 1830) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65i`country' = pop999i`country' *0.04073267 if inrange(year, 1840, 1840) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65i`country' = pop999i`country' *0.04441584 if inrange(year, 1850, 1850) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65i`country' = pop999i`country' *0.04809901 if inrange(year, 1860, 1860) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65i`country' = pop999i`country' *0.05178218 if inrange(year, 1870, 1870) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65i`country' = pop999i`country' *0.0389155 if inrange(year, 1880, 1880) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65i`country' = pop999i`country' *0.02604883 if inrange(year, 1890, 1890) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65i`country' = pop999i`country' *0.01175033 if inrange(year, 1900, 1900) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65i`country' = pop999i`country' *0.01295751 if inrange(year, 1910, 1910) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65i`country' = pop999i`country' *0.01416468 if inrange(year, 1920, 1920) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65i`country' = pop999i`country' *0.01904662 if inrange(year, 1930, 1930) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65i`country' = pop999i`country' *0.02392855 if inrange(year, 1940, 1940) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")



* MENA old age based on International Historical Statistics
replace pop65i`country' = pop999i`country' *0.03375375 if inrange(year, 1800, 1800) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65i`country' = pop999i`country' *0.03419362 if inrange(year, 1810, 1810) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65i`country' = pop999i`country' *0.03438724 if inrange(year, 1820, 1820) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65i`country' = pop999i`country' *0.03458085 if inrange(year, 1830, 1830) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65i`country' = pop999i`country' *0.03477447 if inrange(year, 1840, 1840) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65i`country' = pop999i`country' *0.03496809 if inrange(year, 1850, 1850) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65i`country' = pop999i`country' *0.03516171 if inrange(year, 1860, 1860) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65i`country' = pop999i`country' *0.03535533 if inrange(year, 1870, 1870) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65i`country' = pop999i`country' *0.03554894 if inrange(year, 1880, 1880) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65i`country' = pop999i`country' *0.03574256 if inrange(year, 1890, 1890) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65i`country' = pop999i`country' *0.03593618 if inrange(year, 1900, 1900) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65i`country' = pop999i`country' *0.0361298 if inrange(year, 1910, 1910) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65i`country' = pop999i`country' *0.03632341 if inrange(year, 1920, 1920) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65i`country' = pop999i`country' *0.03651703 if inrange(year, 1930, 1930) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65i`country' = pop999i`country' *0.03099053 if inrange(year, 1940, 1940) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")



* NAOC old age based on International Historical Statistics
replace pop65i`country' = pop999i`country' *0.0445255875 if inrange(year, 1800, 1800) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65i`country' = pop999i`country' *0.04285317 if inrange(year, 1810, 1810) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65i`country' = pop999i`country' *0.04070634 if inrange(year, 1820, 1820) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65i`country' = pop999i`country' *0.03855951 if inrange(year, 1830, 1830) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65i`country' = pop999i`country' *0.03641268 if inrange(year, 1840, 1840) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65i`country' = pop999i`country' *0.03426585 if inrange(year, 1850, 1850) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65i`country' = pop999i`country' *0.03211902 if inrange(year, 1860, 1860) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65i`country' = pop999i`country' *0.02997219 if inrange(year, 1870, 1870) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65i`country' = pop999i`country' *0.03557358 if inrange(year, 1880, 1880) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65i`country' = pop999i`country' *0.03876591 if inrange(year, 1890, 1890) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65i`country' = pop999i`country' *0.0406932 if inrange(year, 1900, 1900) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65i`country' = pop999i`country' *0.04304582 if inrange(year, 1910, 1910) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65i`country' = pop999i`country' *0.04673991 if inrange(year, 1920, 1920) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65i`country' = pop999i`country' *0.05416673 if inrange(year, 1930, 1930) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65i`country' = pop999i`country' *0.06724735 if inrange(year, 1940, 1940) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")



* RUCA old age based on International Historical Statistics
replace pop65i`country' = pop999i`country' *0.0415813 if inrange(year, 1800, 1800) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA") 
replace pop65i`country' = pop999i`country' *0.0420168 if inrange(year, 1810, 1810) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65i`country' = pop999i`country' *0.04203361 if inrange(year, 1820, 1820) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65i`country' = pop999i`country' *0.04205041 if inrange(year, 1830, 1830) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65i`country' = pop999i`country' *0.04206721 if inrange(year, 1840, 1840) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65i`country' = pop999i`country' *0.04208401 if inrange(year, 1850, 1850) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65i`country' = pop999i`country' *0.04210082 if inrange(year, 1860, 1860) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65i`country' = pop999i`country' *0.04211762 if inrange(year, 1870, 1870) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65i`country' = pop999i`country' *0.04213442 if inrange(year, 1880, 1880) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65i`country' = pop999i`country' *0.04215123 if inrange(year, 1890, 1890) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65i`country' = pop999i`country' *0.04216803 if inrange(year, 1900, 1900) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65i`country' = pop999i`country' *0.04165042 if inrange(year, 1910, 1910) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65i`country' = pop999i`country' *0.04113282 if inrange(year, 1920, 1920) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65i`country' = pop999i`country' *0.04061522 if inrange(year, 1930, 1930) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65i`country' = pop999i`country' *0.04196071 if inrange(year, 1940, 1940) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")




* SSEA old age based on International Historical Statistics
replace pop65i`country' = pop999i`country' *0.0232869666666667 if inrange(year, 1800, 1800) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65i`country' = pop999i`country' *0.023049 if inrange(year, 1810, 1810) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65i`country' = pop999i`country' *0.02309801 if inrange(year, 1820, 1820) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65i`country' = pop999i`country' *0.02314701 if inrange(year, 1830, 1830) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65i`country' = pop999i`country' *0.02319601 if inrange(year, 1840, 1840) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65i`country' = pop999i`country' *0.02324502 if inrange(year, 1850, 1850) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65i`country' = pop999i`country' *0.02329402 if inrange(year, 1860, 1860) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65i`country' = pop999i`country' *0.02334303 if inrange(year, 1870, 1870) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65i`country' = pop999i`country' *0.02339203 if inrange(year, 1880, 1880) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65i`country' = pop999i`country' *0.02344103 if inrange(year, 1890, 1890) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65i`country' = pop999i`country' *0.02349004 if inrange(year, 1900, 1900) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65i`country' = pop999i`country' *0.02353904 if inrange(year, 1910, 1910) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65i`country' = pop999i`country' *0.02462164 if inrange(year, 1920, 1920) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65i`country' = pop999i`country' *0.02170027 if inrange(year, 1930, 1930) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65i`country' = pop999i`country' *0.02779463 if inrange(year, 1940, 1940) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")


* SSAF old age based on International Historical Statistics
replace pop65i`country' = pop999i`country' *0.0399332 if inrange(year, 1800, 1800) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ" | "`country'" == "ESAF" | "`country'" == "WCAF") 
replace pop65i`country' = pop999i`country' *0.03984492 if inrange(year, 1810, 1810) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65i`country' = pop999i`country' *0.03968983 if inrange(year, 1820, 1820) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65i`country' = pop999i`country' *0.03953475 if inrange(year, 1830, 1830) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65i`country' = pop999i`country' *0.03937967 if inrange(year, 1840, 1840) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65i`country' = pop999i`country' *0.03922459 if inrange(year, 1850, 1850) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65i`country' = pop999i`country' *0.03906951 if inrange(year, 1860, 1860) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65i`country' = pop999i`country' *0.03891442 if inrange(year, 1870, 1870) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65i`country' = pop999i`country' *0.03875934 if inrange(year, 1880, 1880) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65i`country' = pop999i`country' *0.03860426 if inrange(year, 1890, 1890) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65i`country' = pop999i`country' *0.03844918 if inrange(year, 1900, 1900) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65i`country' = pop999i`country' *0.0382941 if inrange(year, 1910, 1910) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65i`country' = pop999i`country' *0.03813901 if inrange(year, 1920, 1920) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65i`country' = pop999i`country' *0.03798393 if inrange(year, 1930, 1930) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65i`country' = pop999i`country' *0.04188252 if inrange(year, 1940, 1940) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")

*interpolate
ipolate pop65i`country' year, gen(pop65i`country'_2) epolate
drop pop65i`country'
ren pop65i`country'_2 pop65i`country'		
}
drop pop997i* 
tsline pop65iEURO , xline(1950)


**# 15-64i Computation
foreach country in WO EURO NAOC LATA MENA SSAF RUCA EASA SSEA DE FR GB IT ES SE OC QM US CA AU NZ OH AR BR CL CO MX OD TR EG DZ OE ZA OJ RU OA CN JP OB IN ID OI ESAF WCAF SEAS SAS{
	*Generate working age all 15-64 as the addition of 20-64 (996i) and 15-19 (151i)
			g pop15_64i`country'=pop999i`country'-(pop0_14i`country'+pop65i`country')
}			
tsline pop15_64iNAOC , xline(1950)	



**# 999f female all Computation
foreach country in WO EURO NAOC LATA MENA SSAF RUCA EASA SSEA DE FR GB IT ES SE OC QM US CA AU NZ OH AR BR CL CO MX OD TR EG DZ OE ZA OJ RU OA CN JP OB IN ID OI ESAF WCAF SEAS SAS{
	
	
*Generate total female pop. 1800-1949 		
* EASA female based on International Historical Statistics
replace pop999f`country' = pop999i`country' *0.49000001 if inrange(year, 1800, 1800) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop999f`country' = pop999i`country' *0.49034913 if inrange(year, 1810, 1810) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop999f`country' = pop999i`country' *0.49069824 if inrange(year, 1820, 1820) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop999f`country' = pop999i`country' *0.49104736 if inrange(year, 1830, 1830) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop999f`country' = pop999i`country' *0.49139648 if inrange(year, 1840, 1840) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop999f`country' = pop999i`country' *0.4917456 if inrange(year, 1850, 1850) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop999f`country' = pop999i`country' *0.49209471 if inrange(year, 1860, 1860) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop999f`country' = pop999i`country' *0.49244383 if inrange(year, 1870, 1870) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop999f`country' = pop999i`country' *0.49360147 if inrange(year, 1880, 1880) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop999f`country' = pop999i`country' *0.4949376 if inrange(year, 1890, 1890) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop999f`country' = pop999i`country' *0.49709216 if inrange(year, 1900, 1900) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop999f`country' = pop999i`country' *0.49882075 if inrange(year, 1910, 1910) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop999f`country' = pop999i`country' *0.49888319 if inrange(year, 1920, 1920) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop999f`country' = pop999i`country' *0.49743986 if inrange(year, 1930, 1930) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop999f`country' = pop999i`country' *0.4975 if inrange(year, 1940, 1940) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )



* EURO female based on International Historical Statistics
replace pop999f`country' = pop999i`country' *0.520187 if inrange(year, 1800, 1800) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop999f`country' = pop999i`country' *0.5224884 if inrange(year, 1810, 1810) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop999f`country' = pop999i`country' *0.5206065 if inrange(year, 1820, 1820) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop999f`country' = pop999i`country' *0.5186087 if inrange(year, 1830, 1830) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop999f`country' = pop999i`country' *0.5147094 if inrange(year, 1840, 1840) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop999f`country' = pop999i`country' *0.515098 if inrange(year, 1850, 1850) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop999f`country' = pop999i`country' *0.5125905 if inrange(year, 1860, 1860) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop999f`country' = pop999i`country' *0.5080325 if inrange(year, 1870, 1870) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop999f`country' = pop999i`country' *0.5086355 if inrange(year, 1880, 1880) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop999f`country' = pop999i`country' *0.5088542 if inrange(year, 1890, 1890) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop999f`country' = pop999i`country' *0.5078993 if inrange(year, 1900, 1900) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop999f`country' = pop999i`country' *0.5068641 if inrange(year, 1910, 1910) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop999f`country' = pop999i`country' *0.5113947 if inrange(year, 1920, 1920) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop999f`country' = pop999i`country' *0.5107395 if inrange(year, 1930, 1930) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop999f`country' = pop999i`country' *0.5138541 if inrange(year, 1940, 1940) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")


* LATA female based on International Historical Statistics
replace pop999f`country' = pop999i`country' *0.509 if inrange(year, 1800, 1800) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop999f`country' = pop999i`country' *0.50999999 if inrange(year, 1810, 1810) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop999f`country' = pop999i`country' *0.5117982 if inrange(year, 1820, 1820) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop999f`country' = pop999i`country' *0.51276743 if inrange(year, 1830, 1830) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop999f`country' = pop999i`country' *0.51373667 if inrange(year, 1840, 1840) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop999f`country' = pop999i`country' *0.5147059 if inrange(year, 1850, 1850) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop999f`country' = pop999i`country' *0.50930774 if inrange(year, 1860, 1860) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop999f`country' = pop999i`country' *0.50390965 if inrange(year, 1870, 1870) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop999f`country' = pop999i`country' *0.50534746 if inrange(year, 1880, 1880) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop999f`country' = pop999i`country' *0.50678527 if inrange(year, 1890, 1890) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop999f`country' = pop999i`country' *0.50822309 if inrange(year, 1900, 1900) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop999f`country' = pop999i`country' *0.5096609 if inrange(year, 1910, 1910) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop999f`country' = pop999i`country' *0.50333047 if inrange(year, 1920, 1920) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop999f`country' = pop999i`country' *0.50384861 if inrange(year, 1930, 1930) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop999f`country' = pop999i`country' *0.50436682 if inrange(year, 1940, 1940) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")



* MENA female based on International Historical Statistics
replace pop999f`country' = pop999i`country' *0.5 if inrange(year, 1800, 1800) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop999f`country' = pop999i`country' *0.50116572 if inrange(year, 1810, 1810) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop999f`country' = pop999i`country' *0.50233145 if inrange(year, 1820, 1820) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop999f`country' = pop999i`country' *0.50349717 if inrange(year, 1830, 1830) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop999f`country' = pop999i`country' *0.50466289 if inrange(year, 1840, 1840) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop999f`country' = pop999i`country' *0.50582861 if inrange(year, 1850, 1850) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop999f`country' = pop999i`country' *0.50699434 if inrange(year, 1860, 1860) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop999f`country' = pop999i`country' *0.50816006 if inrange(year, 1870, 1870) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop999f`country' = pop999i`country' *0.50932578 if inrange(year, 1880, 1880) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop999f`country' = pop999i`country' *0.51049151 if inrange(year, 1890, 1890) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop999f`country' = pop999i`country' *0.51165723 if inrange(year, 1900, 1900) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop999f`country' = pop999i`country' *0.51282295 if inrange(year, 1910, 1910) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop999f`country' = pop999i`country' *0.51398867 if inrange(year, 1920, 1920) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop999f`country' = pop999i`country' *0.51003462 if inrange(year, 1930, 1930) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop999f`country' = pop999i`country' *0.5065937 if inrange(year, 1940, 1940) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")



* NAOC female based on International Historical Statistics
replace pop999f`country' = pop999i`country' *0.4879182 if inrange(year, 1800, 1800) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop999f`country' = pop999i`country' *0.4901894 if inrange(year, 1810, 1810) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop999f`country' = pop999i`country' *0.4918596 if inrange(year, 1820, 1820) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop999f`country' = pop999i`country' *0.4927266 if inrange(year, 1830, 1830) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop999f`country' = pop999i`country' *0.4911222 if inrange(year, 1840, 1840) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop999f`country' = pop999i`country' *0.4896454 if inrange(year, 1850, 1850) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop999f`country' = pop999i`country' *0.4890124 if inrange(year, 1860, 1860) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop999f`country' = pop999i`country' *0.4951259 if inrange(year, 1870, 1870) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop999f`country' = pop999i`country' *0.4901274 if inrange(year, 1880, 1880) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop999f`country' = pop999i`country' *0.4890444 if inrange(year, 1890, 1890) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop999f`country' = pop999i`country' *0.4900157 if inrange(year, 1900, 1900) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop999f`country' = pop999i`country' *0.4862623 if inrange(year, 1910, 1910) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop999f`country' = pop999i`country' *0.4906834 if inrange(year, 1920, 1920) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop999f`country' = pop999i`country' *0.4943892 if inrange(year, 1930, 1930) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop999f`country' = pop999i`country' *0.4975571 if inrange(year, 1940, 1940) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")



* RUCA female based on International Historical Statistics
replace pop999f`country' = pop999i`country' *0.5 if inrange(year, 1800, 1800) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA") 
replace pop999f`country' = pop999i`country' *0.50115616 if inrange(year, 1810, 1810) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop999f`country' = pop999i`country' *0.50231233 if inrange(year, 1820, 1820) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop999f`country' = pop999i`country' *0.50346849 if inrange(year, 1830, 1830) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop999f`country' = pop999i`country' *0.50462466 if inrange(year, 1840, 1840) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop999f`country' = pop999i`country' *0.50578082 if inrange(year, 1850, 1850) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop999f`country' = pop999i`country' *0.50693699 if inrange(year, 1860, 1860) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop999f`country' = pop999i`country' *0.50809315 if inrange(year, 1870, 1870) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop999f`country' = pop999i`country' *0.50924932 if inrange(year, 1880, 1880) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop999f`country' = pop999i`country' *0.51040548 if inrange(year, 1890, 1890) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop999f`country' = pop999i`country' *0.51201841 if inrange(year, 1900, 1900) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop999f`country' = pop999i`country' *0.51363134 if inrange(year, 1910, 1910) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop999f`country' = pop999i`country' *0.51524428 if inrange(year, 1920, 1920) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop999f`country' = pop999i`country' *0.51685721 if inrange(year, 1930, 1930) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop999f`country' = pop999i`country' *0.52093339 if inrange(year, 1940, 1940) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")




* SSEA female based on International Historical Statistics
replace pop999f`country' = pop999i`country' *0.484 if inrange(year, 1800, 1800) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS"| "`country'" == "OI")
replace pop999f`country' = pop999i`country' *0.48456414 if inrange(year, 1810, 1810) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS"| "`country'" == "OI")
replace pop999f`country' = pop999i`country' *0.48512828 if inrange(year, 1820, 1820) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS"| "`country'" == "OI")
replace pop999f`country' = pop999i`country' *0.48569242 if inrange(year, 1830, 1830) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS"| "`country'" == "OI")
replace pop999f`country' = pop999i`country' *0.48625655 if inrange(year, 1840, 1840) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS"| "`country'" == "OI")
replace pop999f`country' = pop999i`country' *0.48682069 if inrange(year, 1850, 1850) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS"| "`country'" == "OI")
replace pop999f`country' = pop999i`country' *0.48738483 if inrange(year, 1860, 1860) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS"| "`country'" == "OI")
replace pop999f`country' = pop999i`country' *0.48794897 if inrange(year, 1870, 1870) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS"| "`country'" == "OI")
replace pop999f`country' = pop999i`country' *0.48851311 if inrange(year, 1880, 1880) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS"| "`country'" == "OI")
replace pop999f`country' = pop999i`country' *0.4892098 if inrange(year, 1890, 1890) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS"| "`country'" == "OI")
replace pop999f`country' = pop999i`country' *0.4906331 if inrange(year, 1900, 1900) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS"| "`country'" == "OI")
replace pop999f`country' = pop999i`country' *0.48806158 if inrange(year, 1910, 1910) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS"| "`country'" == "OI")
replace pop999f`country' = pop999i`country' *0.48572916 if inrange(year, 1920, 1920) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS"| "`country'" == "OI")
replace pop999f`country' = pop999i`country' *0.48448327 if inrange(year, 1930, 1930) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS"| "`country'" == "OI")
replace pop999f`country' = pop999i`country' *0.48322099 if inrange(year, 1940, 1940) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS"| "`country'" == "OI")

* SSAF female based on International Historical Statistics
replace pop999f`country' = pop999i`country' *0.49000001 if inrange(year, 1800, 1800) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ" | "`country'" == "ESAF" | "`country'" == "WCAF") 
replace pop999f`country' = pop999i`country' *0.49051649 if inrange(year, 1810, 1810) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop999f`country' = pop999i`country' *0.49103296 if inrange(year, 1820, 1820) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop999f`country' = pop999i`country' *0.49154944 if inrange(year, 1830, 1830) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop999f`country' = pop999i`country' *0.49206592 if inrange(year, 1840, 1840) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop999f`country' = pop999i`country' *0.4925824 if inrange(year, 1850, 1850) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop999f`country' = pop999i`country' *0.49309887 if inrange(year, 1860, 1860) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop999f`country' = pop999i`country' *0.49361535 if inrange(year, 1870, 1870) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop999f`country' = pop999i`country' *0.49413183 if inrange(year, 1880, 1880) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop999f`country' = pop999i`country' *0.49464831 if inrange(year, 1890, 1890) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop999f`country' = pop999i`country' *0.48173913 if inrange(year, 1900, 1900) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop999f`country' = pop999i`country' *0.48618785 if inrange(year, 1910, 1910) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop999f`country' = pop999i`country' *0.48953372 if inrange(year, 1920, 1920) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop999f`country' = pop999i`country' *0.49717513 if inrange(year, 1930, 1930) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop999f`country' = pop999i`country' *0.49150315 if inrange(year, 1940, 1940) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")


ipolate pop999f`country' year, gen(pop999f`country'_2) epolate
drop pop999f`country'
ren pop999f`country'_2 pop999f`country'	
}			
tsline pop999fNAOC , xline(1950)			
			
			
			
**# 0-14f Assumption
*Generate young age female 0-14 as the addition of 0-4 (001f), 5-9 (051f), and 10-14 (101f)
foreach country in WO EURO NAOC LATA MENA SSAF RUCA EASA SSEA DE FR GB IT ES SE OC QM US CA AU NZ OH AR BR CL CO MX OD TR EG DZ OE ZA OJ RU OA CN JP OB IN ID OI ESAF WCAF SEAS SAS{
	
	g pop0_14f`country'=pop001f`country'+pop051f`country'+pop101f`country'	if year>=1950			
	
* EASA young female based on International Historical Statistics
	replace pop0_14f`country' = pop0_14i`country' *0.49455374 if inrange(year, 1800, 1800) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14f`country' = pop0_14i`country' *0.49441564 if inrange(year, 1810, 1810) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14f`country' = pop0_14i`country' *0.49328989 if inrange(year, 1820, 1820) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14f`country' = pop0_14i`country' *0.49326825 if inrange(year, 1830, 1830) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14f`country' = pop0_14i`country' *0.48793262 if inrange(year, 1840, 1840) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14f`country' = pop0_14i`country' *0.49343723 if inrange(year, 1850, 1850) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14f`country' = pop0_14i`country' *0.49282449 if inrange(year, 1860, 1860) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14f`country' = pop0_14i`country' *0.4982 if inrange(year, 1870, 1870) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14f`country' = pop0_14i`country' *0.49774422 if inrange(year, 1880, 1880) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14f`country' = pop0_14i`country' *0.49728844 if inrange(year, 1890, 1890) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14f`country' = pop0_14i`country' *0.49683265 if inrange(year, 1900, 1900) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14f`country' = pop0_14i`country' *0.49637687 if inrange(year, 1910, 1910) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14f`country' = pop0_14i`country' *0.49592109 if inrange(year, 1920, 1920) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14f`country' = pop0_14i`country' *0.49546531 if inrange(year, 1930, 1930) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop0_14f`country' = pop0_14i`country' *0.49500953 if inrange(year, 1940, 1940) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )


* EURO young female based on International Historical Statistics
replace pop0_14f`country' = pop0_14i`country' *0.4981944 if inrange(year, 1800, 1800) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14f`country' = pop0_14i`country' *0.4993412 if inrange(year, 1810, 1810) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14f`country' = pop0_14i`country' *0.5 if inrange(year, 1820, 1820) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14f`country' = pop0_14i`country' *0.4979622 if inrange(year, 1830, 1830) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14f`country' = pop0_14i`country' *0.4975924 if inrange(year, 1840, 1840) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14f`country' = pop0_14i`country' *0.495779 if inrange(year, 1850, 1850) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14f`country' = pop0_14i`country' *0.4950726 if inrange(year, 1860, 1860) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14f`country' = pop0_14i`country' *0.4959994 if inrange(year, 1870, 1870) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14f`country' = pop0_14i`country' *0.4945696 if inrange(year, 1880, 1880) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14f`country' = pop0_14i`country' *0.4951617 if inrange(year, 1890, 1890) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14f`country' = pop0_14i`country' *0.49787 if inrange(year, 1900, 1900) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14f`country' = pop0_14i`country' *0.4962043 if inrange(year, 1910, 1910) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14f`country' = pop0_14i`country' *0.4949856 if inrange(year, 1920, 1920) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14f`country' = pop0_14i`country' *0.4934495 if inrange(year, 1930, 1930) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop0_14f`country' = pop0_14i`country' *0.4923318 if inrange(year, 1940, 1940) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")


* LATA young female based on International Historical Statistics
replace pop0_14f`country' = pop0_14i`country' *0.487566 if inrange(year, 1800, 1800) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14f`country' = pop0_14i`country' *0.488066 if inrange(year, 1810, 1810) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14f`country' = pop0_14i`country' *0.488566 if inrange(year, 1820, 1820) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14f`country' = pop0_14i`country' *0.489066 if inrange(year, 1830, 1830) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14f`country' = pop0_14i`country' *0.489566 if inrange(year, 1840, 1840) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14f`country' = pop0_14i`country' *0.490066 if inrange(year, 1850, 1850) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14f`country' = pop0_14i`country' *0.490566 if inrange(year, 1860, 1860) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14f`country' = pop0_14i`country' *0.4880932 if inrange(year, 1870, 1870) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14f`country' = pop0_14i`country' *0.49029273 if inrange(year, 1880, 1880) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14f`country' = pop0_14i`country' *0.4924923 if inrange(year, 1890, 1890) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14f`country' = pop0_14i`country' *0.490134 if inrange(year, 1900, 1900) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14f`country' = pop0_14i`country' *0.4925804 if inrange(year, 1910, 1910) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14f`country' = pop0_14i`country' *0.493071 if inrange(year, 1920, 1920) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14f`country' = pop0_14i`country' *0.494488 if inrange(year, 1930, 1930) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop0_14f`country' = pop0_14i`country' *0.4911416 if inrange(year, 1940, 1940) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")



* MENA young female based on International Historical Statistics
replace pop0_14f`country' = pop0_14i`country' *0.49000001 if inrange(year, 1800, 1800) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14f`country' = pop0_14i`country' *0.48952298 if inrange(year, 1810, 1810) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14f`country' = pop0_14i`country' *0.48904596 if inrange(year, 1820, 1820) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14f`country' = pop0_14i`country' *0.48856893 if inrange(year, 1830, 1830) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14f`country' = pop0_14i`country' *0.48809191 if inrange(year, 1840, 1840) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14f`country' = pop0_14i`country' *0.48761488 if inrange(year, 1850, 1850) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14f`country' = pop0_14i`country' *0.48713785 if inrange(year, 1860, 1860) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14f`country' = pop0_14i`country' *0.48666083 if inrange(year, 1870, 1870) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14f`country' = pop0_14i`country' *0.4861838 if inrange(year, 1880, 1880) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14f`country' = pop0_14i`country' *0.48570678 if inrange(year, 1890, 1890) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14f`country' = pop0_14i`country' *0.48522975 if inrange(year, 1900, 1900) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14f`country' = pop0_14i`country' *0.48475272 if inrange(year, 1910, 1910) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14f`country' = pop0_14i`country' *0.4842757 if inrange(year, 1920, 1920) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14f`country' = pop0_14i`country' *0.48948619 if inrange(year, 1930, 1930) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop0_14f`country' = pop0_14i`country' *0.49229041 if inrange(year, 1940, 1940) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")




* NAOC young female based on International Historical Statistics
replace pop0_14f`country' = pop0_14i`country' *0.49000001 if inrange(year, 1800, 1800) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14f`country' = pop0_14i`country' *0.49015848 if inrange(year, 1810, 1810) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14f`country' = pop0_14i`country' *0.49031695 if inrange(year, 1820, 1820) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14f`country' = pop0_14i`country' *0.49047542 if inrange(year, 1830, 1830) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14f`country' = pop0_14i`country' *0.49086842 if inrange(year, 1840, 1840) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14f`country' = pop0_14i`country' *0.49167484 if inrange(year, 1850, 1850) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14f`country' = pop0_14i`country' *0.49247187 if inrange(year, 1860, 1860) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14f`country' = pop0_14i`country' *0.49363762 if inrange(year, 1870, 1870) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14f`country' = pop0_14i`country' *0.49431801 if inrange(year, 1880, 1880) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14f`country' = pop0_14i`country' *0.49398881 if inrange(year, 1890, 1890) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14f`country' = pop0_14i`country' *0.49358824 if inrange(year, 1900, 1900) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14f`country' = pop0_14i`country' *0.49316955 if inrange(year, 1910, 1910) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14f`country' = pop0_14i`country' *0.49450076 if inrange(year, 1920, 1920) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14f`country' = pop0_14i`country' *0.4923383 if inrange(year, 1930, 1930) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop0_14f`country' = pop0_14i`country' *0.4915446 if inrange(year, 1940, 1940) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")


* RUCA young female based on International Historical Statistics
replace pop0_14f`country' = pop0_14i`country' *0.49599999 if inrange(year, 1800, 1800) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA") 
replace pop0_14f`country' = pop0_14i`country' *0.49667768 if inrange(year, 1810, 1810) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14f`country' = pop0_14i`country' *0.49735537 if inrange(year, 1820, 1820) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14f`country' = pop0_14i`country' *0.49803305 if inrange(year, 1830, 1830) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14f`country' = pop0_14i`country' *0.49871074 if inrange(year, 1840, 1840) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14f`country' = pop0_14i`country' *0.49938843 if inrange(year, 1850, 1850) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14f`country' = pop0_14i`country' *0.50006611 if inrange(year, 1860, 1860) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14f`country' = pop0_14i`country' *0.5007438 if inrange(year, 1870, 1870) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14f`country' = pop0_14i`country' *0.50142149 if inrange(year, 1880, 1880) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14f`country' = pop0_14i`country' *0.50209917 if inrange(year, 1890, 1890) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14f`country' = pop0_14i`country' *0.50277686 if inrange(year, 1900, 1900) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14f`country' = pop0_14i`country' *0.50069916 if inrange(year, 1910, 1910) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14f`country' = pop0_14i`country' *0.49862146 if inrange(year, 1920, 1920) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14f`country' = pop0_14i`country' *0.49654377 if inrange(year, 1930, 1930) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop0_14f`country' = pop0_14i`country' *0.49871439 if inrange(year, 1940, 1940) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")





* SSEA young female based on International Historical Statistics
replace pop0_14f`country' = pop0_14i`country' *0.48500001 if inrange(year, 1800, 1800) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14f`country' = pop0_14i`country' *0.48432887 if inrange(year, 1810, 1810) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14f`country' = pop0_14i`country' *0.48365773 if inrange(year, 1820, 1820) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14f`country' = pop0_14i`country' *0.48298659 if inrange(year, 1830, 1830) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14f`country' = pop0_14i`country' *0.48231545 if inrange(year, 1840, 1840) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14f`country' = pop0_14i`country' *0.48164431 if inrange(year, 1850, 1850) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14f`country' = pop0_14i`country' *0.48097317 if inrange(year, 1860, 1860) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14f`country' = pop0_14i`country' *0.48030203 if inrange(year, 1870, 1870) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14f`country' = pop0_14i`country' *0.47963089 if inrange(year, 1880, 1880) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14f`country' = pop0_14i`country' *0.47722772 if inrange(year, 1890, 1890) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14f`country' = pop0_14i`country' *0.48310527 if inrange(year, 1900, 1900) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14f`country' = pop0_14i`country' *0.48364788 if inrange(year, 1910, 1910) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14f`country' = pop0_14i`country' *0.48373771 if inrange(year, 1920, 1920) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14f`country' = pop0_14i`country' *0.48511103 if inrange(year, 1930, 1930) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop0_14f`country' = pop0_14i`country' *0.48648435 if inrange(year, 1940, 1940) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")




* SSAF young female based on International Historical Statistics
replace pop0_14f`country' = pop0_14i`country' *0.49813351 if inrange(year, 1800, 1800) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ" | "`country'" == "ESAF" | "`country'" == "WCAF") 
replace pop0_14f`country' = pop0_14i`country' *0.49764714 if inrange(year, 1810, 1810) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14f`country' = pop0_14i`country' *0.49716078 if inrange(year, 1820, 1820) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14f`country' = pop0_14i`country' *0.49667441 if inrange(year, 1830, 1830) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14f`country' = pop0_14i`country' *0.49618804 if inrange(year, 1840, 1840) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14f`country' = pop0_14i`country' *0.49570167 if inrange(year, 1850, 1850) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14f`country' = pop0_14i`country' *0.49521531 if inrange(year, 1860, 1860) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14f`country' = pop0_14i`country' *0.49472894 if inrange(year, 1870, 1870) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14f`country' = pop0_14i`country' *0.49424257 if inrange(year, 1880, 1880) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14f`country' = pop0_14i`country' *0.4937562 if inrange(year, 1890, 1890) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14f`country' = pop0_14i`country' *0.49326984 if inrange(year, 1900, 1900) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14f`country' = pop0_14i`country' *0.49278347 if inrange(year, 1910, 1910) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14f`country' = pop0_14i`country' *0.4922971 if inrange(year, 1920, 1920) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14f`country' = pop0_14i`country' *0.49181073 if inrange(year, 1930, 1930) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop0_14f`country' = pop0_14i`country' *0.49132437 if inrange(year, 1940, 1940) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
	
		
		
ipolate pop0_14f`country' year, gen(pop0_14f`country'_2) epolate
drop pop0_14f`country' pop001f`country' pop051f`country' pop101f`country'
ren pop0_14f`country'_2 pop0_14f`country'		
	
}
tsline pop0_14fNAOC , xline(1950)	
	
	
	
**# 65+f Assumption
		*Generate old age female 65+ 
foreach country in WO EURO NAOC LATA MENA SSAF RUCA EASA SSEA DE FR GB IT ES SE OC QM US CA AU NZ OH AR BR CL CO MX OD TR EG DZ OE ZA OJ RU OA CN JP OB IN ID OI ESAF WCAF SEAS SAS{
	
	g pop65f`country'=pop997f`country' if year>=1950

* EASA old age female based on International Historical Statistics	
replace pop65f`country' = pop65i`country' *0.5117 if inrange(year, 1800, 1800) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65f`country' = pop65i`country' *0.51563297 if inrange(year, 1810, 1810) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65f`country' = pop65i`country' *0.51956594 if inrange(year, 1820, 1820) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65f`country' = pop65i`country' *0.52349892 if inrange(year, 1830, 1830) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65f`country' = pop65i`country' *0.52743189 if inrange(year, 1840, 1840) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65f`country' = pop65i`country' *0.53136486 if inrange(year, 1850, 1850) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65f`country' = pop65i`country' *0.53529783 if inrange(year, 1860, 1860) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65f`country' = pop65i`country' *0.5392308 if inrange(year, 1870, 1870) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65f`country' = pop65i`country' *0.54316378 if inrange(year, 1880, 1880) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65f`country' = pop65i`country' *0.54708719 if inrange(year, 1890, 1890) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65f`country' = pop65i`country' *0.54695904 if inrange(year, 1900, 1900) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65f`country' = pop65i`country' *0.55115768 if inrange(year, 1910, 1910) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65f`country' = pop65i`country' *0.55535632 if inrange(year, 1920, 1920) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65f`country' = pop65i`country' *0.55955496 if inrange(year, 1930, 1930) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )
replace pop65f`country' = pop65i`country' *0.5637536 if inrange(year, 1940, 1940) & ("`country'" == "EASA" | "`country'" == "CN" | "`country'" == "JP" | "`country'" == "OB" )


* EURO old age female based on International Historical Statistics	
replace pop65f`country' = pop65i`country' *0.5725158 if inrange(year, 1800, 1800) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65f`country' = pop65i`country' *0.5772358 if inrange(year, 1810, 1810) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65f`country' = pop65i`country' *0.5869565 if inrange(year, 1820, 1820) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65f`country' = pop65i`country' *0.5743088 if inrange(year, 1830, 1830) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65f`country' = pop65i`country' *0.5694101 if inrange(year, 1840, 1840) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65f`country' = pop65i`country' *0.557776 if inrange(year, 1850, 1850) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65f`country' = pop65i`country' *0.5483316 if inrange(year, 1860, 1860) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65f`country' = pop65i`country' *0.5398226 if inrange(year, 1870, 1870) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65f`country' = pop65i`country' *0.5274523 if inrange(year, 1880, 1880) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65f`country' = pop65i`country' *0.5239621 if inrange(year, 1890, 1890) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65f`country' = pop65i`country' *0.5285069 if inrange(year, 1900, 1900) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65f`country' = pop65i`country' *0.5422131 if inrange(year, 1910, 1910) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65f`country' = pop65i`country' *0.5487913 if inrange(year, 1920, 1920) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65f`country' = pop65i`country' *0.5443902 if inrange(year, 1930, 1930) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")
replace pop65f`country' = pop65i`country' *0.5471739 if inrange(year, 1940, 1940) & ("`country'" == "EURO" | "`country'" == "DE" | "`country'" == "FR" | "`country'" == "GB" | "`country'" == "IT" | "`country'" == "ES" | "`country'" == "SE" | "`country'" == "OC" | "`country'" == "QM")


* LATA old age female based on International Historical Statistics	
replace pop65f`country' = pop65i`country' *0.4813 if inrange(year, 1800, 1800) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65f`country' = pop65i`country' *0.48477158 if inrange(year, 1810, 1810) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65f`country' = pop65i`country' *0.48824316 if inrange(year, 1820, 1820) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65f`country' = pop65i`country' *0.49171474 if inrange(year, 1830, 1830) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65f`country' = pop65i`country' *0.49518632 if inrange(year, 1840, 1840) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65f`country' = pop65i`country' *0.4986579 if inrange(year, 1850, 1850) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65f`country' = pop65i`country' *0.50212948 if inrange(year, 1860, 1860) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65f`country' = pop65i`country' *0.50560106 if inrange(year, 1870, 1870) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65f`country' = pop65i`country' *0.50907263 if inrange(year, 1880, 1880) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65f`country' = pop65i`country' *0.51591289 if inrange(year, 1890, 1890) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65f`country' = pop65i`country' *0.51220477 if inrange(year, 1900, 1900) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65f`country' = pop65i`country' *0.51555687 if inrange(year, 1910, 1910) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65f`country' = pop65i`country' *0.52408105 if inrange(year, 1920, 1920) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65f`country' = pop65i`country' *0.5274024 if inrange(year, 1930, 1930) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")
replace pop65f`country' = pop65i`country' *0.5269596 if inrange(year, 1940, 1940) & ("`country'" == "LATA" | "`country'" == "AR" | "`country'" == "BR" | "`country'" == "CL" | "`country'" == "CO" | "`country'" == "MX" | "`country'" == "OD")



* MENA old age female based on International Historical Statistics	
replace pop65f`country' = pop65i`country' *0.54540002 if inrange(year, 1800, 1800) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65f`country' = pop65i`country' *0.54548861 if inrange(year, 1810, 1810) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65f`country' = pop65i`country' *0.54557721 if inrange(year, 1820, 1820) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65f`country' = pop65i`country' *0.5456658 if inrange(year, 1830, 1830) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65f`country' = pop65i`country' *0.54575439 if inrange(year, 1840, 1840) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65f`country' = pop65i`country' *0.54584298 if inrange(year, 1850, 1850) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65f`country' = pop65i`country' *0.54593157 if inrange(year, 1860, 1860) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65f`country' = pop65i`country' *0.54602016 if inrange(year, 1870, 1870) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65f`country' = pop65i`country' *0.54610875 if inrange(year, 1880, 1880) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65f`country' = pop65i`country' *0.54619734 if inrange(year, 1890, 1890) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65f`country' = pop65i`country' *0.54628593 if inrange(year, 1900, 1900) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65f`country' = pop65i`country' *0.54637452 if inrange(year, 1910, 1910) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65f`country' = pop65i`country' *0.54646311 if inrange(year, 1920, 1920) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65f`country' = pop65i`country' *0.5465517 if inrange(year, 1930, 1930) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")
replace pop65f`country' = pop65i`country' *0.54436862 if inrange(year, 1940, 1940) & ("`country'" == "MENA" | "`country'" == "TR" | "`country'" == "EG" | "`country'" == "DZ" | "`country'" == "OE")



* NAOC old age female based on International Historical Statistics	
replace pop65f`country' = pop65i`country' *0.4887 if inrange(year, 1800, 1800) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65f`country' = pop65i`country' *0.49012844 if inrange(year, 1810, 1810) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65f`country' = pop65i`country' *0.49155687 if inrange(year, 1820, 1820) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65f`country' = pop65i`country' *0.4929853 if inrange(year, 1830, 1830) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65f`country' = pop65i`country' *0.49441374 if inrange(year, 1840, 1840) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65f`country' = pop65i`country' *0.49584217 if inrange(year, 1850, 1850) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65f`country' = pop65i`country' *0.49727061 if inrange(year, 1860, 1860) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65f`country' = pop65i`country' *0.49869904 if inrange(year, 1870, 1870) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65f`country' = pop65i`country' *0.49611399 if inrange(year, 1880, 1880) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65f`country' = pop65i`country' *0.48944101 if inrange(year, 1890, 1890) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65f`country' = pop65i`country' *0.49527535 if inrange(year, 1900, 1900) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65f`country' = pop65i`country' *0.49745807 if inrange(year, 1910, 1910) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65f`country' = pop65i`country' *0.49715099 if inrange(year, 1920, 1920) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65f`country' = pop65i`country' *0.49901709 if inrange(year, 1930, 1930) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")
replace pop65f`country' = pop65i`country' *0.5015325 if inrange(year, 1940, 1940) & ("`country'" == "NAOC" | "`country'" == "US" | "`country'" == "CA" | "`country'" == "AU" | "`country'" == "NZ" | "`country'" == "OH")



* RUCA old age female based on International Historical Statistics	
replace pop65f`country' = pop65i`country' *0.5 if inrange(year, 1800, 1800) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA") 
replace pop65f`country' = pop65i`country' *0.50143437 if inrange(year, 1810, 1810) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65f`country' = pop65i`country' *0.50286875 if inrange(year, 1820, 1820) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65f`country' = pop65i`country' *0.50430312 if inrange(year, 1830, 1830) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65f`country' = pop65i`country' *0.5057375 if inrange(year, 1840, 1840) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65f`country' = pop65i`country' *0.50717187 if inrange(year, 1850, 1850) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65f`country' = pop65i`country' *0.50860624 if inrange(year, 1860, 1860) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65f`country' = pop65i`country' *0.51004062 if inrange(year, 1870, 1870) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65f`country' = pop65i`country' *0.51147499 if inrange(year, 1880, 1880) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65f`country' = pop65i`country' *0.51290936 if inrange(year, 1890, 1890) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65f`country' = pop65i`country' *0.51434374 if inrange(year, 1900, 1900) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65f`country' = pop65i`country' *0.53039583 if inrange(year, 1910, 1910) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65f`country' = pop65i`country' *0.54644791 if inrange(year, 1920, 1920) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65f`country' = pop65i`country' *0.5625 if inrange(year, 1930, 1930) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")
replace pop65f`country' = pop65i`country' *0.58884382 if inrange(year, 1940, 1940) & ("`country'" == "RUCA" | "`country'" == "RU" | "`country'" == "OA")






* SSEA old age female based on International Historical Statistics	
replace pop65f`country' = pop65i`country' *0.51368016 if inrange(year, 1800, 1800) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65f`country' = pop65i`country' *0.51312059 if inrange(year, 1810, 1810) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65f`country' = pop65i`country' *0.51256102 if inrange(year, 1820, 1820) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65f`country' = pop65i`country' *0.51200145 if inrange(year, 1830, 1830) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65f`country' = pop65i`country' *0.51144189 if inrange(year, 1840, 1840) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65f`country' = pop65i`country' *0.51088232 if inrange(year, 1850, 1850) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65f`country' = pop65i`country' *0.51032275 if inrange(year, 1860, 1860) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65f`country' = pop65i`country' *0.50976318 if inrange(year, 1870, 1870) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65f`country' = pop65i`country' *0.50920361 if inrange(year, 1880, 1880) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65f`country' = pop65i`country' *0.50864404 if inrange(year, 1890, 1890) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65f`country' = pop65i`country' *0.50808448 if inrange(year, 1900, 1900) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65f`country' = pop65i`country' *0.5116279 if inrange(year, 1910, 1910) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65f`country' = pop65i`country' *0.504015 if inrange(year, 1920, 1920) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65f`country' = pop65i`country' *0.5 if inrange(year, 1930, 1930) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")
replace pop65f`country' = pop65i`country' *0.5111103 if inrange(year, 1940, 1940) & ("`country'" == "SSEA" | "`country'" == "IN" | "`country'" == "ID" | "`country'" == "SEAS" | "`country'" == "SAS" | "`country'" == "OI")


* SSAF old age female based on International Historical Statistics	
replace pop65f`country' = pop65i`country' *0.5 if inrange(year, 1800, 1800) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ" | "`country'" == "ESAF" | "`country'" == "WCAF") 
replace pop65f`country' = pop65i`country' *0.50126797 if inrange(year, 1810, 1810) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65f`country' = pop65i`country' *0.50253593 if inrange(year, 1820, 1820) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65f`country' = pop65i`country' *0.5038039 if inrange(year, 1830, 1830) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65f`country' = pop65i`country' *0.50507186 if inrange(year, 1840, 1840) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" == "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65f`country' = pop65i`country' *0.50633983 if inrange(year, 1850, 1850) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65f`country' = pop65i`country' *0.50760779 if inrange(year, 1860, 1860) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65f`country' = pop65i`country' *0.50887576 if inrange(year, 1870, 1870) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65f`country' = pop65i`country' *0.51014372 if inrange(year, 1880, 1880) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65f`country' = pop65i`country' *0.51141169 if inrange(year, 1890, 1890) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65f`country' = pop65i`country' *0.51267965 if inrange(year, 1900, 1900) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65f`country' = pop65i`country' *0.51394762 if inrange(year, 1910, 1910) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65f`country' = pop65i`country' *0.51521558 if inrange(year, 1920, 1920) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65f`country' = pop65i`country' *0.51648355 if inrange(year, 1930, 1930) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
replace pop65f`country' = pop65i`country' *0.52620548 if inrange(year, 1940, 1940) & ("`country'" == "SSAF" | "`country'" == "ZA" | "`country'" ==  "OJ"| "`country'" == "ESAF" | "`country'" == "WCAF")
	
	
ipolate pop65f`country' year, gen(pop65f`country'_2) epolate
drop pop65f`country' pop997f`country'
ren pop65f`country'_2 pop65f`country'
}			
tsline pop65fNAOC , xline(1950)		


**# 15-64f Computation
foreach country in WO EURO NAOC LATA MENA SSAF RUCA EASA SSEA DE FR GB IT ES SE OC QM US CA AU NZ OH AR BR CL CO MX OD TR EG DZ OE ZA OJ RU OA CN JP OB IN ID OI ESAF WCAF SEAS SAS{
*Generate working age all 15-64 as the addition of 20-64 (996i) and 15-19 (151i)
			g pop15_64f`country'=pop999f`country'-(pop0_14f`country'+pop65f`country')
}			
tsline pop15_64fNAOC , xline(1950)	




**# Compute region totals accounting for projections
foreach pop in 999i 999f 992i  991i 15_64i 0_14i 65i 15_64f 0_14f 65f{
	drop pop`pop'EURO	
	gen pop`pop'EURO=pop`pop'DE+pop`pop'FR+pop`pop'GB+pop`pop'IT+pop`pop'ES+pop`pop'SE+pop`pop'OC+pop`pop'QM
	
	drop pop`pop'NAOC 
	gen pop`pop'NAOC=pop`pop'US+pop`pop'CA+pop`pop'AU+pop`pop'NZ+pop`pop'OH	
	
	drop pop`pop'LATA
	gen pop`pop'LATA=pop`pop'AR+pop`pop'BR+pop`pop'CL+pop`pop'CO+pop`pop'MX+pop`pop'OD
	
	drop pop`pop'MENA
	gen pop`pop'MENA=pop`pop'TR+pop`pop'EG+pop`pop'DZ+pop`pop'OE
	
	drop pop`pop'SSAF
	gen pop`pop'SSAF=pop`pop'ZA+pop`pop'OJ
	
	drop pop`pop'RUCA
	gen pop`pop'RUCA=pop`pop'RU+pop`pop'OA
	
	drop pop`pop'EASA
	gen pop`pop'EASA=pop`pop'CN+pop`pop'JP+pop`pop'OB
	
	drop pop`pop'SSEA
	gen pop`pop'SSEA=pop`pop'IN+pop`pop'ID+pop`pop'OI	
	
	
*East-Southern Africa
drop pop`pop'ESAF
gen pop`pop'ESAF=pop`pop'SSAF-pop`pop'WCAF 

*South East Asia
drop pop`pop'SEAS
g pop`pop'SEAS=pop`pop'SSEA-pop`pop'SAS

drop pop`pop'WO
	gen pop`pop'WO=pop`pop'EURO+pop`pop'NAOC+pop`pop'LATA+pop`pop'MENA+pop`pop'SSAF+pop`pop'RUCA+pop`pop'EASA+pop`pop'SSEA
}

drop pop996*
drop  pop151*
drop  pop991f*
misstable summarize


reshape long pop999i pop999f pop992i  pop991i pop15_64i pop0_14i pop65i pop15_64f pop0_14f pop65f, i(year ) j(country) string
sort country year



encode country, gen(country_code)

xtset 	country_code year

save "$work_data/pops_1800_2023_UN.dta", replace

drop pop15_64i pop15_64f pop991i
g pop15_64i=pop999i-pop65i-pop0_14i
g pop15_64f=pop999f-pop65f-pop0_14f
g pop991i=pop999i-pop992i

order year country pop999i pop992i pop0_14i pop65i pop999f pop0_14f pop65f pop15_64i pop15_64f pop991i
keep year country pop999i pop992i pop0_14i pop65i pop999f pop0_14f pop65f pop15_64i pop15_64f pop991i
save "$work_data\pop_1800_2100_33coreterritories.dta",replace