
/********Stata code used for the TN:Extending WID Population Series:
Projections 2024-2100 & Age/Gender Breakdowns*********/

/****Creates dataset with UN Projections for 216 countries 1950-2100**/
/****Creates provisional dataset with populations for 57 core territories 1800-2023**/

**# UN Projections 216 countries 1950-2100


use "$work_data/populations.dta", clear
tab year
drop p
ren iso country


gen coreterritory=.
		foreach c of global coreterritories{
			replace coreterritory=1 if country=="`c'"
		}
		gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		keep if (coreterritory==1  | corecountry==1)
		
		keep if inlist(widcode,"npopul999i", "npopul992i", "npopul991i", "npopul996i", "npopul151i","npopul001i") | ///
		inlist(widcode, "npopul051i","npopul101i", "npopul997i") | ///
		inlist(widcode,"npopul999f", "npopul992f", "npopul991f", "npopul996f", "npopul151f","npopul001f") | ///
		inlist(widcode, "npopul051f","npopul101f", "npopul997f")
		keep value year country widcode
		reshape wide value, i(year country) j(widcode) string
		keep if year>=1950
ren valuenpopul* pop*
sort country year 
		
local today = c(current_date)
label data "Poptot and breakdowns for 216 core countries 1800-2100, Dataset created on `today'"		
save "$outputs\widpop_1950_2100_216countries.dta",replace		
	describe	
		
		
		

**# Extended definitions 57 core territories

*Load and extrapolate data from 1800 to 2023
	
		/****importation of WID population series***/ 
		wid, ind(npopul) ag(999) pop(i) clear
		gen coreterritory=.
		foreach c of global coreterritories{
			replace coreterritory=1 if country=="`c'"
		}
		gen corecountry=.
		foreach c of global corecountries{
			replace corecountry=1 if country=="`c'"
		}
		keep if (coreterritory==1 | country=="WO" | corecountry==1)
		rename value poptot
		drop age pop percentile variable coreterritory corecountry
		reshape wide poptot, i(year) j(country) string
		br year poptotNL	poptotNO	poptotDK	poptotKR	poptotTW	poptotIR	poptotMA	poptotSA	poptotAE	poptotBD	poptotMM	poptotPK	poptotPH	poptotTH	poptotVN	poptotCD	poptotET	poptotKE	poptotCI	poptotML	poptotNE	poptotNG	poptotRW	poptotSD //for ChatGPT
		
*Import populations for the new countries for the period 1800-1950 (simulated using WID data 1950-2023)	
		preserve
		import excel using "$root\raw-data\simulated_pops_1800_1950_extended_countries.xlsx",clear firstrow
		ren poptot* poptotGPT*
		save "$work_data\ChatGPopTot_1800_1950_extended_countries.dta",replace 
		restore
		merge 1:1 year using "$work_data\ChatGPopTot_1800_1950_extended_countries.dta"
		drop _merge
		cap erase "$work_data\ChatGPopTot_1800_1950_extended_countries.dta"
		foreach var in NL	NO	DK	KR	TW	IR	MA	SA	AE	BD	MM	PK	PH	TH	VN	CD	ET	KE	CI	ML	NE	NG	RW	SD {
			replace poptot`var'=poptotGPT`var' if poptot`var'==. & year<1950
			drop poptotGPT`var'
		}
		
		
		keep if year==1820 | year==1850 | year==1880 | year==1900 | year==1910 | year==1920 | year==1930 | year==1940 | year==1950 | year==1960 | year==1970 | year>=1980
		sort year
		
		
		**generate other residuals
		*Europe, add (Denmark, Norway, Netherlands) and substract them from OC
		g poptotOC_E=poptotOC-poptotNL-poptotNO-poptotDK
		
		*EASA, add (South Korea and Taiwan) and substract them from OB
		g poptotOB_E=poptotOB-poptotKR-poptotTW
		
		*MENA, add (Iran, Morocco, Saudi Arabia, and UAE) and substract them from OE
		g poptotOE_E=poptotOE-poptotIR-poptotMA-poptotSA-poptotAE
		
		*SSEA, add (Bangladesh, Myanmar, Pakistan, Phillipines, Thailand, Vietnam) and substract them from OI
		g poptotOI_E=poptotOI-poptotBD-poptotMM-poptotPK-poptotPH-poptotTH-poptotVN
		replace poptotOI_E=0 if poptotOI_E<0
		
		*SSAF, add (Congo, Ethiopia, Kenya, Ivory Coast, Mali, Niger, NIgeria, Rwanda, Sudan) and substract them from OI
		g poptotOJ_E=poptotOJ-poptotCD-poptotET-poptotKE-poptotCI-poptotML-poptotNE-poptotNG-poptotRW-poptotSD		
	
sum poptotO*	
		/***sous-totaux regionaux**/
		gen poptotEURO=poptotDE+poptotFR+poptotGB+poptotIT+poptotES+poptotSE+poptotOC+poptotQM
		gen poptotNAOC=poptotUS+poptotCA+poptotAU+poptotNZ+poptotOH
		gen poptotLATA=poptotAR+poptotBR+poptotCL+poptotCO+poptotMX+poptotOD
		gen poptotMENA=poptotTR+poptotEG+poptotDZ+poptotOE
		gen poptotSSAF=poptotZA+poptotOJ
		gen poptotRUCA=poptotRU+poptotOA
		gen poptotEASA=poptotCN+poptotJP+poptotOB
		gen poptotSSEA=poptotIN+poptotID+poptotOI

		*East-Southern Africa
		gen poptotESAF= poptotBI	+poptotBW	+poptotDJ	+poptotER	+poptotET	+poptotKE	+poptotKM	+poptotLS	+poptotMG	+poptotMU	+poptotMW	+poptotMZ	+poptotNA	+poptotRW	+poptotSC	+poptotSD	+poptotSO	+poptotSS	+poptotSZ	+poptotTZ	+poptotUG	+poptotZA	+poptotZM	+poptotZW	/*+poptotZZ*/ //Ricardo subregion:East-Southern Africa

		*West-Central Africa
		gen poptotWCAF= poptotAO	+poptotBF	+poptotBJ	+poptotCD	+poptotCF	+poptotCD	+poptotCI	+poptotCM	+poptotCV	+poptotGA	+poptotGH	+poptotGM	+poptotGN	+poptotGQ	+poptotGW	+poptotLR	+poptotML	+poptotMR	+poptotNE	+poptotNG	/*+poptotSH*/	+poptotSL	+poptotSN	+poptotST	+poptotTD	+poptotTG //Ricardo subregion:West-Central Africa

		*South East Asia
		g poptotSEAS=poptotBN	+poptotID	+poptotKH	+poptotLA	+poptotMM	+poptotMY	+poptotPH	+poptotSG	+poptotTH	+poptotTL	+poptotVN

		*South Asia
		g poptotSAS=poptotAF	+poptotBD	+poptotBT	+poptotIN	+poptotLK	+poptotMV	+poptotNP	+poptotPK

		*Extrapolate to the past maintaining the share in 1950
		foreach var in poptotESAF poptotWCAF{
			g sh`var'=`var'/poptotSSAF
			sum sh`var' if year==1950
			replace `var'=r(mean)*poptotSSAF if `var'==. & year<1950 
		}

		foreach var in poptotSEAS poptotSAS{
			g sh`var'=`var'/poptotSSEA
			sum sh`var' if year==1950
			replace `var'=r(mean)*poptotSSEA if `var'==. & year<1950 
		}
		g check1=shpoptotESAF +shpoptotWCAF 
		g check2=shpoptotSEAS +shpoptotSAS
		drop check* sh*




		
		
		
		

		/****construction of annual 1800-2023 population series for the 57 extended core territories**/
		keep year poptotWO  /*poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA*/ ///
		poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC_E  poptotNL poptotNO poptotDK poptotQM ///
		poptotUS poptotCA poptotAU poptotNZ poptotOH /// 
		poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD /// 
		poptotTR poptotEG poptotDZ poptotOE_E poptotIR poptotMA poptotSA poptotAE ///
		poptotZA poptotOJ_E poptotCD poptotET poptotKE poptotCI poptotML poptotNE poptotNG poptotRW poptotSD /// 
		poptotRU poptotOA /// 
		poptotCN poptotJP poptotOB_E  poptotKR poptotTW /// 
		poptotIN poptotID poptotOI_E poptotBD poptotMM poptotPK poptotPH poptotTH poptotVN ///
		poptotESAF poptotWCAF poptotSEAS poptotSAS ///
		poptotOC poptotOJ poptotOE poptotOI poptotOB
		order year poptotWO  /*poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA*/ ///
		poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC_E  poptotNL poptotNO poptotDK poptotQM ///
		poptotUS poptotCA poptotAU poptotNZ poptotOH /// 
		poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD /// 
		poptotTR poptotEG poptotDZ poptotOE_E poptotIR poptotMA poptotSA poptotAE ///
		poptotZA poptotOJ_E poptotCD poptotET poptotKE poptotCI poptotML poptotNE poptotNG poptotRW poptotSD /// 
		poptotRU poptotOA /// 
		poptotCN poptotJP poptotOB_E  poptotKR poptotTW /// 
		poptotIN poptotID poptotOI_E poptotBD poptotMM poptotPK poptotPH poptotTH poptotVN ///
		poptotESAF poptotWCAF poptotSEAS poptotSAS ///
		poptotOC poptotOJ poptotOE poptotOI poptotOB
		insobs 190
		replace year=1800 if _n==56
		replace year=year[_n-1]+1 if _n>=57
		
		sort year poptotWO
				drop poptotWO 
		drop if year==year[_n-1]
		
	gl extended	"DE FR GB IT ES SE OC_E NL NO DK QM US CA AU NZ OH AR BR CL CO MX OD TR EG DZ OE_E IR MA SA AE ZA OJ_E CD ET KE CI ML NE NG RW SD RU OA CN JP OB_E KR TW IN ID OI_E BD MM PK PH TH VN ESAF WCAF SEAS SAS "
		
		foreach i in /*WO EURO NAOC LATA MENA SSAF RUCA EASA SSEA*/ $extended OC OJ OE OI OB{
			forvalues j=1/20{
				replace poptot`i'=poptot`i'[21]/((poptot`i'[51]/poptot`i'[21])^((21-`j')/30)) if _n==`j'
			}
			forvalues j=22/50{
				replace poptot`i'=((51-`j')*poptot`i'[21]+(`j'-21)*poptot`i'[51])/30 if _n==`j'
			}
			forvalues j=52/80{
				replace poptot`i'=((81-`j')*poptot`i'[51]+(`j'-51)*poptot`i'[81])/30 if _n==`j'
			}
			forvalues j=82/100{
				replace poptot`i'=((101-`j')*poptot`i'[81]+(`j'-81)*poptot`i'[101])/20 if _n==`j'
			}
			forvalues j=102/110{
				replace poptot`i'=((111-`j')*poptot`i'[101]+(`j'-101)*poptot`i'[111])/10 if _n==`j'
			}
			forvalues j=112/120{
				replace poptot`i'=((121-`j')*poptot`i'[111]+(`j'-111)*poptot`i'[121])/10 if _n==`j'
			}
			forvalues j=122/130{
				replace poptot`i'=((131-`j')*poptot`i'[121]+(`j'-121)*poptot`i'[131])/10 if _n==`j'
			}
			forvalues j=132/140{
				replace poptot`i'=((141-`j')*poptot`i'[131]+(`j'-131)*poptot`i'[141])/10 if _n==`j'
			}
			forvalues j=142/150{
				replace poptot`i'=((151-`j')*poptot`i'[141]+(`j'-141)*poptot`i'[151])/10 if _n==`j'
			}
			forvalues j=152/160{
				replace poptot`i'=((161-`j')*poptot`i'[151]+(`j'-151)*poptot`i'[161])/10 if _n==`j'
			}
			forvalues j=162/170{
				replace poptot`i'=((171-`j')*poptot`i'[161]+(`j'-161)*poptot`i'[171])/10 if _n==`j'
			}
			forvalues j=172/180{
				replace poptot`i'=((181-`j')*poptot`i'[171]+(`j'-171)*poptot`i'[181])/10 if _n==`j'
			}
			forvalues j=225/226{ // imputes 2024 and 2025
				replace poptot`i'=((224-`j')*poptot`i'[214]+(`j'-214)*poptot`i'[224])/10 if _n==`j'
			}
			replace poptot`i'=poptot`i'/1000000
		}
		
replace poptotOI_E=poptotSEAS +poptotSAS	-poptotIN-poptotID-poptotBD-poptotMM-poptotPK-poptotPH-poptotTH-poptotVN	if poptotOI_E==. & year<1820
		order year /*poptotWO poptotEURO poptotNAOC poptotLATA poptotMENA poptotSSAF poptotRUCA poptotEASA poptotSSEA*/ poptotDE poptotFR poptotGB poptotIT poptotES poptotSE poptotOC_E poptotNL poptotNO poptotDK poptotQM poptotUS poptotCA poptotAU poptotNZ poptotOH poptotAR poptotBR poptotCL poptotCO poptotMX poptotOD poptotTR poptotEG poptotDZ poptotOE_E poptotIR poptotMA poptotSA poptotAE poptotZA poptotOJ_E poptotCD poptotET poptotKE poptotCI poptotML poptotNE poptotNG poptotRW poptotSD poptotRU poptotOA poptotCN poptotJP poptotOB_E poptotKR poptotTW poptotIN poptotID poptotOI_E poptotBD poptotMM poptotPK poptotPH poptotTH poptotVN poptotESAF poptotWCAF poptotSEAS poptotSAS
		*save 
		format _all %13.0g
		ren poptot* pop999i*


reshape long pop999i , i(year ) j(country) string
sort country year


save "$work_data/pops_1800_2023_57c.dta", replace




